@@ -32,29 +32,17 @@
 #include "canvas.h"
 #include "fpoint.h"
 #include "fpointarray.h"
-#include "hyphenator.h"
 #include "pageitem_table.h"
-#include "pageitem_textframe.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
-#include "scraction.h"
 #include "scribus.h"
-#include "scribusXml.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "text/frect.h"
-#include "ui/basepointwidget.h"
-#include "ui/hruler.h"
 #include "ui/insertTable.h"
-#include "ui/pageselector.h"
-#include "ui/propertiespalette.h"
-#include "ui/scrapbookpalette.h"
-#include "ui/vruler.h"
 #include "undomanager.h"
-#include "units.h"
-#include "util.h"
 #include "util_math.h"
 
 CreateMode::CreateMode(ScribusView* view) : CanvasMode(view) 
@@ -69,18 +57,18 @@ void CreateMode::drawControls(QPainter* p)
 
 	QPointF topLeft(createObjectPos.x(), createObjectPos.y());
 	QPointF btRight(canvasCurrCoord.x(), canvasCurrCoord.y());
-	QColor  drawColor = qApp->palette().color(QPalette::Active, QPalette::Highlight);
+	QColor  drawColor = QApplication::palette().color(QPalette::Active, QPalette::Highlight);
 
 	if (createObjectMode != modeDrawLine)
 	{
 		QRectF bounds = QRectF(topLeft, btRight).normalized();
 		//Lock Height to Width for Control Modifier for region drawing
-		if (modifiers==Qt::ControlModifier)
+		if (modifiers == Qt::ControlModifier)
 		{
 			bounds.setHeight(bounds.width());
-			if (btRight.y()<topLeft.y())
+			if (btRight.y() < topLeft.y())
 				bounds.moveBottom(topLeft.y());
-			if (btRight.x()<topLeft.x() && btRight.y()>topLeft.y())
+			if (btRight.x() < topLeft.x() && btRight.y() > topLeft.y())
 				bounds.moveTop(topLeft.y());
 		}
 		QRect localRect = m_canvas->canvasToLocal(bounds);
@@ -129,7 +117,7 @@ void CreateMode::drawControls(QPainter* p)
 		{
 			FPointArray poly;
 			int valCount = m_doc->ValCount;
-			double *vals = m_doc->ShapeValues;
+			const double *vals = m_doc->ShapeValues;
 			for (int a = 0; a < valCount-3; a += 4)
 			{
 				if (vals[a] < 0)
@@ -138,9 +126,9 @@ void CreateMode::drawControls(QPainter* p)
 					continue;
 				}
 				double x1 = localRect.width()  * vals[a] / 100.0;
-				double y1 = localRect.height() * vals[a+1] / 100.0;
-				double x2 = localRect.width()  * vals[a+2] / 100.0;
-				double y2 = localRect.height() * vals[a+3] / 100.0;
+				double y1 = localRect.height() * vals[a + 1] / 100.0;
+				double x2 = localRect.width()  * vals[a + 2] / 100.0;
+				double y2 = localRect.height() * vals[a + 3] / 100.0;
 				poly.addPoint(x1, y1);
 				poly.addPoint(x2, y2);
 			}
@@ -242,7 +230,7 @@ void CreateMode::mouseDoubleClickEvent(QMouseEvent *m)
 
 void CreateMode::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	modifiers = m->modifiers();
 	
 	double newX, newY;
@@ -250,7 +238,7 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 	QPainter p;
 //	QRect tx;
 	m->accept();
-//	qDebug() << "legacy mode move:" << m->x() << m->y() << m_canvas->globalToCanvas(m->globalPos()).x() << m_canvas->globalToCanvas(m->globalPos()).y();
+//	qDebug() << "legacy mode move:" << m->x() << m->y() << m_canvas->globalToCanvas(m->globalPosition()).x() << m_canvas->globalToCanvas(m->globalPosition()).y();
 //	emit MousePos(m->x()/m_canvas->scale(),// + m_doc->minCanvasCoordinate.x(), 
 //				  m->y()/m_canvas->scale()); // + m_doc->minCanvasCoordinate.y());
 
@@ -264,7 +252,7 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 	}
 	if ((!m_MouseButtonPressed) || !(m->buttons() & Qt::LeftButton))
 	{
-		m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
+		m_canvas->displayCorrectedXYHUD(m->globalPosition(), mousePointDoc.x(), mousePointDoc.y());
 		return;
 	}
 
@@ -319,7 +307,7 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 	{
 		if (modifiers == Qt::ControlModifier)
 			hSize = wSize;
-		m_canvas->displaySizeHUD(m->globalPos(), wSize, hSize, false);
+		m_canvas->displaySizeHUD(m->globalPosition(), wSize, hSize, false);
 	}
 	else
 	{
@@ -327,7 +315,7 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 		if (angle < 0.0)
 			angle = angle + 360;
 		double trueLength = sqrt(pow(createObjectRect.width(), 2) + pow(createObjectRect.height(), 2));
-		m_canvas->displaySizeHUD(m->globalPos(), trueLength, angle, true);
+		m_canvas->displaySizeHUD(m->globalPosition(), trueLength, angle, true);
 	}
 
 	// Necessary for drawControls to be called
@@ -336,7 +324,7 @@ void CreateMode::mouseMoveEvent(QMouseEvent *m)
 
 void CreateMode::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	modifiers = m->modifiers();
 	
 	double Rxp = 0, Ryp = 0;
@@ -347,7 +335,7 @@ void CreateMode::mousePressEvent(QMouseEvent *m)
 	inItemCreation = false;
 //	oldClip = 0;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
+	m_view->registerMousePress(m->globalPosition());
 //	QRect mpo(m->x()-m_doc->guidesPrefs().grabRadius, m->y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
 //	mpo.moveBy(qRound(m_doc->minCanvasCoordinate.x() * m_canvas->scale()), qRound(m_doc->minCanvasCoordinate.y() * m_canvas->scale()));
 	canvasPressCoord = mousePointDoc;
@@ -365,7 +353,7 @@ void CreateMode::mousePressEvent(QMouseEvent *m)
 	m_doc->ApplyGuides(&Rxp, &Ryp,true);
 	createObjectPos.setXY(Rxp, Ryp);
 
-	if (m->button() == Qt::MidButton)
+	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
 		if (m->modifiers() & Qt::ControlModifier)
@@ -415,6 +403,7 @@ void CreateMode::mouseReleaseEvent(QMouseEvent *m)
 									Um::Create + " " + currItem->getUName(),  "", Um::ICreate);
 		m_createTransaction.reset();
 		m_doc->changed();
+		m_doc->changedPagePreview();
 		/*currItem->update();
 		currItem->emitAllToGUI();*/
 	}
@@ -439,7 +428,7 @@ void CreateMode::mouseReleaseEvent(QMouseEvent *m)
 void CreateMode::selectPage(QMouseEvent *m)
 {
 	m_MouseButtonPressed = true;
-	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	canvasPressCoord     = mousePointDoc;
 //	QRect mpo(m->x()-m_doc->guidesPrefs().grabRadius, m->y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
 //	mpo.moveBy(qRound(Doc->minCanvasCoordinate.x() * m_canvas->scale()), qRound(m_doc->minCanvasCoordinate.y() * m_canvas->scale()));
@@ -450,8 +439,8 @@ void CreateMode::selectPage(QMouseEvent *m)
 		int i = m_doc->OnPage(canvasPressCoord.x(), canvasPressCoord.y());
 		if (i!=-1)
 		{
-			uint docCurrPageNo=m_doc->currentPageNumber();
-			uint j=static_cast<uint>(i);
+			uint docCurrPageNo = m_doc->currentPageNumber();
+			uint j = static_cast<uint>(i);
 			if (docCurrPageNo != j)
 			{
 				m_doc->setCurrentPage(m_doc->Pages->at(j));
@@ -459,8 +448,8 @@ void CreateMode::selectPage(QMouseEvent *m)
 				m_view->DrawNew();
 			}
 		}
-/*		uint docPagesCount=m_doc->Pages->count();
-		uint docCurrPageNo=m_doc->currentPageNumber();
+/*		uint docPagesCount = m_doc->Pages->count();
+		uint docCurrPageNo = m_doc->currentPageNumber();
 		for (uint i = 0; i < docPagesCount; ++i)
 		{
 			int x = static_cast<int>(m_doc->Pages->at(i)->xOffset() * m_canvas->scale());
@@ -497,7 +486,7 @@ void CreateMode::SetupDrawNoResize(int nr)
 	//#6456 m_view->resetMoveTimer();
 }
 
-void CreateMode::getFrameItemTypes(int& itemType, int& frameType)
+void CreateMode::getFrameItemTypes(int& itemType, int& frameType) const
 {
 	itemType  = (int) PageItem::Polygon;
 	frameType = (int) PageItem::Rectangle;
@@ -613,7 +602,7 @@ PageItem* CreateMode::doCreateNewObject()
 	if (createObjectMode != modeDrawLine)
 	{
 		createObjectRect = createObjectRect.normalized();
-		if (modifiers==Qt::ControlModifier)
+		if (modifiers == Qt::ControlModifier)
 		{
 			//bottom right and upper left are ok
 			//upper right
@@ -928,7 +917,7 @@ bool CreateMode::doOneClick(FPoint& startPoint, FPoint& endPoint)
 	return doCreate;
 }
 
-FRect CreateMode::adjustedRect(FPoint &firstPoint, FPoint &secondPoint)
+FRect CreateMode::adjustedRect(const FPoint &firstPoint, const FPoint &secondPoint)
 {
 	// Lock to grid.
 	FPoint first = m_doc->ApplyGridF(firstPoint);
