@@ -54,7 +54,7 @@ class CanvasMode_EditGradient :  public CanvasMode
 
 	private:
 
-		typedef enum
+		enum eGradientPoint
 		{
 			noPointDefined,
 			useGradientStart,
@@ -66,7 +66,7 @@ class CanvasMode_EditGradient :  public CanvasMode
 			useControl3,
 			useControl4,
 			useControl5
-		} eGradientPoint;
+		};
 
 		inline bool GetItem(PageItem** pi);
 
@@ -77,7 +77,7 @@ class CanvasMode_EditGradient :  public CanvasMode
 		FPoint OldGrControl3;
 		FPoint OldGrControl4;
 		FPoint OldGrControl5;
-		ScribusMainWindow* m_ScMW {nullptr};
+		// ScribusMainWindow* m_ScMW {nullptr};
 		double OldGrEndX {0.0};
 		double OldGrEndY {0.0};
 		double OldGrFocalX {0.0};
