@@ -18,26 +18,22 @@
 
 #include <QApplication>
 #include <QCursor>
-#include <QDesktopWidget>
+#include <QDebug>
 #include <QEvent>
 #include <QInputDialog>
 #include <QMouseEvent>
+#include <QPainter>
 #include <QPoint>
 #include <QRect>
 #include <QScreen>
-#include <QDebug>
 
 #include "appmodes.h"
 #include "canvas.h"
-#include "fpoint.h"
 #include "sccolorengine.h"
 #include "scribus.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "ui/propertiespalette.h"
-#include "util.h"
-#include "util_math.h"
 
 
 CanvasMode_EyeDropper::CanvasMode_EyeDropper(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
@@ -140,7 +136,7 @@ void CanvasMode_EyeDropper::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
+	m_view->registerMousePress(m->globalPosition());
 }
 
 void CanvasMode_EyeDropper::mouseReleaseEvent(QMouseEvent *m)
@@ -155,19 +151,22 @@ void CanvasMode_EyeDropper::mouseReleaseEvent(QMouseEvent *m)
 	m_view->setCursor(QCursor(Qt::ArrowCursor));
 
 	QPixmap pm;
-	QWidget* pWidget = QApplication::widgetAt(m->globalPos());
+	QWidget* pWidget = QApplication::widgetAt(m->globalPosition().toPoint());
 	if (pWidget)
 	{
 		// This works on Wayland contrary to the QScreen::grabWindow() solution,
 		// but only if clicked point is inside Scribus application
-		auto localPos = pWidget->mapFromGlobal(m->globalPos());
+		auto localPos = pWidget->mapFromGlobal(m->globalPosition().toPoint());
 		pm = pWidget->grab(QRect(localPos.x(), localPos.y(), 1, 1));
 	}
 	else
 	{
-		QScreen* screen = QGuiApplication::primaryScreen();
+		QScreen* screen = QGuiApplication::screenAt(m->globalPosition().toPoint());
 		if (screen)
-			pm = screen->grabWindow(QApplication::desktop()->winId(), m->globalPos().x(), m->globalPos().y(), 1, 1);
+		{
+			QPoint globalPos = m->globalPosition().toPoint();
+			pm = screen->grabWindow(0, globalPos.x(), globalPos.y(), 1, 1);
+		}
 	}
 	if (pm.isNull())
 	{
