@@ -13,7 +13,6 @@
 *                                                                         *
 ***************************************************************************/
 
-#include "canvasmode_measurements.h"
 
 #include <QApplication>
 #include <QPainter>
@@ -21,30 +20,29 @@
 
 #include "appmodes.h"
 #include "canvas.h"
+#include "canvasmode_measurements.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "ui/measurements.h"
 #include "util_math.h"
 
 
-MeasurementsMode::MeasurementsMode(ScribusView* view) : CanvasMode(view), m_start(0,0), m_current(0,0)
+MeasurementsMode::MeasurementsMode(ScribusView* view) : CanvasMode(view)
 {
 	m_palette = new Measurements(m_view);
 	m_palette->startup();
 	m_palette->hide();
 	connect( m_palette, SIGNAL(paletteShown(bool)), this, SLOT(setActive(bool)));
-	m_active = false;
-	m_startDoc = FPoint(0,0);
-	m_currentDoc = FPoint(0,0);
 }
 
-void MeasurementsMode::enterEvent(QEvent *)
+void MeasurementsMode::enterEvent(QEvent *e)
 {
 	m_view->setCursor(QCursor(Qt::CrossCursor));
 }
 
-void MeasurementsMode::leaveEvent(QEvent *)
+void MeasurementsMode::leaveEvent(QEvent *e)
 {
+	// Nothing to do
 }
 
 void MeasurementsMode::setActive(bool active)
@@ -53,15 +51,16 @@ void MeasurementsMode::setActive(bool active)
 		m_view->requestMode(modeNormal);
 }
 
-
-void MeasurementsMode::activate(bool)
+void MeasurementsMode::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
 	m_palette->show();
 }
 
-void MeasurementsMode::deactivate(bool)
+void MeasurementsMode::deactivate(bool forGesture)
 {
 	m_palette->hide();
+	CanvasMode::deactivate(forGesture);
 }
 
 void MeasurementsMode::drawControls(QPainter* p)
@@ -74,12 +73,22 @@ void MeasurementsMode::drawControls(QPainter* p)
 	p->restore();
 }
 
+void MeasurementsMode::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void MeasurementsMode::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
+}
+
 void MeasurementsMode::mouseReleaseEvent(QMouseEvent *m)
 {
 	if (m_active)
 	{
 		m->accept();
-		adjustPoint(m->globalPos());		
+		adjustPoint(m->globalPosition());		
 	}
 	m_active = false;
 	showValues();
@@ -90,13 +99,13 @@ void MeasurementsMode::mouseMoveEvent(QMouseEvent *m)
 	if (m_active)
 	{
 		m->accept();
-		adjustPoint(m->globalPos());
+		adjustPoint(m->globalPosition());
 		showValues();
 	}
 	else
 	{
-		FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-		m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
+		FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+		m_canvas->displayCorrectedXYHUD(m->globalPosition(), mousePointDoc.x(), mousePointDoc.y());
 	}
 }
 
@@ -104,24 +113,24 @@ void MeasurementsMode::mousePressEvent(QMouseEvent *m)
 {
 	m->accept();
 	m_active = true;
-	adjustPoint(m->globalPos());
+	adjustPoint(m->globalPosition());
 	m_start = m_current;
 	m_startDoc = m_currentDoc;
 	showValues();
 }
 
-void MeasurementsMode::adjustPoint(QPoint globalPoint)
+void MeasurementsMode::adjustPoint(QPointF globalPoint)
 {
-	QPoint point = globalPoint - (m_canvas->mapToParent(QPoint(0, 0)) + m_canvas->parentWidget()->mapToGlobal(QPoint(0, 0)));
-	m_canvas->update(QRect(m_start, m_current).normalized().adjusted(-1,-1,1,1));
+	QPointF point = globalPoint - (m_canvas->mapToParent(QPointF(0, 0)) + m_canvas->parentWidget()->mapToGlobal(QPointF(0, 0)));
+	m_canvas->update(QRect(m_start.toPoint(), m_current.toPoint()).normalized().adjusted(-1, -1, 1, 1));
 	m_current = point;
-	m_currentDoc = m_canvas->localToCanvas(m_current) - FPoint(m_doc->currentPage()->xOffset(),m_doc->currentPage()->yOffset());
+	m_currentDoc = m_canvas->localToCanvas(m_current) - FPoint(m_doc->currentPage()->xOffset(), m_doc->currentPage()->yOffset());
 }
 
 void MeasurementsMode::showValues()
 {
 	double dx = m_currentDoc.x() - m_startDoc.x();
 	double dy = m_currentDoc.y() - m_startDoc.y();
-	m_palette->setValues(m_startDoc.x(), m_startDoc.y(), m_currentDoc.x(), m_currentDoc.y(), -xy2Deg(dx, dy), sqrt(dx*dx + dy*dy));
-	m_canvas->update(QRect(m_start, m_current).normalized());
+	m_palette->setValues(m_startDoc.x(), m_startDoc.y(), m_currentDoc.x(), m_currentDoc.y(), -xy2Deg(dx, dy), sqrt(dx * dx + dy * dy));
+	m_canvas->update(QRect(m_start.toPoint(), m_current.toPoint()).normalized());
 }
