@@ -13,9 +13,6 @@
 *                                                                         *
 ***************************************************************************/
 
-
-#include "canvasmode_panning.h"
-
 #include <QCursor>
 #include <QEvent>
 #include <QMouseEvent>
@@ -25,11 +22,9 @@
 
 #include "canvas.h"
 #include "canvasgesture_pan.h"
-#include "fpoint.h"
-#include "fpointarray.h"
-#include "scribusview.h"
+#include "canvasmode_panning.h"
 #include "scribusdoc.h"
-#include "util.h"
+#include "scribusview.h"
 
 CanvasMode_Panning::CanvasMode_Panning(ScribusView* view) : CanvasMode(view) 
 {
@@ -41,7 +36,7 @@ void CanvasMode_Panning::drawControls(QPainter* p)
 	commonDrawControls(p, false);
 }
 
-void CanvasMode_Panning::enterEvent(QEvent *)
+void CanvasMode_Panning::enterEvent(QEvent *e)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 	{
@@ -54,9 +49,10 @@ void CanvasMode_Panning::leaveEvent(QEvent *e)
 {
 }
 
-
 void CanvasMode_Panning::activate(bool fromGesture)
 {
+	CanvasMode::activate(fromGesture);
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m_doc->DragP = false;
@@ -74,6 +70,17 @@ void CanvasMode_Panning::activate(bool fromGesture)
 void CanvasMode_Panning::deactivate(bool forGesture)
 {
 	m_view->setRedrawMarkerShown(false);
+	CanvasMode::deactivate(forGesture);
+}
+
+void CanvasMode_Panning::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CanvasMode_Panning::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
 }
 
 void CanvasMode_Panning::mouseDoubleClickEvent(QMouseEvent *m)
@@ -92,7 +99,7 @@ void CanvasMode_Panning::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());*/
+	m_view->registerMousePress(m->globalPosition());*/
 	
 	m_view->startGesture(m_panGesture);
 	m_panGesture->mousePressEvent(m);
