@@ -6,7 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 
 #include <QItemSelectionModel>
-#include <QWidget>
+#include <QPaintDevice>
 
 #include "chartablemodel.h"
 #include "fonts/scface.h"
