@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 /***************************************************************************
 	begin                : Aug 2005
 	copyright            : (C) 2005 by Craig Bradney
-	email                : cbradney@zip.com.au
+	email                : cbradney@scribus.info
 ***************************************************************************/
 
 /***************************************************************************
@@ -43,7 +43,7 @@ class QEvent;
    done initially.
 
  trNone = tr("None") was removed because it's problematic in
-   East European langiages.
+   East European languages.
 */
 class SCRIBUS_API CommonStrings : public QObject
 {
@@ -105,6 +105,7 @@ public:
 	static QString trYesKey;
 	//! \brief Translated "No" with key accelerator "&No"
 	static QString trNoKey;
+	static QString trCustom;
 
 	//Item Types
 	static QString itemType_TextFrame;
