@@ -14,10 +14,10 @@
 ScDLManager::ScDLManager(QObject *parent)
 	: QObject(parent)
 {
-	m_thread=new ScDLThread();
-	connect(m_thread, SIGNAL(fileReceived(const QString &)), this, SLOT(dlReceived(QString)));
-	connect(m_thread, SIGNAL(fileFailed(const QString &)), this, SLOT(dlFailed(QString)));
-	connect(m_thread, SIGNAL(fileStarted(const QString &)), this, SLOT(dlStarted(QString)));
+	m_thread = new ScDLThread();
+	connect(m_thread, SIGNAL(fileReceived(QString)), this, SLOT(dlReceived(QString)));
+	connect(m_thread, SIGNAL(fileFailed(QString)), this, SLOT(dlFailed(QString)));
+	connect(m_thread, SIGNAL(fileStarted(QString)), this, SLOT(dlStarted(QString)));
 	connect(m_thread, SIGNAL(fileDownloadProgress(qint64,qint64)), this, SIGNAL(fileDownloadProgress(qint64,qint64)));
 	//connect(thread, SIGNAL(finished()), this, SIGNAL(finished()));
 	connect(m_thread, SIGNAL(finished()), this, SLOT(moveFinishedDownloads()));
@@ -89,7 +89,7 @@ void ScDLManager::dlStarted(const QString& filename)
 	while (i.hasNext())
 	{
 		i.next();
-		if (i.value().state!=DownloadData::Successful && i.value().state!=DownloadData::Failed && i.value().downloadLocation+i.value().name==filename)
+		if (i.value().state != DownloadData::Successful && i.value().state != DownloadData::Failed && i.value().downloadLocation + i.value().name == filename)
 		{
 			//qDebug()<<"starting"<<i.value().downloadLocation+i.value().name<<filename;
 			i.value().state = DownloadData::Started;
@@ -143,14 +143,14 @@ void ScDLManager::moveFinishedDownloads()
 		{
 			case DownloadData::Successful:
 				{
-					if (i.value().downloadLocation==i.value().destinationLocation)
+					if (i.value().downloadLocation == i.value().destinationLocation)
 						;//qDebug()<<i.value().name<<"is in"<<i.value().downloadLocation<<"which is the same as"<<i.value().destinationLocation;
 					else
 					{
 						//qDebug()<<"Need to move"<<i.value().name<<"from"<<i.value().downloadLocation<<"to"<<i.value().destinationLocation;
-						QString newName=i.value().name;
+						QString newName = i.value().name;
 						if (!i.value().destinationName.isEmpty())
-							newName=i.value().destinationName;
+							newName = i.value().destinationName;
 						moveFile(i.value().downloadLocation+i.value().name, i.value().destinationLocation+newName);
 					}
 				}
