@@ -3,6 +3,8 @@
 #include "scdlthread.h"
 #include "scpaths.h"
 
+#include <utility>
+
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
@@ -10,7 +12,6 @@
 #include <QNetworkRequest>
 #include <QUrl>
 
-
 ScDLThread::ScDLThread(QObject *parent) : QThread(parent)
 {
 	connect(this, SIGNAL(runSignal()), this, SLOT(runSlot()));
@@ -36,11 +37,11 @@ void ScDLThread::addURL(const QUrl &url, bool overwrite, const QString& location
 void ScDLThread::addURLs(const QStringList &urlList, bool overwrite, const QString& location, const QString& destinationLocation)
 {
 	//qDebug()<<"ScDLThread::addURLs:"<<urlList;
-	m_urlList=urlList;
+	m_urlList = urlList;
 	QString l(QDir::cleanPath(location));
 	if (!l.endsWith("/"))
 		l += "/";
-	for (const QString& u : qAsConst(m_urlList))
+	for (const QString& u : std::as_const(m_urlList))
 	{
 		QUrl url(u);
 		if (!urlOK(u))
@@ -93,11 +94,11 @@ void ScDLThread::startNextDownload()
 	if (m_downloadQueue.isEmpty())
 	{
 		//qDebug()<<downloadedCount<<"/"<<totalCount<<"files downloaded successfully";
-		m_downloadedCount=m_totalCount=0;
+		m_downloadedCount = m_totalCount = 0;
 		emit finished();
 		return;
 	}
-	QPair<QUrl, QString> urlPair=m_downloadQueue.dequeue();
+	QPair<QUrl, QString> urlPair = m_downloadQueue.dequeue();
 
 	QString filename = saveFileName(urlPair.first, urlPair.second, true);
 	if (filename.isEmpty())
@@ -116,8 +117,8 @@ void ScDLThread::startNextDownload()
 	}
 	emit fileStarted(m_output.fileName());
 	QNetworkRequest request(urlPair.first);
-	//QNetworkReply *nwr=manager.head(request);
-	//qDebug()<<nwr->url()<<nwr->rawHeaderList();
+	//QNetworkReply *nwr = manager.head(request);
+	//qDebug() << nwr->url() << nwr->rawHeaderList();
 	//connect(&manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(replyFinished(QNetworkReply*)));
 	m_currentDownload = m_manager.get(request);
 	connect(m_currentDownload, SIGNAL(finished()), this, SLOT(downloadFinished()));
@@ -160,13 +161,13 @@ void ScDLThread::downloadFinished()
 
 void ScDLThread::replyFinished(QNetworkReply* reply)
 {
-	QVariant possibleRedirectUrl =reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
+	QVariant possibleRedirectUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
 	QUrl urlRedirectedTo = possibleRedirectUrl.toUrl();
 	QString text;
 	/* If the URL is not empty, we're being redirected. */
-	if(!urlRedirectedTo.isEmpty())
+	if (!urlRedirectedTo.isEmpty())
 	{
-		qDebug()<<reply->header(QNetworkRequest::LocationHeader);
+		qDebug() << reply->header(QNetworkRequest::LocationHeader);
 		text = QString("QNAMRedirect::replyFinished: Redirected to ").append(urlRedirectedTo.toString());
 		addURL(text, true, ScPaths::downloadDir(), ScPaths::downloadDir());
 		/* We'll do another request to the redirection url. */
