@@ -676,7 +676,7 @@ namespace cff {
 		CFF_Number result;
 		result.type = cff_varnt_Card;
 		result.exponent = 0;
-		uint start=pos;
+		uint start = pos;
 		uchar b0 = dict[pos++];
 		uchar b1,b2,b3,b4;
 		if (b0 == cff_dict_Card16)
@@ -1548,7 +1548,7 @@ namespace cff {
 		}
 		result.append('\0');
 		result.append((uchar) (maxGid+1));
-		for (uint gid = 0; gid <= maxGid; ++gid);
+		for (uint gid = 0; gid <= maxGid; ++gid)
 		{
 			if (codes.contains(gid))
 				result.append(codes[gid]);
