@@ -14,6 +14,43 @@
 #include FT_TRUETYPE_IDS_H
 
 #include <QDebug>
+#include <QScopedPointer>
+
+#include "scconfig.h"
+
+#include <harfbuzz/hb.h>
+#ifdef HAVE_HARFBUZZ_SUBSET
+#include <harfbuzz/hb-subset.h>
+#endif
+
+struct HbBlobDeleter
+{
+	static void cleanup(void *pointer)
+	{
+		if (pointer)
+			hb_blob_destroy((hb_blob_t*) pointer);
+	}
+};
+
+struct HbFaceDeleter
+{
+	static void cleanup(void *pointer)
+	{
+		if (pointer)
+			hb_face_destroy((hb_face_t*) pointer);
+	}
+};
+
+#ifdef HAVE_HARFBUZZ_SUBSET
+struct HbSubsetInputDeleter
+{
+	static void cleanup(void *pointer)
+	{
+		if (pointer)
+			hb_subset_input_destroy((hb_subset_input_t*) pointer);
+	}
+};
+#endif
 
 namespace sfnt {
 	
@@ -22,6 +59,7 @@ namespace sfnt {
 		const unsigned char * pp = reinterpret_cast<const unsigned char*>(bb.data()) + pos;
 		return pp[0];
 	}
+
 	quint32 word(const QByteArray & bb, uint pos)
 	{
 		const unsigned char * pp = reinterpret_cast<const unsigned char*>(bb.data()) + pos;
@@ -95,14 +133,8 @@ namespace sfnt {
 		return true;
 	}
 
-
-
-
-
-
 	const uint post_format10_names_count = 258;
 
-
 	static const char* post_format10_names[] = {
 		".notdef",
 		".null",
@@ -305,8 +337,6 @@ namespace sfnt {
 		"dcroat"
 	};
 
-
-
 	bool PostTable::usable() const
 	{
 		return m_usable;
@@ -343,7 +373,6 @@ namespace sfnt {
 		return ".notdef";
 	}
 
-
 	void PostTable::readFrom(FT_Face face)
 	{
 		QByteArray postData;
@@ -421,12 +450,10 @@ namespace sfnt {
 			usedNames[name] = gid;
 			m_names.append(name);
 		}
-		m_errorMsg = "";
+		m_errorMsg.clear();
 		m_usable = true;
 	}
 
-
-
 	int copyTable(QByteArray& ttf, uint destDirEntry, uint pos, const QByteArray& source, uint dirEntry)
 	{
 		FT_ULong tag = word(source, dirEntry + ttf_TableRecord_tag);
@@ -445,16 +472,13 @@ namespace sfnt {
 		return tableSize;
 	}
 
-
 	QByteArray extractFace(const QByteArray& coll, int faceIndex)
 	{
 		QByteArray result;
 
 		const int numFonts = word(coll, ttc_numFonts);
 		if (faceIndex >= static_cast<int>(numFonts))
-		{
 			return result;
-		}
 
 		uint faceOffset = sfnt::word(coll, ttc_OffsetTables + 4 * faceIndex);
 		uint nTables	= sfnt::word16(coll, faceOffset + ttf_numtables);
@@ -472,18 +496,12 @@ namespace sfnt {
 		}
 		result.resize(headerLength + tableLengths);
 		if (!result.data())
-		{
-			result.resize(0);
-			return result;
-		}
+			return QByteArray();
 
 		// write header
 		//		sDebug(QObject::tr("memcpy header: %1 %2 %3").arg(0).arg(faceOffset).arg(headerLength));
 		if (!copy(result, 0, coll, faceOffset, headerLength))
-		{
-			result.resize(0);
-			return result;
-		}
+			return QByteArray();
 		uint pos = headerLength;
 		for (uint i=0; i < nTables; ++i)
 		{
@@ -492,10 +510,7 @@ namespace sfnt {
 
 			int tableSize = copyTable(result, destDirEntry, pos, coll, sourceDirEntry);
 			if (tableSize < 0)
-			{
-				result.resize(0);
-				return result;
-			}
+				return QByteArray();
 			pos += tableSize;
 
 			// pad
@@ -512,9 +527,7 @@ namespace sfnt {
 		for (uint i=0; i < nTables; ++i)
 		{
 			if (ttfTag == tag(word(ttf, pos + ttf_TableRecord_tag)))
-			{
 				return pos;
-			}
 			pos += ttf_TableRecord_Size;
 		}
 		return 0;
@@ -561,7 +574,6 @@ namespace sfnt {
 		return result;
 	}
 
-
 	quint32 calcTableChecksum(QByteArray& table)
 	{
 		quint32 Sum = 0L;
@@ -570,7 +582,6 @@ namespace sfnt {
 		return Sum;
 	}
 
-
 	void writeTable(QByteArray& ttf, const QByteArray& tag, QByteArray& table)
 	{
 		//qDebug() << "writing table" << tag << table.size() << "@" << ttf.size();
@@ -586,7 +597,6 @@ namespace sfnt {
 		ttf.append(table);
 	}
 
-
 	bool hasLongLocaFormat(const QByteArray& ttf)
 	{
 		const QByteArray head = getTable(ttf, "head");
@@ -595,7 +605,6 @@ namespace sfnt {
 		return idxToLocFormat == 1;
 	}
 
-
 	QList<quint32> readLoca(const QByteArray& ttf)
 	{
 		QList<quint32> result;
@@ -603,12 +612,12 @@ namespace sfnt {
 		result.reserve(loca.length());
 		if (hasLongLocaFormat(ttf))
 		{
-			for (int i = 0; i < loca.length(); i+=4)
+			for (int i = 0; i < loca.length(); i += 4)
 				result.append(word(loca, i));
 		}
 		else
 		{
-			for (int i = 0; i < loca.length(); i+=2)
+			for (int i = 0; i < loca.length(); i += 2)
 				result.append(word16(loca, i) * 2);
 		}
 		return result;
@@ -630,7 +639,6 @@ namespace sfnt {
 		return result;
 	}
 
-
 	QList<std::pair<qint16,quint16> > readHmtx(const QByteArray& ttf)
 	{
 		QList<std::pair<qint16,quint16> > result;
@@ -658,7 +666,6 @@ namespace sfnt {
 		return result;
 	}
 
-
 	QByteArray writeHmtx(const QList<std::pair<qint16,quint16> >& longHorMetrics)
 	{
 		QByteArray result;
@@ -673,7 +680,6 @@ namespace sfnt {
 		return result;
 	}
 
-
 	QMap<uint, uint> readCMap(const QByteArray& ttf)
 	{
 		QMap<uint,uint> result;
@@ -706,7 +712,7 @@ namespace sfnt {
 				symbolFormat = format;
 				continue;
 			}
-			format = 1; // no such format
+//			format = 1; // no such format
 		}
 		// If no unicode cmap was found, fallback on ms symbol cmap
 		uint format = unicodeFormat;
@@ -727,7 +733,7 @@ namespace sfnt {
 					uint idRangeOffsets = idDeltas + segCount2 + ttf_cmap4_IdRangeOffsets_IdDeltas;
 					//uint glyphIndexArray = idRangeOffsets + segCount2 + ttf_cmap4_GlyphIds_IdRangeOffsets;
 
-					for (uint seg = 0; seg < segCount2; seg+=2)
+					for (uint seg = 0; seg < segCount2; seg += 2)
 					{
 						uint start = word16(cmaps, startCodes + seg);
 						uint end = word16(cmaps, endCodes + seg);
@@ -801,8 +807,6 @@ namespace sfnt {
 		return result;
 	}
 
-
-
 	QByteArray writeCMap(const QMap<uint, uint>& cmap)
 	{
 		// we always write only one table: platform=3(MS), encoding=1(Unicode 16bit)
@@ -932,9 +936,7 @@ namespace sfnt {
 				{
 					quint16 glyph = cmap[startCode + offset];
 					if (glyph != 0)
-					{
 						glyph -= idDeltas[i];
-					}
 					appendWord16(result, glyph);
 				}
 			}
@@ -944,7 +946,6 @@ namespace sfnt {
 		return result;
 	}
 	
-	
 	QList<uint> copyGlyphComponents(QByteArray& destGlyf, const QByteArray& srcGlyf, uint srcOffset,
 									QMap<uint,uint>& newForOldGid, uint& nextFreeGid)
 	{
@@ -976,25 +977,32 @@ namespace sfnt {
 			appendWord16(destGlyf, glyphIndex);
 			
 			/* args */
-			if ( flags & ttf_glyf_ComponentFlag_ARG_1_AND_2_ARE_WORDS) {
+			if ( flags & ttf_glyf_ComponentFlag_ARG_1_AND_2_ARE_WORDS)
+			{
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // arg1
 				pos += 2;
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // arg2
 				pos += 2;
 			}
-			else {
+			else
+			{
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // arg1and2
 				pos += 2;
 			}
-			if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_A_SCALE ) {
+			if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_A_SCALE )
+			{
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // scale
 				pos += 2;
-			} else if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_AN_X_AND_Y_SCALE ) {
+			}
+			else if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_AN_X_AND_Y_SCALE )
+			{
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // xscale
 				pos += 2;
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // yscale
 				pos += 2;
-			} else if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_A_TWO_BY_TWO ) {
+			}
+			else if ( flags & ttf_glyf_ComponentFlag_WE_HAVE_A_TWO_BY_TWO )
+			{
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // xscale
 				pos += 2;
 				appendWord16(destGlyf, word16(srcGlyf, pos)); // scale01
@@ -1018,7 +1026,6 @@ namespace sfnt {
 		
 		return result;
 	}
-	
 
 	QList<uint> copyGlyph(QList<uint>& destLoca, QByteArray& destGlyf, uint destGid,
 						  const QList<uint>& srcLoca, const QByteArray& srcGlyf, uint srcGid,
@@ -1060,16 +1067,13 @@ namespace sfnt {
 		return compositeElements;
 	}
 	
-	
-	QByteArray subsetFace(const QByteArray& ttf, QList<uint>& glyphs)
+	QByteArray subsetFace(const QByteArray& ttf, QList<uint>& glyphs, QMap<uint, uint>& glyphMap)
 	{
 		QMap<QByteArray,QByteArray> tables;
 		
-		
 		//		qDebug() << "loca table:" << (void*) oldLoca[0] << (void*) oldLoca[1] << (void*) oldLoca[2] << (void*) oldLoca[3] << (void*) oldLoca[4] << (void*) oldLoca[5] << (void*) oldLoca[6] << (void*) oldLoca[7];
-		
 
-		QMap<uint,uint> newForOldGid;
+		QMap<uint, uint> newForOldGid;
 		if (glyphs.length() == 0)
 		{
 			tables["loca"] = getTable(ttf, "loca");
@@ -1105,7 +1109,6 @@ namespace sfnt {
 			tables["glyf"] = newGlyf;
 		}
 		
-		
 		QMap<uint,uint> cmap = readCMap(ttf);
 		QMap<uint,uint>::iterator it;
 		uint firstChar = 0xFFFFFFFF;
@@ -1130,7 +1133,6 @@ namespace sfnt {
 			}
 		}
 		tables["cmap"] = writeCMap(cmap);
-
 		
 		QByteArray os2 = getTable(ttf, "OS/2");
 		if (os2.length() > ttf_os2_usLastCharIndex)
@@ -1201,12 +1203,10 @@ namespace sfnt {
 		QByteArray fpgm = getTable(ttf, "fpgm");
 		if (fpgm.length() > 0)
 			tables["fpgm"] = fpgm;
-		
 
 		QByteArray head = getTable(ttf, "head");
 		putWord(head, ttf_head_checkSumAdjustment, 0);
 		tables["head"] = head;
-		
 
 		QByteArray font = createTableDir(tables.keys());
 		QMap<QByteArray,QByteArray>::iterator tableP;
@@ -1220,9 +1220,85 @@ namespace sfnt {
 		headTable = word(font, headTable + ttf_TableRecord_offset);
 		putWord(font, headTable + ttf_head_checkSumAdjustment, checkSumAdjustment);
 		
+		glyphMap.clear();
+		for (int i = 0; i < glyphs.length(); ++i)
+			glyphMap[glyphs[i]] = i;
 		// done!
 		
 		return font;
 	}
+
+	QByteArray subsetFaceWithHB(const QByteArray& fontData, QList<uint> cids, int faceIndex, QMap<uint, uint>& glyphMap)
+	{
+		glyphMap.clear();
+
+#ifdef HAVE_HARFBUZZ_SUBSET
+		QScopedPointer<hb_blob_t, HbBlobDeleter> hbBlob(hb_blob_create(fontData.data(), fontData.length(), HB_MEMORY_MODE_READONLY, nullptr, nullptr));
+		if (hbBlob.isNull())
+			return QByteArray();
+
+		QScopedPointer<hb_face_t, HbFaceDeleter> hbFullFace(hb_face_create(hbBlob.get(), faceIndex));
+		if (hbFullFace.isNull())
+			return QByteArray();
+
+		QScopedPointer<hb_subset_input_t, HbSubsetInputDeleter> hbSubsetInput(hb_subset_input_create_or_fail());
+		hb_set_t* glyphSet = hb_subset_input_glyph_set(hbSubsetInput.get());
+		if (glyphSet == nullptr)
+			return QByteArray();
+
+		for (int i = 0; i < cids.count(); ++i)
+			hb_set_add(glyphSet, cids.at(i));
+
+#if HB_VERSION_ATLEAST(2, 9, 0)
+		uint32_t subsetFlags = (uint32_t) hb_subset_input_get_flags(hbSubsetInput.get());
+		subsetFlags |= HB_SUBSET_FLAGS_RETAIN_GIDS;
+		subsetFlags &= ~HB_SUBSET_FLAGS_NO_HINTING;
+		subsetFlags |= HB_SUBSET_FLAGS_NAME_LEGACY;
+		hb_subset_input_set_flags(hbSubsetInput.get(), subsetFlags);
+#else
+		hb_subset_input_set_retain_gids(hbSubsetInput.get(), true);
+		hb_subset_input_set_drop_hints(hbSubsetInput.get(), false);
+#if HB_VERSION_ATLEAST(2, 6, 5)
+		hb_subset_input_set_name_legacy(hbSubsetInput.get(), true);
+#endif
+#endif
+
+#if HB_VERSION_ATLEAST(2, 9, 0)
+		QScopedPointer<hb_face_t, HbFaceDeleter> hbSubsetFace(hb_subset_or_fail(hbFullFace.get(), hbSubsetInput.get()));
+		if (hbSubsetFace.isNull())
+			return QByteArray();
+#else
+		QScopedPointer<hb_face_t, HbFaceDeleter> hbSubsetFace(hb_subset(hbFullFace.get(), hbSubsetInput.get()));
+		if (hbSubsetFace.isNull())
+			return QByteArray();
+#endif
+
+		QScopedPointer<hb_blob_t, HbBlobDeleter> hbSubsetBlob(hb_face_reference_blob(hbSubsetFace.get()));
+		if (hbSubsetBlob.isNull())
+			return QByteArray();
+
+		unsigned int length;
+		const char* subsetData = hb_blob_get_data(hbSubsetBlob.get(), &length);
+
+		QByteArray subset(subsetData, length);
+		if (!subset.isEmpty())
+		{
+			for (int i = 0; i < cids.length(); ++i)
+				glyphMap[cids[i]] = cids[i];
+		}
+		return subset;
+#else
+		return QByteArray();
+#endif
+	}
+
+	bool canSubsetOpenTypeFonts()
+	{
+#ifdef HAVE_HARFBUZZ_SUBSET
+		return true;
+#else
+		return false;
+#endif
+	}
 	
 } // namespace sfnt
