@@ -13,7 +13,7 @@ for which a new license (GPL+exception) is in place.
 	copyright            : (C) 2004 by Alessandro Rimoldi
 	email                : http://ideale.ch/contact
 	copyright            : (C) 2005 by Craig Bradney
-	email                : cbradney@zip.com.au
+	email                : cbradney@scribus.info
 ***************************************************************************/
 
 /***************************************************************************
@@ -29,6 +29,7 @@ for which a new license (GPL+exception) is in place.
 #include <csignal>
 
 #include <QApplication>
+#include <QImageReader>
 #include <QMessageBox>
 
 #include "scribusapp.h"
@@ -69,6 +70,8 @@ int mainApp(int argc, char **argv)
 	qputenv("QT_QPA_PLATFORM", "xcb");
 #endif
 
+	QImageReader::setAllocationLimit(1024);
+
 	ScribusQApp app(argc, argv);
 	initCrashHandler();
 	app.parseCommandLine();
