@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 /***************************************************************************
     begin                : Jan 2005
     copyright            : (C) 2005 by Craig Bradney
-    email                : cbradney@zip.com.au
+    email                : cbradney@scribus.info
  ***************************************************************************/
 
 /***************************************************************************
@@ -57,7 +57,7 @@ class SCRIBUS_API MenuManager : public QObject
 		void setText(const QString &menuName, const QString &menuText);
 
 		QMenu *getLocalPopupMenu(const QString &menuName);
-		bool addMenuStringToMenuBar(const QString &menuName, bool rememberMenu = false);
+		bool addMenuStringToMenuBar(const QString& menuName, bool rememberMenu = false);
 		bool addMenuStringToMenuBarBefore(const QString &, const QString &beforeMenuName);
 		void clear();
 		bool clearMenu(const QString &menuName);
@@ -67,6 +67,9 @@ class SCRIBUS_API MenuManager : public QObject
 		void addMenuItemStringAfter(const QString &s, const QString &after, const QString &parent);
 		void addMenuItemStringsToMenu(const QString &menuName, QMenu *menuToAddTo, const QMap<QString, QPointer<ScrAction> > &menuActions);
 		void addMenuItemStringsToRememberedMenu(const QString &menuName, const QMap<QString, QPointer<ScrAction> > &menuActions);
+		void hideRemberedMenu(const QString& menuName);
+		void showRemberedMenu(const QString& menuName);
+
 		void addMenuItemStringsToMenuBar(const QString &menuName, const QMap<QString, QPointer<ScrAction> > &menuActions);
 		void clearMenuStrings(const QString &menuName);
 		void dumpMenuStrings();
