@@ -27,20 +27,52 @@ using ObjAttrVector = QList<ObjectAttribute>;
 
 enum TOCPageLocation { Beginning, End, NotShown };
 
+
+struct ToCSetupEntryStyleData
+{
+	QString styleToFind; //Style we'll search for
+	QString styleForText; //Style we'll set on the TOC entry
+	// QString styleForNumber; //Character style for page numbers
+	bool removeLineBreaks; //Remove line breaks if they are in the text of the TOC entry
+	TOCPageLocation pageLocation; //Place the page number for the TOC at the beginning, end or not at all
+};
+
 struct ToCSetup
 {
 	QString name; //Name of ToC
-	QString itemAttrName; //Attribute to Scan for
+	QString tocSource;
+	QString itemAttrName; //If the ToC is based on attributes, this is the attribute to scan for
 	QString frameName; //Destination frame
 	TOCPageLocation pageLocation; //Place the page number for the TOC at the beginning, end or not at all
 	bool listNonPrintingFrames; //List non printing frames in the TOC
 	QString textStyle; //Paragraph style for text
-	//QString leaderParaStyle; //Paragraph style for leaders
-	//QString pageNumberParaStyle; //Paragraph style for page numbers
+	QStringList styleListToFind; //If the ToC is based on styles, this is the list of styles we'll search for
+	QStringList styleListForTOC; //If the ToC is based on styles, this is the list of styles we'll set on the TOC entries
+	QList<ToCSetupEntryStyleData> entryData;
 };
 
 using ToCSetupVector = QList<ToCSetup>;
 
+struct IndexSetup
+{
+	QString name; //Name of Index
+	QString frameName; //Destination frame
+	bool listNonPrintingFrames{false}; //List non printing frames in the index
+	bool combineIdenticalEntries{true};
+	bool combinePageNumbers{true};
+	bool caseSensitiveCombination{false};
+	bool autoCapitalizeEntries{true};
+	bool addAlphaSeparators{false};
+	QString headingStyle;
+	QString separatorStyle;
+	QString level1Style;
+	QString level2Style;
+	QString level3Style;
+
+};
+
+using IndexSetupVector = QList<IndexSetup>;
+
 struct DocumentSection
 {
 	uint number; //Just an index in the section list
