@@ -33,7 +33,6 @@ CWDialog::CWDialog(QWidget* parent, ScribusDoc* doc, const char* name, bool moda
 	setModal(modal);
 	ScColor color;
 	QString colorName;
-	connectSlots(false);
 	// setup combobox
 	typeCombo->addItem(colorWheel->getTypeDescription(colorWheel->Monochromatic), colorWheel->Monochromatic);
 	typeCombo->addItem(colorWheel->getTypeDescription(colorWheel->Analogous), colorWheel->Analogous);
@@ -93,28 +92,42 @@ CWDialog::CWDialog(QWidget* parent, ScribusDoc* doc, const char* name, bool moda
 	resize(QSize(prefs->getInt("cw_width", 640),
 		   prefs->getInt("cw_height", 480)).expandedTo(minimumSizeHint()));
 	previewLabel->resize(prefs->getInt("cw_samplex", 300), prefs->getInt("cw_sampley", 100));
+
+	for (int i = 0; i < currentColorTable->rowCount(); i++)
+	{
+		for (int j = 0; j < currentColorTable->columnCount(); j++)
+		{
+			auto item = new QTableWidgetItem();
+			item->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
+			currentColorTable->setItem(i, j, item);
+		}
+	}
 		
 	// setup
 	colorspaceTab_currentChanged(colorspaceTab->currentIndex());
 
 	// signals and slots that cannot be in ui file
-	connect(colorWheel, SIGNAL(clicked(int, const QPoint&)),
-			this, SLOT(colorWheel_clicked(int, const QPoint&)));
-	connect(documentColorList, SIGNAL(currentTextChanged(const QString &)),
-			this, SLOT(documentColorList_currentChanged(const QString &)));
-	connect(colorList, SIGNAL(currentTextChanged(const QString &)),
-			this, SLOT(colorList_currentChanged(const QString &)));
-	connect(angleSpin, SIGNAL(valueChanged(int)),
-			this, SLOT(angleSpin_valueChanged(int)));
-	connect(colorspaceTab, SIGNAL(currentChanged(int)),
-			this, SLOT(colorspaceTab_currentChanged(int)));
+	connect(colorWheel, SIGNAL(clicked(int,QPoint)),this, SLOT(colorWheel_clicked(int,QPoint)));
+	connect(documentColorList, SIGNAL(currentTextChanged(QString)), this, SLOT(documentColorList_currentChanged(QString)));
+	connect(colorList, SIGNAL(currentTextChanged(QString)), this, SLOT(colorList_currentChanged(QString)));
+	connect(angleSpin, SIGNAL(valueChanged(int)), this, SLOT(angleSpin_valueChanged(int)));
+	connect(colorspaceTab, SIGNAL(currentChanged(int)), this, SLOT(colorspaceTab_currentChanged(int)));
 	connect(typeCombo, SIGNAL(activated(int)), this, SLOT(typeCombo_activated(int)));
 	connect(defectCombo, SIGNAL(activated(int)), this, SLOT(defectCombo_activated(int)));
 	connect(addButton, SIGNAL(clicked()), this, SLOT(addButton_clicked()));
 	connect(replaceButton, SIGNAL(clicked()), this, SLOT(replaceButton_clicked()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(cancelButton_clicked()));
 
-	connectSlots(true);
+	connect( cSpin, SIGNAL( valueChanged(int) ), this, SLOT( cSpin_valueChanged(int) ) );
+	connect( mSpin, SIGNAL( valueChanged(int) ), this, SLOT( mSpin_valueChanged(int) ) );
+	connect( ySpin, SIGNAL( valueChanged(int) ), this, SLOT( ySpin_valueChanged(int) ) );
+	connect( kSpin, SIGNAL( valueChanged(int) ), this, SLOT( kSpin_valueChanged(int) ) );
+	connect( rSpin, SIGNAL( valueChanged(int) ), this, SLOT( rSpin_valueChanged(int) ) );
+	connect( gSpin, SIGNAL( valueChanged(int) ), this, SLOT( gSpin_valueChanged(int) ) );
+	connect( bSpin, SIGNAL( valueChanged(int) ), this, SLOT( bSpin_valueChanged(int) ) );
+	connect( hSpin, SIGNAL( valueChanged(int) ), this, SLOT( hSpin_valueChanged(int) ) );
+	connect( sSpin, SIGNAL( valueChanged(int) ), this, SLOT( sSpin_valueChanged(int) ) );
+	connect( vSpin, SIGNAL( valueChanged(int) ), this, SLOT( vSpin_valueChanged(int) ) );
 }
 
 CWDialog::~CWDialog()
@@ -134,34 +147,18 @@ CWDialog::~CWDialog()
 	prefs->set("cw_sampley", previewLabel->height());
 }
 
-void CWDialog::connectSlots(bool conn)
+void CWDialog::blockSpinSignals(bool block)
 {
-	if (conn)
-	{
-		connect( cSpin, SIGNAL( valueChanged(int) ), this, SLOT( cSpin_valueChanged(int) ) );
-		connect( mSpin, SIGNAL( valueChanged(int) ), this, SLOT( mSpin_valueChanged(int) ) );
-		connect( ySpin, SIGNAL( valueChanged(int) ), this, SLOT( ySpin_valueChanged(int) ) );
-		connect( kSpin, SIGNAL( valueChanged(int) ), this, SLOT( kSpin_valueChanged(int) ) );
-		connect( rSpin, SIGNAL( valueChanged(int) ), this, SLOT( rSpin_valueChanged(int) ) );
-		connect( gSpin, SIGNAL( valueChanged(int) ), this, SLOT( gSpin_valueChanged(int) ) );
-		connect( bSpin, SIGNAL( valueChanged(int) ), this, SLOT( bSpin_valueChanged(int) ) );
-		connect( hSpin, SIGNAL( valueChanged(int) ), this, SLOT( hSpin_valueChanged(int) ) );
-		connect( sSpin, SIGNAL( valueChanged(int) ), this, SLOT( sSpin_valueChanged(int) ) );
-		connect( vSpin, SIGNAL( valueChanged(int) ), this, SLOT( vSpin_valueChanged(int) ) );
-	}
-	else
-	{
-		disconnect( cSpin, SIGNAL( valueChanged(int) ), this, SLOT( cSpin_valueChanged(int) ) );
-		disconnect( mSpin, SIGNAL( valueChanged(int) ), this, SLOT( mSpin_valueChanged(int) ) );
-		disconnect( ySpin, SIGNAL( valueChanged(int) ), this, SLOT( ySpin_valueChanged(int) ) );
-		disconnect( kSpin, SIGNAL( valueChanged(int) ), this, SLOT( kSpin_valueChanged(int) ) );
-		disconnect( rSpin, SIGNAL( valueChanged(int) ), this, SLOT( rSpin_valueChanged(int) ) );
-		disconnect( gSpin, SIGNAL( valueChanged(int) ), this, SLOT( gSpin_valueChanged(int) ) );
-		disconnect( bSpin, SIGNAL( valueChanged(int) ), this, SLOT( bSpin_valueChanged(int) ) );
-		disconnect( hSpin, SIGNAL( valueChanged(int) ), this, SLOT( hSpin_valueChanged(int) ) );
-		disconnect( sSpin, SIGNAL( valueChanged(int) ), this, SLOT( sSpin_valueChanged(int) ) );
-		disconnect( vSpin, SIGNAL( valueChanged(int) ), this, SLOT( vSpin_valueChanged(int) ) );
-	}
+	cSpin->blockSignals(block);
+	mSpin->blockSignals(block);
+	ySpin->blockSignals(block);
+	kSpin->blockSignals(block);
+	rSpin->blockSignals(block);
+	gSpin->blockSignals(block);
+	bSpin->blockSignals(block);
+	hSpin->blockSignals(block);
+	sSpin->blockSignals(block);
+	vSpin->blockSignals(block);
 }
 
 void CWDialog::documentColorList_currentChanged(const QString& itemText)
@@ -255,7 +252,8 @@ void CWDialog::setPreview()
 	int y = previewLabel->height();
 	QList<ScColor> cols = colorWheel->colorList.values();
 	int xstep = x / cols.count();
-	QPixmap pm = QPixmap(x, y);
+	QPixmap pm = QPixmap(x * devicePixelRatioF(), y * devicePixelRatioF());
+	pm.setDevicePixelRatio(devicePixelRatioF());
 	QPainter *p = new QPainter(&pm);
 	QFontMetrics fm = p->fontMetrics();
 
@@ -417,23 +415,23 @@ void CWDialog::setupRGBComponent(const ScColor& col)
 {
 	RGBColor rgb;
 	ScColorEngine::getRGBValues(col, m_Doc, rgb);
-	connectSlots(false);
+	blockSpinSignals(true);
 	rSpin->setValue(rgb.r);
 	gSpin->setValue(rgb.g);
 	bSpin->setValue(rgb.b);
-	connectSlots(true);
+	blockSpinSignals(false);
 }
 
 void CWDialog::setupCMYKComponent(const ScColor& col)
 {
 	CMYKColorF cmyk;
 	ScColorEngine::getCMYKValues(col, m_Doc, cmyk);
-	connectSlots(false);
+	blockSpinSignals(true);
 	cSpin->setValue(qRound(cmyk.c * 100.0));
 	mSpin->setValue(qRound(cmyk.m * 100.0));
 	ySpin->setValue(qRound(cmyk.y * 100.0));
 	kSpin->setValue(qRound(cmyk.k * 100.0));
-	connectSlots(true);
+	blockSpinSignals(false);
 }
 
 void CWDialog::setupHSVComponent(const ScColor& col)
@@ -441,11 +439,11 @@ void CWDialog::setupHSVComponent(const ScColor& col)
 	int h, s, v;
 	QColor qc(ScColorEngine::getRGBColor(col, m_Doc));
 	qc.getHsv(&h, &s, &v);
-	connectSlots(false);
+	blockSpinSignals(true);
 	hSpin->setValue(h);
 	sSpin->setValue(s);
 	vSpin->setValue(v);
-	connectSlots(true);
+	blockSpinSignals(false);
 }
 
 void CWDialog::setupColorComponents()
@@ -514,49 +512,46 @@ void CWDialog::colorList_currentChanged(const QString& itemText)
 	// if it's base color we do not need to recompute it again
 	if (itemText == colorWheel->trBaseColor)
 	{
-		currentColorTable->setItem(0, 4, new QTableWidgetItem(cmykLabel->text()));
-		currentColorTable->setItem(1, 4, new QTableWidgetItem(rgbLabel->text()));
-		currentColorTable->setItem(2, 4, new QTableWidgetItem(hsvLabel->text()));
-		currentColorTable->setItem(0, 0, new QTableWidgetItem(cSpin->text()));
-		currentColorTable->setItem(0, 1, new QTableWidgetItem(mSpin->text()));
-		currentColorTable->setItem(0, 2, new QTableWidgetItem(ySpin->text()));
-		currentColorTable->setItem(0, 3, new QTableWidgetItem(kSpin->text()));
-		currentColorTable->setItem(1, 0, new QTableWidgetItem(rSpin->text()));
-		currentColorTable->setItem(1, 1, new QTableWidgetItem(gSpin->text()));
-		currentColorTable->setItem(1, 2, new QTableWidgetItem(bSpin->text()));
-		currentColorTable->setItem(2, 0, new QTableWidgetItem(hSpin->text()));
-		currentColorTable->setItem(2, 1, new QTableWidgetItem(sSpin->text()));
-		currentColorTable->setItem(2, 2, new QTableWidgetItem(vSpin->text()));
+		currentColorTable->item(0, 4)->setText(cmykLabel->text());
+		currentColorTable->item(1, 4)->setText(rgbLabel->text());
+		currentColorTable->item(2, 4)->setText(hsvLabel->text());
+		currentColorTable->item(0, 0)->setText(cSpin->text());
+		currentColorTable->item(0, 1)->setText(mSpin->text());
+		currentColorTable->item(0, 2)->setText(ySpin->text());
+		currentColorTable->item(0, 3)->setText(kSpin->text());
+		currentColorTable->item(1, 0)->setText(rSpin->text());
+		currentColorTable->item(1, 1)->setText(gSpin->text());
+		currentColorTable->item(1, 2)->setText(bSpin->text());
+		currentColorTable->item(2, 0)->setText(hSpin->text());
+		currentColorTable->item(2, 1)->setText(sSpin->text());
+		currentColorTable->item(2, 2)->setText(vSpin->text());
 	}
 	else
 	{
 		ScColor col(colorWheel->colorList[itemText]);
-		currentColorTable->setItem(0, 4, new QTableWidgetItem(col.nameCMYK(m_Doc)));
-		currentColorTable->setItem(1, 4, new QTableWidgetItem(col.nameRGB(m_Doc)));
-		currentColorTable->setItem(2, 4, new QTableWidgetItem(getHexHsv(col)));
+		currentColorTable->item(0, 4)->setText(col.nameCMYK(m_Doc));
+		currentColorTable->item(1, 4)->setText(col.nameRGB(m_Doc));
+		currentColorTable->item(2, 4)->setText(getHexHsv(col));
 		// components
 		QString num;
 		CMYKColor cmyk;
 		ScColorEngine::getCMYKValues(col, m_Doc, cmyk);
-		currentColorTable->setItem(0, 0, new QTableWidgetItem(num.setNum(cmyk.c)));
-		currentColorTable->setItem(0, 1, new QTableWidgetItem(num.setNum(cmyk.m)));
-		currentColorTable->setItem(0, 2, new QTableWidgetItem(num.setNum(cmyk.y)));
-		currentColorTable->setItem(0, 3, new QTableWidgetItem(num.setNum(cmyk.k)));
+		currentColorTable->item(0, 0)->setText(num.setNum(cmyk.c));
+		currentColorTable->item(0, 1)->setText(num.setNum(cmyk.m));
+		currentColorTable->item(0, 2)->setText(num.setNum(cmyk.y));
+		currentColorTable->item(0, 3)->setText(num.setNum(cmyk.k));
 		RGBColor rgb;
 		ScColorEngine::getRGBValues(col, m_Doc, rgb);
-		currentColorTable->setItem(1, 0, new QTableWidgetItem(num.setNum(rgb.r)));
-		currentColorTable->setItem(1, 1, new QTableWidgetItem(num.setNum(rgb.g)));
-		currentColorTable->setItem(1, 2, new QTableWidgetItem(num.setNum(rgb.b)));
+		currentColorTable->item(1, 0)->setText(num.setNum(rgb.r));
+		currentColorTable->item(1, 1)->setText(num.setNum(rgb.g));
+		currentColorTable->item(1, 2)->setText(num.setNum(rgb.b));
 		int h, s, v;
 		QColor hsvCol(ScColorEngine::getRGBColor(col, m_Doc));
 		hsvCol.getHsv(&h, &s, &v);
-		currentColorTable->setItem(2, 0, new QTableWidgetItem(num.setNum(h)));
-		currentColorTable->setItem(2, 1, new QTableWidgetItem(num.setNum(s)));
-		currentColorTable->setItem(2, 2, new QTableWidgetItem(num.setNum(v)));
+		currentColorTable->item(2, 0)->setText(num.setNum(h));
+		currentColorTable->item(2, 1)->setText(num.setNum(s));
+		currentColorTable->item(2, 2)->setText(num.setNum(v));
 	}
-	int columnWidth = currentColorTable->fontMetrics().maxWidth() * 4;
-	for (int i = 0; i < 4 ; ++i)
-		currentColorTable->setColumnWidth(i, columnWidth);
 }
 
 QString CWDialog::getHexHsv(const ScColor& c)
