@@ -34,7 +34,6 @@ for which a new license (GPL+exception) is in place.
 #include "svgexplugin.h"
 
 #include "scconfig.h"
-#include "canvas.h"
 #include "cmsettings.h"
 #include "commonstrings.h"
 #include "pageitem_table.h"
@@ -44,19 +43,17 @@ for which a new license (GPL+exception) is in place.
 #include "qtiocompressor.h"
 #include "scpage.h"
 #include "scpattern.h"
-#include "scribuscore.h"
+#include "scribus.h"
 #include "sctextstruct.h"
 #include "tableutils.h"
 #include "util.h"
 #include "ui/customfdialog.h"
-#include "ui/guidemanager.h"
 #include "ui/scmessagebox.h"
 #include "sccolorengine.h"
 #include "util_formats.h"
 #include "util_math.h"
 #include "text/textlayout.h"
 #include "text/textlayoutpainter.h"
-#include "text/boxes.h"
 
 int svgexplugin_getPluginAPIVersion()
 {
@@ -170,8 +167,7 @@ bool SVGExportPlugin::run(ScribusDoc* doc, const QString& filename)
 		if (fileName.isEmpty())
 			return true;
 		prefs->set("wdir", fileName.left(fileName.lastIndexOf("/")));
-		QFile f(fileName);
-		if (f.exists())
+		if (QFile::exists(fileName))
 		{
 			int exit = ScMessageBox::warning(doc->scMW(), CommonStrings::trWarning,
 				QObject::tr("Do you really want to overwrite the file:\n%1 ?").arg(fileName),
@@ -1077,13 +1073,13 @@ QDomElement SVGExPlug::processImageItem(PageItem *item, const QString& trans, co
 		}
 		else
 		{
-			QFileInfo fi = QFileInfo(item->Pfile);
+			QFileInfo fi(item->Pfile);
 			QString imgFileName = m_baseDir + "/" + fi.baseName() + ".png";
-			QFileInfo im = QFileInfo(imgFileName);
+			QFileInfo im(imgFileName);
 			if (im.exists())
 				imgFileName = m_baseDir + "/" + fi.baseName() + "_copy.png";
 			img.qImage().save(imgFileName, "PNG");
-			QFileInfo fi2 = QFileInfo(imgFileName);
+			QFileInfo fi2(imgFileName);
 			ob3.setAttribute("xlink:href", fi2.baseName() + ".png");
 		}
 		ob3.setAttribute("x", FToStr(item->imageXOffset() * item->imageXScale()));
@@ -1488,7 +1484,7 @@ QDomElement SVGExPlug::processInlineItem(PageItem* embItem, const QString& trans
 
 QString SVGExPlug::handleGlyph(uint gid, const ScFace& font)
 {
-	QString glName = QString("Gl%1%2").arg(font.psName().simplified().replace(QRegExp("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%]"), "_" )).arg(gid);
+	QString glName = QString("Gl%1%2").arg(font.psName().simplified().replace(QRegularExpression("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%]"), "_" )).arg(gid);
 	if (m_glyphNames.contains(glName))
 		return glName;
 	FPointArray pts = font.glyphOutline(gid);
