@@ -932,10 +932,9 @@ void CgmPlug::decodeClass2(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	}
 	else if (elemID == 6)
 	{
-		QPointF max, min;
-		max = getBinaryCoords(ts, true);
-		min = getBinaryCoords(ts, true);
-		QRectF vd = QRectF(max, min);
+		QPointF max = getBinaryCoords(ts, true);
+		QPointF min = getBinaryCoords(ts, true);
+		QRectF vd(max, min);
 		vcdFlippedV = (vd.height() > 0);
 		vcdFlippedH = (vd.width() < 0);
 		vd = vd.normalized();
@@ -1066,10 +1065,9 @@ void CgmPlug::decodeClass3(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	}
 	else if (elemID == 5)
 	{
-		QPointF max, min;
-		max = getBinaryCoords(ts);
-		min = getBinaryCoords(ts);
-		QRectF vd = QRectF(max, min);
+		QPointF max = getBinaryCoords(ts);
+		QPointF min = getBinaryCoords(ts);
+		QRectF vd(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1411,8 +1409,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		}
 		ts >> mode;
 		int bytesRead = ts.device()->pos() - pos;
-		QLineF pr = QLineF(p, r);
-		QLineF rq = QLineF(r, q);
+		QLineF pr(p, r);
+		QLineF rq(r, q);
 		double originX = p.x();
 		double originY = p.y();
 		bool flipX = false;
@@ -1543,22 +1541,23 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 					istr.skipRawData(1);
 			}
 		}
-		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
-		tempFile->setAutoRemove(false);
-		tempFile->open();
-		QString fileName = getLongPathName(tempFile->fileName());
-		tempFile->close();
-		ite->isInlineImage = true;
-		ite->isTempFile = true;
-		image.save(fileName, "PNG");
-		if ((image.width() < 20) || image.height() < 20)
-			ite->pixm.imgInfo.lowResType = 0;
-		m_Doc->loadPict(fileName, ite);
-		delete tempFile;
-		ite->setImageFlippedH(flipX);
-		ite->setImageFlippedV(flipY);
-		ite->setImageScalingMode(false, false);
-		ite->adjustPictScale();
+		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
+		if (tempFile.open())
+		{
+			QString fileName = getLongPathName(tempFile.fileName());
+			tempFile.setAutoRemove(false);
+			tempFile.close();
+			ite->isInlineImage = true;
+			ite->isTempFile = true;
+			image.save(fileName, "PNG");
+			if ((image.width() < 20) || image.height() < 20)
+				ite->pixm.imgInfo.lowResType = 0;
+			m_Doc->loadPict(fileName, ite);
+			ite->setImageFlippedH(flipX);
+			ite->setImageFlippedV(flipY);
+			ite->setImageScalingMode(false, false);
+			ite->adjustPictScale();
+		}
 		colorPrecision = t_colorPrecision;
 		colorIndexPrecision = t_colorIndexPrecision;
 	}
@@ -1568,10 +1567,9 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	}
 	else if (elemID == 11)
 	{
-		QPointF max, min;
-		max = getBinaryCoords(ts);
-		min = getBinaryCoords(ts);
-		QRectF vd = QRectF(max, min);
+		QPointF max = getBinaryCoords(ts);
+		QPointF min = getBinaryCoords(ts);
+		QRectF vd(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1614,17 +1612,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pStart = convertCoords(getBinaryCoords(ts));
 		QPointF pInter = convertCoords(getBinaryCoords(ts));
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
-		QLineF s_e = QLineF(pStart, pEnd);
+		QLineF s_e(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i = QLineF(pStart, pInter);
+		QLineF s_i(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1 = QLineF(center, pStart);
-			QLineF rad3 = QLineF(center, pInter);
+			QLineF rad1(center, pStart);
+			QLineF rad3(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1662,17 +1660,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
 		quint16 mode;
 		ts >> mode;
-		QLineF s_e = QLineF(pStart, pEnd);
+		QLineF s_e(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i = QLineF(pStart, pInter);
+		QLineF s_i(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1 = QLineF(center, pStart);
-			QLineF rad3 = QLineF(center, pInter);
+			QLineF rad1(center, pStart);
+			QLineF rad3(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1724,8 +1722,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1781,8 +1779,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1868,8 +1866,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX = QLineF(cx, cy, r1x, r1y);
-		QLineF dstY = QLineF(cx, cy, r2x, r2y);
+		QLineF dstX(cx, cy, r1x, r1y);
+		QLineF dstY(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -1887,8 +1885,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -1972,8 +1970,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX = QLineF(cx, cy, r1x, r1y);
-		QLineF dstY = QLineF(cx, cy, r2x, r2y);
+		QLineF dstX(cx, cy, r1x, r1y);
+		QLineF dstY(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -1992,8 +1990,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
-		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
+		QLineF stv(cx, cy, cx + sx, cy + sy);
+		QLineF env(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -2373,14 +2371,14 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		m_Doc->adjustItemSize(ite);
 		ite->OldB2 = ite->width();
 		ite->OldH2 = ite->height();
-		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
-		tempFile->setAutoRemove(false);
-		if (tempFile->open())
+		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
+		if (tempFile.open())
 		{
-			QString fileName = getLongPathName(tempFile->fileName());
+			QString fileName = getLongPathName(tempFile.fileName());
 			if (!fileName.isEmpty())
 			{
-				tempFile->close();
+				tempFile.setAutoRemove(false);
+				tempFile.close();
 				ite->isInlineImage = true;
 				ite->isTempFile = true;
 				tmpImg.save(fileName, "PNG");
@@ -2412,7 +2410,6 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			m_Doc->Items->removeAll(ite);
 			delete ite;
 		}
-		delete tempFile;
 		colorPrecision = t_colorPrecision;
 	//	qDebug() << "PATTERN TABLE" << "Index" << index << "NX" << nx << "NY" << ny;
 	}
@@ -2422,8 +2419,8 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		double phy = convertCoords(getBinaryDistance(ts));
 		double pwx = convertCoords(getBinaryDistance(ts));
 		double pwy = convertCoords(getBinaryDistance(ts));
-		QLineF hp = QLineF(0, 0, phx, phy);
-		QLineF wp = QLineF(0, 0, pwx, pwy);
+		QLineF hp(0, 0, phx, phy);
+		QLineF wp(0, 0, pwx, pwy);
 		patternScaleX = wp.length();
 		patternScaleY = hp.length();
 	//	qDebug() << "PATTERN SIZE" << wp.length() << hp.length();
@@ -3046,7 +3043,7 @@ double CgmPlug::getBinaryDistance(QDataStream &ts)
 
 QPointF CgmPlug::getBinaryCoords(QDataStream &ts, bool raw)
 {
-	QPointF ret = QPointF(0.0, 0.0);
+	QPointF ret(0.0, 0.0);
 	if (vdcType == 0)				// integer coords
 	{
 		int x = getBinaryInt(ts, vdcInt);
