@@ -12,7 +12,6 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -22,34 +21,18 @@ for which a new license (GPL+exception) is in place.
 #include <libfreehand/libfreehand.h>
 
 #include "commonstrings.h"
-#include "ui/customfdialog.h"
-#include "fileloader.h"
 #include "loadsaveplugin.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "ui/propertiespalette.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scpattern.h"
 #include "scribus.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
 #include "undomanager.h"
-#include "util.h"
-#include "util_formats.h"
-#include "util_math.h"
 
 FhPlug::FhPlug(ScribusDoc* doc, int flags)
 {
@@ -66,10 +49,9 @@ FhPlug::FhPlug(ScribusDoc* doc, int flags)
 
 QImage FhPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	double b, h;
-	b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
+	QFileInfo fi(fName);
+	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
+	double h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	docWidth = b;
 	docHeight = h;
 	progressDialog = nullptr;
@@ -127,15 +109,14 @@ bool FhPlug::import(const QString& fNameIn, const TransactionSettings& trSetting
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	if ( showProgress )
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -155,8 +136,8 @@ bool FhPlug::import(const QString& fNameIn, const TransactionSettings& trSetting
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
+	double b = 0.0;
+	double h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
@@ -324,8 +305,7 @@ bool FhPlug::convert(const QString& fn)
 	importedColors.clear();
 	importedPatterns.clear();
 
-	QFile file(fn);
-	if (!file.exists())
+	if (!QFile::exists(fn))
 	{
 		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
 		return false;
@@ -347,7 +327,7 @@ bool FhPlug::convert(const QString& fn)
 		{
 			ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-			QMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project https://www.documentliberation.org"), 1, 0, 0);
+			QMessageBox::warning(mw, CommonStrings::trWarning, tr("Parsing failed!\n\nPlease submit your file (if possible) to the\nDocument Liberation Project https://www.documentliberation.org"), QMessageBox::Ok, QMessageBox::NoButton);
 			qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
 		}
 		return false;
