@@ -260,13 +260,13 @@ private:
 	void applyParagraphStyle(ParagraphStyle &tmpStyle, ObjStyle &oStyle) const;
 	void parseTransform(const QString &transform, double *rotation, double *transX, double *transY) const;
 	void parseTransform(FPointArray *composite, const QString &transform) const;
-	void parseViewBox(const QDomElement& object, double *x, double *y, double *w, double *h) const;
+	void parseViewBox( const QDomElement& object, double *x, double *y, double *w, double *h ) const;
 	void appendPoints(FPointArray *composite, const QDomElement& object, bool closePath);
 	void parseStyles(QDomElement &sp);
 	QString getStyleName(QDomElement &e) const;
 	void resovleStyle(ObjStyle &tmpOStyle, const QString& pAttrs);
 	double parseUnit(const QString &unit) const;
-	const char * getCoord( const char *ptr, double &number ) const;
+	const char * getCoord(const char *ptr, double &number) const;
 	bool parseEnhPath(const QString& svgPath, FPointArray &result, bool &fill, bool &stroke);
 	double angleFromPoint(const QPointF &point) const;
 	double radSweepAngle(double start, double stop, bool clockwise) const;
@@ -313,6 +313,9 @@ private:
 	QHash<QString, QPainterPath> pathResources;
 	std::unique_ptr<ScZipHandler> uz;
 
+	QString m_currentOdgFilePath;
+	QString m_currentOdgFileDir;
+
 public slots:
 	void cancelRequested() { cancel = true; }
 };
