@@ -420,13 +420,11 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 
 	if (compressed)
 	{
-		QTemporaryFile *tmpFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
-		if (tmpFile == nullptr)
-			return false;
-		tmpFile->open();
-		QString fname = getLongPathName(tmpFile->fileName());
-		tmpFile->write(f);
-		tmpFile->close();
+		QTemporaryFile tmpFile(QDir::tempPath() + "/scribus_temp_zip_XXXXXX.dat");
+		tmpFile.open();
+		QString fname = getLongPathName(tmpFile.fileName());
+		tmpFile.write(f);
+		tmpFile.close();
 		QFile file(fname);
 		QtIOCompressor compressor(&file);
 		compressor.setStreamFormat(QtIOCompressor::GzipFormat);
@@ -434,11 +432,7 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 		f = compressor.readAll();
 		compressor.close();
 		if (f.isEmpty())
-		{
-			delete tmpFile;
 			return false;
-		}
-		delete tmpFile;
 	}
 
 #if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
@@ -1435,15 +1429,15 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 				if (uz->read(obState.imagePath, f))
 				{
 					QFileInfo fi(obState.imagePath);
-					QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pages_XXXXXX." + fi.suffix());
-					tempFile->setAutoRemove(false);
-					if (tempFile->open())
+					QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pages_XXXXXX." + fi.suffix());
+					if (tempFile.open())
 					{
-						QString fileName = getLongPathName(tempFile->fileName());
+						QString fileName = getLongPathName(tempFile.fileName());
 						if (!fileName.isEmpty())
 						{
-							tempFile->write(f);
-							tempFile->close();
+							tempFile.setAutoRemove(false);
+							tempFile.write(f);
+							tempFile.close();
 							retObj->isInlineImage = true;
 							retObj->isTempFile = true;
 							retObj->AspectRatio = false;
@@ -1452,7 +1446,6 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 							retObj->adjustPictScale();
 						}
 					}
-					delete tempFile;
 				}
 			}
 		}
@@ -1471,7 +1464,7 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 			QRectF br = po.boundingRect();
 			po.translate(-br.x(), -br.y());
 			po.translate(obState.xPos, obState.yPos);
-			if (itemText.length() > 0)
+			if (itemText.isNotEmpty())
 				z = m_Doc->itemAdd(PageItem::TextFrame, PageItem::Rectangle, baseX + po[0].x(), baseY + po[0].y(), obState.width, obState.height, obState.LineW, obState.CurrColorFill, obState.CurrColorStroke);
 			else if (obState.currentPathClosed)
 				z = m_Doc->itemAdd(PageItem::PolyLine, PageItem::Unspecified, baseX + po[0].x(), baseY + po[0].y(), obState.width, obState.height, obState.LineW, obState.CurrColorFill, obState.CurrColorStroke);
@@ -1489,7 +1482,7 @@ PageItem* PagesPlug::parseObjReference(QDomElement &draw)
 			else
 				retObj->SetRectFrame();
 			retObj->setRotation(-obState.rotation, true);
-			if (itemText.length() > 0)
+			if (itemText.isNotEmpty())
 			{
 				retObj->itemText.append(itemText);
 				retObj->itemText.trim();
