@@ -12,7 +12,7 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStack>
 #include <QDebug>
 
@@ -34,7 +34,6 @@ for which a new license (GPL+exception) is in place.
 #include "prefstable.h"
 #include "ui/propertiespalette.h"
 #include "rawimage.h"
-#include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
@@ -49,7 +48,7 @@ for which a new license (GPL+exception) is in place.
 #include "undomanager.h"
 #include "util.h"
 #include "util_formats.h"
-#include "util_math.h"
+
 
 extern SCRIBUS_API ScribusQApp * ScQApp;
 
@@ -66,12 +65,11 @@ QxpPlug::QxpPlug(ScribusDoc* doc, int flags)
 	cancel = false;
 }
 
-QImage QxpPlug::readThumbnail(QString fName)
+QImage QxpPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	double b, h;
-	b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
-	h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
+	QFileInfo fi(fName);
+	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
+	double h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	docWidth = b;
 	docHeight = h;
 	progressDialog = nullptr;
@@ -126,22 +124,20 @@ QImage QxpPlug::readThumbnail(QString fName)
 	return QImage();
 }
 
-bool QxpPlug::import(QString fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool QxpPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
-	QString fName = fNameIn;
 	bool success = false;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
-	QFileInfo fi = QFileInfo(fName);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	if ( showProgress )
+	if (showProgress)
 	{
 		ScribusMainWindow* mw=(m_Doc==0) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -161,8 +157,8 @@ bool QxpPlug::import(QString fNameIn, const TransactionSettings& trSettings, int
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
+	double b = 0.0;
+	double h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
@@ -221,7 +217,7 @@ bool QxpPlug::import(QString fNameIn, const TransactionSettings& trSettings, int
 	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
-	if (convert(fName))
+	if (convert(fNameIn))
 	{
 		tmpSel->clear();
 		QDir::setCurrent(CurDirP);
@@ -326,13 +322,12 @@ QxpPlug::~QxpPlug()
 	delete tmpSel;
 }
 
-bool QxpPlug::convert(QString fn)
+bool QxpPlug::convert(const QString& fn)
 {
 	importedColors.clear();
 	importedPatterns.clear();
 
-	QFile file(fn);
-	if (!file.exists())
+	if (!QFile::exists(fn))
 	{
 		qDebug() << "File " << QFile::encodeName(fn).data() << " does not exist";
 		return false;
