@@ -15,6 +15,7 @@ for which a new license (GPL+exception) is in place.
 #include <QPainterPath>
 #include <QStack>
 #include <QTemporaryFile>
+#include <QUrl>
 
 #include "svgplugin.h"
 
@@ -31,19 +32,16 @@ for which a new license (GPL+exception) is in place.
 #include "scconfig.h"
 #include "sclimits.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scpattern.h"
 #include "scraction.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
-#include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "ui/customfdialog.h"
 #include "ui/propertiespalette.h"
 #include "ui/scmessagebox.h"
-#include "ui/scmwmenumanager.h"
 #include "undomanager.h"
 #include "util.h"
 #include "util_formats.h"
@@ -80,14 +78,7 @@ SVGImportPlugin::SVGImportPlugin() :
 	registerFormats();
 	languageChange();
 }
-/*
-void SVGImportPlugin::addToMainWindowMenu(ScribusMainWindow *mw)
-{
-	importAction->setEnabled(true);
-	connect(importAction, SIGNAL(triggered()), SLOT(import()));
-	mw->scrMenuMgr->addMenuItem(importAction, "FileImport");
-}
-*/
+
 SVGImportPlugin::~SVGImportPlugin()
 {
 	unregisterAll();
@@ -218,8 +209,8 @@ QImage SVGImportPlugin::readThumbnail(const QString& fileName)
 }
 
 SVGPlug::SVGPlug(ScribusDoc* doc, int flags)
-	   : m_Doc(doc),
-	     importerFlags(flags)
+	: m_Doc(doc),
+	  importerFlags(flags)
 {
 	tmpSel = new Selection(this, false);
 
@@ -228,7 +219,7 @@ SVGPlug::SVGPlug(ScribusDoc* doc, int flags)
 	importedPatterns.clear();
 
 	interactive = (flags & LoadSavePlugin::lfInteractive);
-//	m_gc.setAutoDelete(true);
+	//	m_gc.setAutoDelete(true);
 }
 
 SVGPlug::~SVGPlug()
@@ -265,7 +256,8 @@ QImage SVGPlug::readThumbnail(const QString& fName)
 	if (!docElem.attribute("viewBox").isEmpty())
 	{
 		QString viewbox(docElem.attribute("viewBox"));
-		QStringList points = viewbox.replace(QRegularExpression(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
+		static QRegularExpression re(",");
+		QStringList points = viewbox.replace(re, " ").simplified().split(' ', Qt::SkipEmptyParts);
 		if (points.size() > 3)
 		{
 			QTransform matrix;
@@ -314,16 +306,24 @@ QImage SVGPlug::readThumbnail(const QString& fName)
 
 bool SVGPlug::import(const QString& fname, const TransactionSettings& trSettings, int flags)
 {
+	m_currentSvgFilePath.clear();
+	m_currentSvgFileDir.clear();
+
 	if (!loadData(fname))
 	{
 		importFailed = true;
 		return false;
 	}
+
+	QFileInfo fInfo(fname);
+	m_currentSvgFilePath = fInfo.absoluteFilePath();
+	m_currentSvgFileDir = fInfo.absolutePath();
+
 	QString CurDirP = QDir::currentPath();
-	QFileInfo efp(fname);
-	QDir::setCurrent(efp.path());
+	QDir::setCurrent(fInfo.path());
 	convert(trSettings, flags);
 	QDir::setCurrent(CurDirP);
+
 	return true;
 }
 
@@ -455,7 +455,8 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 	if (!docElem.attribute("viewBox").isEmpty())
 	{
 		QString viewbox(docElem.attribute("viewBox"));
-		QStringList points = viewbox.replace(QRegularExpression(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
+		static QRegularExpression re(",");
+		QStringList points = viewbox.replace(re, " ").simplified().split(' ', Qt::SkipEmptyParts);
 		if (points.size() > 3)
 		{
 			QTransform matrix;
@@ -646,62 +647,62 @@ PageItem *SVGPlug::finishNode(const QDomNode &e, PageItem* item)
 	double coeff2 = sqrt(gcm.m21() * gcm.m21() + gcm.m22() * gcm.m22());
 	switch (item->itemType())
 	{
-	case PageItem::ImageFrame:
-		{
-			item->ClipEdited = true;
-			item->FrameType = 3;
-			QTransform mm = gc->matrix;
-			item->PoLine.map(mm);
-			item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
-			FPoint wh = getMaxClipF(&item->PoLine);
-			item->setWidthHeight(wh.x(), wh.y());
-			m_Doc->adjustItemSize(item);
-			item->ContourLine = item->PoLine.copy();
-//			item->moveBy(mm.dx(), mm.dy());
-//			item->setWidthHeight(item->width() * mm.m11(), item->height() * mm.m22());
-//			item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
-			if (item->imageIsAvailable)
+		case PageItem::ImageFrame:
 			{
-				item->setImageXYOffset(0.0, 0.0);
-				item->setImageXYScale(item->width() / (item->pixm.width() * (item->pixm.imgInfo.xres / 72.0)),
-									  item->height() / (item->pixm.height() * (item->pixm.imgInfo.yres / 72.0)));
-				item->setImageScalingMode(false, false); // fit to frame
+				item->ClipEdited = true;
+				item->FrameType = 3;
+				QTransform mm = gc->matrix;
+				item->PoLine.map(mm);
+				item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
+				FPoint wh = getMaxClipF(&item->PoLine);
+				item->setWidthHeight(wh.x(), wh.y());
+				m_Doc->adjustItemSize(item);
+				item->ContourLine = item->PoLine.copy();
+				//			item->moveBy(mm.dx(), mm.dy());
+				//			item->setWidthHeight(item->width() * mm.m11(), item->height() * mm.m22());
+				//			item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
+				if (item->imageIsAvailable)
+				{
+					item->setImageXYOffset(0.0, 0.0);
+					item->setImageXYScale(item->width() / (item->pixm.width() * (item->pixm.imgInfo.xres / 72.0)),
+										  item->height() / (item->pixm.height() * (item->pixm.imgInfo.yres / 72.0)));
+					item->setImageScalingMode(false, false); // fit to frame
+				}
+				break;
+			}
+		case PageItem::TextFrame:
+			{
+				//QTransform mm = gc->matrix;
+				item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
+				item->itemText.trim();
 			}
 			break;
-		}
-	case PageItem::TextFrame:
-		{
-			//QTransform mm = gc->matrix;
-			item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
-			item->itemText.trim();
-		}
-		break;
-	default:
-		{
-			item->ClipEdited = true;
-			item->FrameType = 3;
-			QTransform mm = gc->matrix;
-			item->PoLine.map(mm);
-			/*if (haveViewBox)
+		default:
+			{
+				item->ClipEdited = true;
+				item->FrameType = 3;
+				QTransform mm = gc->matrix;
+				item->PoLine.map(mm);
+				/*if (haveViewBox)
 			{
 				QTransform mv;
 				mv.translate(viewTransformX, viewTransformY);
 				mv.scale(viewScaleX, viewScaleY);
 				ite->PoLine.map(mv);
 			}*/
-			item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
-			FPoint wh = getMaxClipF(&item->PoLine);
-			item->setWidthHeight(wh.x(), wh.y());
-//			if (item->asPolyLine())
-//				item->setPolyClip(qRound(qMax(item->lineWidth() / 2.0, 1)));
-//			else
-//				item->Clip = flattenPath(item->PoLine, item->Segments);
-			FPoint wx = getMinClipF(&item->PoLine);
-			inGroupXOrigin = qMin(inGroupXOrigin, wx.x());
-			inGroupYOrigin = qMin(inGroupYOrigin, wx.y());
-			m_Doc->adjustItemSize(item);
-			break;
-		}
+				item->setLineWidth(item->lineWidth() * (coeff1 + coeff2) / 2.0);
+				FPoint wh = getMaxClipF(&item->PoLine);
+				item->setWidthHeight(wh.x(), wh.y());
+				//			if (item->asPolyLine())
+				//				item->setPolyClip(qRound(qMax(item->lineWidth() / 2.0, 1)));
+				//			else
+				//				item->Clip = flattenPath(item->PoLine, item->Segments);
+				FPoint wx = getMinClipF(&item->PoLine);
+				inGroupXOrigin = qMin(inGroupXOrigin, wx.x());
+				inGroupYOrigin = qMin(inGroupYOrigin, wx.y());
+				m_Doc->adjustItemSize(item);
+				break;
+			}
 	}
 	item->setRedrawBounding();
 	item->OwnPage = m_Doc->OnPage(item);
@@ -751,7 +752,7 @@ PageItem *SVGPlug::finishNode(const QDomNode &e, PageItem* item)
 					item->GrEndX   = gc->GradFillX2 * item->width();
 					item->GrEndY   = gc->GradFillY2 * item->height();
 					item->GrFocalX = gc->GradFillFX * item->width();
-					item->GrFocalY = gc->GradFillFY * item->height(); 
+					item->GrFocalY = gc->GradFillFY * item->height();
 					double angle1 = atan2(gc->GradFillY2-gc->GradFillY1,gc->GradFillX2-gc->GradFillX1)*(180.0/M_PI);
 					double angle2 = atan2(item->GrEndY - item->GrStartX, item->GrEndX - item->GrStartX)*(180.0/M_PI);
 					double dx = item->GrStartX + (item->GrEndX - item->GrStartX) / 2.0;
@@ -996,7 +997,7 @@ FPoint SVGPlug::parseTextPosition(const QDomElement &e, const FPoint* pos)
 			QStringList xl(xatt.split(QChar(' '), Qt::SkipEmptyParts));
 			xatt = xl.first();
 		}
-		x = parseUnit(xatt); 
+		x = parseUnit(xatt);
 	}
 
 	if (e.hasAttribute("y"))
@@ -1020,7 +1021,7 @@ FPoint SVGPlug::parseTextPosition(const QDomElement &e, const FPoint* pos)
 			QStringList xl(dxatt.split(QChar(' '), Qt::SkipEmptyParts));
 			dxatt = xl.first();
 		}
-		x += parseUnit(dxatt); 
+		x += parseUnit(dxatt);
 	}
 
 	if (e.hasAttribute("dy"))
@@ -1032,7 +1033,7 @@ FPoint SVGPlug::parseTextPosition(const QDomElement &e, const FPoint* pos)
 			QStringList xl(dyatt.split(QChar(' '), Qt::SkipEmptyParts));
 			dyatt = xl.first();
 		}
-		y += parseUnit(dyatt); 
+		y += parseUnit(dyatt);
 	}
 
 	return FPoint(x, y);
@@ -1102,21 +1103,23 @@ void SVGPlug::parseDefs(const QDomElement &e)
 			continue;
 		SvgStyle svgStyle;
 		parseStyle(&svgStyle, b);
-		if (!svgStyle.Display) 
+		if (!svgStyle.Display)
 			continue;
 		QString STag2 = parseTagName(b);
 		if (STag2 == "g")
 			parseDefs(b);
-		else if (STag2 == "linearGradient" || STag2 == "radialGradient")
-			parseGradient(b);
 		else if (STag2 == "clipPath")
 			parseClipPath(b);
-		else if (STag2 == "pattern")
-			parsePattern(b);
-		else if (STag2 == "marker")
-			parseMarker(b);
 		else if (STag2 == "filter")
 			parseFilter(b);
+		else if (STag2 == "linearGradient" || STag2 == "radialGradient")
+			parseGradient(b);
+		else if (STag2 == "marker")
+			parseMarker(b);
+		else if (STag2 == "pattern")
+			parsePattern(b);
+		else if (STag2 == "style")
+			parseCSS(b);
 	}
 }
 
@@ -1196,23 +1199,22 @@ void SVGPlug::parseClipPathAttr(const QDomElement &e, FPointArray& clipPath) con
 
 void SVGPlug::parseFilterAttr(const QDomElement &e, PageItem* item) const
 {
+	if (!e.hasAttribute("filter"))
+		return;
 	QString filterName;
-	if (e.hasAttribute("filter"))
+	QString attr = e.attribute("filter");
+	if (attr.startsWith( "url("))
 	{
-		QString attr = e.attribute("filter");
-		if (attr.startsWith( "url("))
-		{
-			unsigned int start = attr.indexOf("#") + 1;
-			unsigned int end = attr.lastIndexOf(")");
-			filterName = attr.mid(start, end - start);
-			if (filterName.isEmpty())
-				return;
-		}
-		if (filters.contains(filterName))
-		{
-			filterSpec spec = filters[filterName];
-			item->setFillBlendmode(spec.blendMode);
-		}
+		unsigned int start = attr.indexOf("#") + 1;
+		unsigned int end = attr.lastIndexOf(")");
+		filterName = attr.mid(start, end - start);
+		if (filterName.isEmpty())
+			return;
+	}
+	if (filters.contains(filterName))
+	{
+		filterSpec spec = filters[filterName];
+		item->setFillBlendmode(spec.blendMode);
 	}
 }
 
@@ -1227,7 +1229,7 @@ QList<PageItem*> SVGPlug::parseA(const QDomElement &e)
 			continue;
 		SvgStyle svgStyle;
 		parseStyle(&svgStyle, b);
-		if (!svgStyle.Display) 
+		if (!svgStyle.Display)
 			continue;
 		QList<PageItem*> el = parseElement(b);
 		for (int ec = 0; ec < el.count(); ++ec)
@@ -1264,7 +1266,7 @@ QList<PageItem*> SVGPlug::parseGroup(const QDomElement &e)
 				continue;
 			SvgStyle svgStyle;
 			parseStyle(&svgStyle, b);
-			if (!svgStyle.Display) 
+			if (!svgStyle.Display)
 				continue;
 			QList<PageItem*> el = parseElement(b);
 			for (int ec = 0; ec < el.count(); ++ec)
@@ -1288,7 +1290,7 @@ QList<PageItem*> SVGPlug::parseGroup(const QDomElement &e)
 			continue;
 		SvgStyle svgStyle;
 		parseStyle(&svgStyle, b);
-		if (!svgStyle.Display) 
+		if (!svgStyle.Display)
 			continue;
 		QList<PageItem*> el = parseElement(b);
 		for (int ec = 0; ec < el.count(); ++ec)
@@ -1407,7 +1409,7 @@ QList<PageItem*> SVGPlug::parseDoc(const QDomElement &e)
 			continue;
 		SvgStyle svgStyle;
 		parseStyle(&svgStyle, b);
-		if (!svgStyle.Display) 
+		if (!svgStyle.Display)
 			continue;
 		QList<PageItem*> el = parseElement(b);
 		for (int ec = 0; ec < el.count(); ++ec)
@@ -1432,28 +1434,8 @@ QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 		parseDefs(e);
 	else if (STag == "a")
 		GElements = parseA(e);
-	else if (STag == "switch")
-		GElements = parseSwitch(e);
-	else if (STag == "symbol")
-		GElements = parseSymbol(e);
-	else if (STag == "use")
-		GElements = parseUse(e);
-	else if (STag == "linearGradient" || STag == "radialGradient")
-		parseGradient(e);
-	else if (STag == "rect")
-		GElements = parseRect(e);
-	else if (STag == "ellipse")
-		GElements = parseEllipse(e);
 	else if (STag == "circle")
 		GElements = parseCircle(e);
-	else if (STag == "line")
-		GElements = parseLine(e);
-	else if (STag == "path")
-		GElements = parsePath(e);
-	else if (STag == "polyline" || STag == "polygon")
-		GElements = parsePolyline(e);
-	else if (STag == "text")
-		GElements = parseText(e);
 	else if (STag == "clipPath")
 		parseClipPath(e);
 	else if (STag == "desc")
@@ -1461,13 +1443,35 @@ QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 		if (groupLevel == 1)
 			docDesc = e.text();
 	}
+	else if (STag == "ellipse")
+		GElements = parseEllipse(e);
+	else if (STag == "image")
+		GElements = parseImage(e);
+	else if (STag == "line")
+		GElements = parseLine(e);
+	else if (STag == "linearGradient" || STag == "radialGradient")
+		parseGradient(e);
+	else if (STag == "path")
+		GElements = parsePath(e);
+	else if (STag == "polyline" || STag == "polygon")
+		GElements = parsePolyline(e);
+	else if (STag == "rect")
+		GElements = parseRect(e);
+	else if (STag == "style")
+		parseCSS(e);
+	else if (STag == "switch")
+		GElements = parseSwitch(e);
+	else if (STag == "symbol")
+		GElements = parseSymbol(e);
+	else if (STag == "text")
+		GElements = parseText(e);
 	else if (STag == "title")
 	{
 		if (groupLevel == 1)
 			docTitle = e.text();
 	}
-	else if (STag == "image")
-		GElements = parseImage(e);
+	else if (STag == "use")
+		GElements = parseUse(e);
 /*	else if (STag == "i:pgf")
 	{
 		QByteArray cdat;
@@ -1538,9 +1542,6 @@ QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 		fclose(source);
 		fclose(dest);
 	} */
-/*	else if (STag == "image")
-		GElements = parseImage(e);
-	} */
 	else if (!isIgnorableNodeName(STag))
 	{
 		// warn if unsupported SVG feature are encountered
@@ -1618,9 +1619,29 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 	PageItem* ite = m_Doc->Items->at(z);
 	if (!hrefData.isEmpty())
 	{
-		//hrefData contains a filename
+		// hrefData contains a filename
 		if (!hrefData.startsWith("data:"))
-			m_Doc->loadPict(hrefData, ite);
+		{
+			// Be a bit careful about where we load from
+			QUrl fileUrl(hrefData);
+			if (fileUrl.isValid())
+			{
+				bool isLocalFile = fileUrl.isLocalFile();
+				QString host = fileUrl.host();
+				if (isLocalFile && host.isEmpty())
+				{
+					QString imageFilePath = fileUrl.toLocalFile();
+					m_Doc->loadPict(imageFilePath, ite);
+				}
+				else if (host.isEmpty())
+				{
+					QString imageFilePath(hrefData);
+					if (fileUrl.isRelative())
+						imageFilePath = m_currentSvgFileDir + "/" + fileUrl.path();
+					m_Doc->loadPict(imageFilePath, ite);
+				}
+			}
+		}
 		else
 		{
 			//hrefData is embedded
@@ -1631,18 +1652,19 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 			ba.append(hrefData.toLatin1());
 			if (dataType.contains("base64"))
 				ba = QByteArray::fromBase64(ba);
-			QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_svg_XXXXXX.png");
-			tempFile->setAutoRemove(false);
-			tempFile->open();
-			QString fileName = getLongPathName(tempFile->fileName());
-			tempFile->close();
-			delete tempFile;
-			ite->isTempFile = true;
-			ite->isInlineImage = true;
-			QImage img;
-			img.loadFromData(ba);
-			img.save(fileName, "PNG");
-			m_Doc->loadPict(fileName, ite);
+			QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_svg_XXXXXX.png");
+			if (tempFile.open())
+			{
+				QString fileName = getLongPathName(tempFile.fileName());
+				tempFile.setAutoRemove(false);
+				tempFile.close();
+				ite->isTempFile = true;
+				ite->isInlineImage = true;
+				QImage img;
+				img.loadFromData(ba);
+				img.save(fileName, "PNG");
+				m_Doc->loadPict(fileName, ite);
+			}
 		}
 	}
 	if (!clipPath.empty())
@@ -1692,10 +1714,9 @@ QVector<double> SVGPlug::parseNumbersList(const QString& numbersStr) const
 	while (str->isSpace())
 		++str;
 	while (ScCLocale::isDigit(str->unicode()) ||
-	       *str == QLatin1Char('-') || *str == QLatin1Char('+') ||
-	       *str == QLatin1Char('.'))
+		*str == QLatin1Char('-') || *str == QLatin1Char('+') ||
+		*str == QLatin1Char('.'))
 	{
-
 		numbers.append(ScCLocale::toDoubleC(str));
 
 		while (str->isSpace())
@@ -1719,7 +1740,7 @@ QList<PageItem*> SVGPlug::parsePath(const QDomElement &e)
 	double baseY = m_Doc->currentPage()->yOffset();
 	setupNode(e);
 	const SvgStyle *gc = m_gc.top();
-	PageItem::ItemType itype = pArray.parseSVG(e.attribute("d")) ? PageItem::PolyLine : PageItem::Polygon; 
+	PageItem::ItemType itype = pArray.parseSVG(e.attribute("d")) ? PageItem::PolyLine : PageItem::Polygon;
 	int z = m_Doc->itemAdd(itype, PageItem::Unspecified, baseX, baseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol);
 	PageItem* ite = m_Doc->Items->at(z);
 	ite->fillRule = (gc->fillRule != "nonzero");
@@ -1757,7 +1778,7 @@ QList<PageItem*> SVGPlug::parsePolyline(const QDomElement &e)
 		else
 			z = m_Doc->itemAdd(PageItem::PolyLine, PageItem::Unspecified, baseX, baseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol);
 		PageItem* ite = m_Doc->Items->at(z);
-		ite->fillRule = (gc->fillRule != "nonzero"); 
+		ite->fillRule = (gc->fillRule != "nonzero");
 		ite->PoLine.resize(0);
 		ite->PoLine.svgInit();
 		bool bFirst = true;
@@ -1978,7 +1999,7 @@ QList<PageItem*> SVGPlug::parseSwitch(const QDomElement &e)
 				}
 			}
 		}
-		else 
+		else
 		{
 			if (de.hasAttribute("requiredExtensions") || de.hasAttribute("requiredFeatures"))
 				continue;
@@ -2027,6 +2048,57 @@ QList<PageItem*> SVGPlug::parseUse(const QDomElement &e)
 	return UElements;
 }
 
+void SVGPlug::parseCSS(const QDomElement &e)
+{
+	// static QRegularExpression ruleRegex(R"(\.(\w+)\s*\{([^}]*)\})");
+	static QRegularExpression newlinesTabsRegex("[\\n\\t\\r]");
+	static QRegularExpression multipleSpacesRegex("\\s+");
+	static QRegularExpression ruleRegex(R"(([^\{]+)\s*\{\s*([^}]+?)\s*\})");
+	for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
+	{
+		QDomText t = n.toText();
+		if (t.isNull())
+			continue;
+
+		QString cssText = n.nodeValue();
+		QString normalizedCss = cssText.trimmed();
+
+		normalizedCss.replace(newlinesTabsRegex, " ");
+		normalizedCss.replace(multipleSpacesRegex, " ");
+		QRegularExpressionMatchIterator i = ruleRegex.globalMatch(normalizedCss);
+
+		while (i.hasNext())
+		{
+			QRegularExpressionMatch match = i.next();
+			QString className = match.captured(1).trimmed(); // e.g., "st0"
+			QStringList classNameList = className.split(",");
+			for (QString& clsName : classNameList)
+			{
+				QString clsName2 = clsName.trimmed();
+				if (clsName2.startsWith('.'))
+					clsName = clsName2.mid(1); // Remove the leading dot
+			}
+			QString properties = match.captured(2).trimmed(); // e.g., "fill:#EA5B0C;"
+			QStringList props = properties.split(';', Qt::SkipEmptyParts);
+			// Optional: further parse properties if needed
+			for (const QString& clsName : classNameList)
+			{
+				CSSStyle& cst = cssStyleList[clsName];
+				for (const QString& prop : props)
+				{
+					QStringList keyValue = prop.split(':', Qt::SkipEmptyParts);
+					if (keyValue.size() == 2)
+					{
+						QString key = keyValue[0].trimmed();
+						QString value = keyValue[1].trimmed();
+						parseCSSAttribute(cst, key, value);
+					}
+				}
+			}
+		}
+	}
+}
+
 QFont SVGPlug::getFontFromStyle(const SvgStyle& style) const
 {
 	QFont font(QApplication::font());
@@ -2187,11 +2259,8 @@ double SVGPlug::parseFontSize(const QString& fsize) const
 {
 	bool noUnit  = true;
 	QString unit = fsize.right(2);
-	if (unit == "pt" || unit == "cm" || unit == "mm" || 
-		unit == "in" || unit == "px")
-	{
+	if (unit == "pt" || unit == "cm" || unit == "mm" || unit == "in" || unit == "px")
 		noUnit = false;
-	}
 	double value = parseUnit(fsize);
 	if (noUnit)
 		value *= 0.8;
@@ -2357,21 +2426,25 @@ const char * SVGPlug::getCoord(const char *ptr, double &number) const
 
 QString SVGPlug::parseColor(const QString &s)
 {
+	QString str = s.trimmed();
+	if (str == "none")
+		return CommonStrings::None;
+
 	QColor c;
-	if (s.length() > 11) // icc-color()
+	if (str.length() > 11) // icc-color()
 	{
-		int iccColorIndex  = s.indexOf("icc-color");
+		int iccColorIndex  = str.indexOf("icc-color");
 		if (iccColorIndex >= 0)
 		{
-			QString iccColorName = parseIccColor(s);
+			QString iccColorName = parseIccColor(str);
 			if (iccColorName.length() > 0)
 				return iccColorName;
 		}
 	}
-	if (s.startsWith( "rgb(" ) )
+	
+	if (str.startsWith( "rgb(" ) )
 	{
-		QString parse = s.trimmed();
-		QStringList colors = parse.split(',', Qt::SkipEmptyParts);
+		QStringList colors = str.split(',', Qt::SkipEmptyParts);
 		QString r = colors[0].right(colors[0].length() - 4);
 		QString g = colors[1];
 		QString b = colors[2].left(colors[2].length() - 1);
@@ -2393,7 +2466,7 @@ QString SVGPlug::parseColor(const QString &s)
 		c = QColor(r.toInt(), g.toInt(), b.toInt());
 	}
 	else
-		c = QColor::fromString(s.trimmed());
+		c = QColor::fromString(str);
 
 	ScColor tmp;
 	tmp.fromQColor(c);
@@ -2803,11 +2876,66 @@ void SVGPlug::parsePA(SvgStyle *obj, const QString &command, const QString &para
 	}
 }
 
+void  SVGPlug::parseCSSAttribute(CSSStyle& style, const QString& command, const QString& params)
+{
+	if (command == "fill")
+	{
+		style.fillColor = parseColor(params);
+		return;
+	}
+	if (command == "stroke")
+	{
+		style.strokeColor = parseColor(params);
+		return;
+	}
+	if (command == "stroke-linecap")
+	{
+		if (params == "butt")
+			style.strokeLineCap = Qt::FlatCap;
+		else if (params == "round")
+			style.strokeLineCap = Qt::RoundCap;
+		else if (params == "square")
+			style.strokeLineCap = Qt::SquareCap;
+		return;
+	}
+	if (command == "stroke-linejoin")
+	{
+		if (params == "miter")
+			style.strokeLineJoin = Qt::MiterJoin;
+		else if (params == "round")
+			style.strokeLineJoin = Qt::RoundJoin;
+		else if (params == "bevel")
+			style.strokeLineJoin = Qt::BevelJoin;
+		return;
+	}
+	if (command == "stroke-width")
+	{
+		style.strokeWidth = parseUnit(params);
+		return;
+	}
+}
+
 void SVGPlug::parseStyle(SvgStyle *obj, const QDomElement &e)
 {
 	SvgStyle *gc = m_gc.top();
 	if (!gc)
 		return;
+
+	if (e.hasAttribute("class") && cssStyleList.contains(e.attribute("class")))
+	{
+		const CSSStyle& cssStyle = cssStyleList[e.attribute("class")];
+		if (!cssStyle.fillColor.isEmpty())
+			gc->FillCol = cssStyle.fillColor;
+		if (!cssStyle.strokeColor.isEmpty())
+			gc->StrokeCol = cssStyle.strokeColor;
+		if (cssStyle.strokeLineCap.has_value())
+			obj->PLineEnd = *cssStyle.strokeLineCap;
+		if (cssStyle.strokeLineJoin.has_value())
+			obj->PLineJoin = *cssStyle.strokeLineJoin;
+		if (cssStyle.strokeWidth.has_value())
+			obj->LWidth = *cssStyle.strokeWidth;
+	}
+
 	if (!e.attribute("display").isEmpty())
 		parsePA(obj, "display", e.attribute("display"));
 	if (!e.attribute("color").isEmpty())
