@@ -133,10 +133,16 @@ bool UniconvImportPlugin::import(const QString& fileName, int flags)
 
 	//Get a temporary filename ending in .svg (sadly
 	//uniconvertor has no other way of specifying the output format
-	QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_uniconv_XXXXXX.svg");
-	tempFile->open();
-	QString tempFileName = tempFile->fileName();
-	tempFile->close();
+	QString tempFileName;
+	QTemporaryFile tempFile(QDir::tempPath() + "/scribus_uniconv_XXXXXX.svg");
+	if (tempFile.open())
+	{
+		tempFileName = tempFile.fileName();
+		tempFile.close();
+	}
+
+	if (tempFileName.isEmpty())
+		return false;
 
 	//prepare arguments for uniconvertor call
 	QStringList arguments;
@@ -148,7 +154,8 @@ bool UniconvImportPlugin::import(const QString& fileName, int flags)
 	uniconv.start(PrefsManager::instance().uniconvExecutable(), arguments);
 
 	//handle errors
-	if (!uniconv.waitForStarted(120000)) {
+	if (!uniconv.waitForStarted(120000))
+	{
 		qWarning() << "Uniconvertor failed:" <<
 			PrefsManager::instance().uniconvExecutable() << arguments;
 		ScMessageBox::warning(mw, CommonStrings::trWarning,
@@ -156,32 +163,30 @@ bool UniconvImportPlugin::import(const QString& fileName, int flags)
 			"File->Preferences->External Tools may be incorrect or the "
 			"software has been uninstalled since preferences "
 			"were set. (%1)").arg(uniconv.errorString()));
-		delete tempFile;
 		return false;
 	}
-	if (!uniconv.waitForFinished(120000)) {
+	if (!uniconv.waitForFinished(120000))
+	{
 		qDebug() << "Uniconv exit code:" << uniconv.exitCode();
 		ScMessageBox::warning(mw, CommonStrings::trWarning,
 			tr("Uniconvertor did not exit correctly: %1").arg(uniconv.errorString(), QString(uniconv.readAll())));
-		delete tempFile;
 		return false;
 	}
-	if (uniconv.exitCode()) {
+	if (uniconv.exitCode())
+	{
 		qDebug() << "Uniconv exit code:" << uniconv.exitCode();
 		ScMessageBox::warning(mw, CommonStrings::trWarning,
 			tr("Uniconvertor failed to convert the file: %1").arg(QString(uniconv.readAll())));
-		delete tempFile;
 		return false;
 	}
 
 	//Import SVG
 	const FileFormat *fmt = LoadSavePlugin::getFormatByExt("svg");
-	if (!fmt) {
+	if (!fmt)
+	{
 		ScMessageBox::warning(mw, CommonStrings::trWarning, tr("The SVG Import plugin could not be found"));
-		delete tempFile;
 		return false;
 	}
 	fmt->loadFile(tempFileName, flags);
-	delete tempFile;
 	return true;
 }
