@@ -1196,7 +1196,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						QDomElement eo = spo.toElement();
 						if (eo.tagName() == "vo:point")
 						{
-							FPoint pp = FPoint(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
+							FPoint pp(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
 							if (eo.hasAttribute("vo:control"))
 							{
 								if ((eo.attribute("vo:control") == "constraint-before") || (eo.attribute("vo:control") == "before"))
@@ -1303,7 +1303,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						else if (spo.tagName() == "uni:applyElementOpacity")
 							shadowObjTrans = (spo.text() == "true");
 					}
-					QLineF oLine = QLineF(0, 0, shadowOffset, 0);
+					QLineF oLine(0, 0, shadowOffset, 0);
 					oLine.setAngle(shadowAngle - 180.0);
 					shadowX = oLine.p2().x();
 					shadowY = oLine.p2().y();
@@ -1535,7 +1535,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				QString gradColor1Str = colorStops[1]->name;
 				QColor gradColor1 = colorStops[1]->color;
 				item->meshGradientPatches.clear();
-				FPoint center = FPoint(item->width() / 2.0, item->height() / 2.0);
+				FPoint center(item->width() / 2.0, item->height() / 2.0);
 				MeshPoint cP;
 				cP.resetTo(center);
 				cP.transparency = 1.0;
@@ -1577,7 +1577,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				item->GrControl4 = FPoint(0, item->height());
 				if (gradientAngle != 0)
 				{
-					QLineF gradientVector = QLineF(item->width() / 2.0, item->height() / 2.0, 0, 0);
+					QLineF gradientVector(item->width() / 2.0, item->height() / 2.0, 0, 0);
 					gradientVector.setLength(gradientVector.length() + 1);
 					gradientVector.setAngle(gradientVector.angle() + gradientAngle);
 					QPointF g1 = intersectBoundingRect(item, gradientVector);
@@ -1649,15 +1649,15 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 			{
 				if (!imageData.isEmpty())
 				{
-					QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_viva_XXXXXX.png");
-					tempFile->setAutoRemove(false);
-					if (tempFile->open())
+					QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_viva_XXXXXX.png");
+					if (tempFile.open())
 					{
-						QString fileName = getLongPathName(tempFile->fileName());
+						QString fileName = getLongPathName(tempFile.fileName());
 						if (!fileName.isEmpty())
 						{
-							tempFile->write(imageData);
-							tempFile->close();
+							tempFile.setAutoRemove(false);
+							tempFile.write(imageData);
+							tempFile.close();
 							item->isInlineImage = true;
 							item->isTempFile = true;
 							item->AspectRatio = true;
@@ -1665,7 +1665,6 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 							m_Doc->loadPict(fileName, item);
 						}
 					}
-					delete tempFile;
 				}
 			}
 			item->setImageXYScale(imageScaleX / item->pixm.imgInfo.xres * 72, imageScaleX / item->pixm.imgInfo.xres * 72);
@@ -1676,7 +1675,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 			item->setTextToFrameDist(textMarginLeft, textMarginRight, textMarginTop, textMarginBottom);
 			item->setColumns(textColumnCount);
 			item->setColumnGap(textColumnGap);
-			if (itemText.length() > 0)
+			if (itemText.isNotEmpty())
 				item->itemText.append(itemText);
 			item->itemText.trim();
 		}
