@@ -10,33 +10,26 @@ for which a new license (GPL+exception) is in place.
 #include "scconfig.h"
 #include "wmfimport.h"
 
-#include <QCursor>
-#include <QDrag>
 #include <QBuffer>
+#include <QCursor>
 #include <QDataStream>
+#include <QDrag>
 #include <QFile>
+#include <QGuiApplication>
 #include <QMimeData>
 #include <QPainterPath>
-#include <QRegExp>
 
 #include "commonstrings.h"
 #include "fpointarray.h"
 #include "loadsaveplugin.h"
 #include "pageitem.h"
-#include "prefsfile.h"
-#include "prefsmanager.h"
 #include "scmimedata.h"
-#include "scraction.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
-#include "ui/propertiespalette.h"
-#include "ui/scmwmenumanager.h"
 #include "undomanager.h"
-#include "util.h"
 #include "util_math.h"
 
 #include "wmfstruct.h"
@@ -1375,7 +1368,7 @@ void WMFImport::createFontIndirect( QList<PageItem*>& /*items*/, long , const sh
 	// TODO: investigation why some test case need -2. (size of font in logical point)
 	int fontSize = (params[0] != 0) ? (qAbs(params[0]) - 2) : 12;
 	handle->font.setPixelSize( fontSize );
-	handle->font.setWeight( (params[ 4 ] >> 3) );
+	handle->font.setWeight( (QFont::Weight) ((params[ 4 ] >> 3)) );
 	handle->font.setItalic( (params[ 5 ] & 0x01) );
 	handle->font.setUnderline( (params[ 5 ] & 0x100) );
 	handle->font.setStrikeOut( (params[ 6 ] & 0x01) );
