@@ -11,7 +11,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -22,32 +21,19 @@ for which a new license (GPL+exception) is in place.
 
 #include "commonstrings.h"
 #include "loadsaveplugin.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
-#include "scpattern.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
 #include "third_party/wpg/WPGStreamImplementation.h"
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
 #include "util_math.h"
 
 ScrPainter::ScrPainter()
@@ -391,19 +377,20 @@ void ScrPainter::drawBitmap(const libwpg::WPGBitmap& bitmap, double hres, double
 	double h = (bitmap.rect.y2 - bitmap.rect.y1) * 72.0;
 	int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, bitmap.rect.x1 * 72 + baseX, bitmap.rect.y1 * 72 + baseY, w, h, 1, m_Doc->itemToolPrefs().imageFillColor, m_Doc->itemToolPrefs().imageStrokeColor);
 	PageItem *ite = m_Doc->Items->at(z);
-	QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_wpg_XXXXXX.png");
-	tempFile->setAutoRemove(false);
-	tempFile->open();
-	QString fileName = getLongPathName(tempFile->fileName());
-	tempFile->close();
-	delete tempFile;
-	ite->isTempFile = true;
-	ite->isInlineImage = true;
-	image.setDotsPerMeterX ((int) (hres / 0.0254));
-	image.setDotsPerMeterY ((int) (vres / 0.0254));
-	image.save(fileName, "PNG");
-	m_Doc->loadPict(fileName, ite);
-	ite->setImageScalingMode(false, false);
+	QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_wpg_XXXXXX.png");
+	if (tempFile.open())
+	{
+		QString fileName = getLongPathName(tempFile.fileName());
+		tempFile.setAutoRemove(false);
+		tempFile.close();
+		ite->isTempFile = true;
+		ite->isInlineImage = true;
+		image.setDotsPerMeterX((int) (hres / 0.0254));
+		image.setDotsPerMeterY((int) (vres / 0.0254));
+		image.save(fileName, "PNG");
+		m_Doc->loadPict(fileName, ite);
+		ite->setImageScalingMode(false, false);
+	}
 	ite->moveBy(m_Doc->currentPage()->xOffset(), m_Doc->currentPage()->yOffset());
 	finishItem(ite);
 //	qDebug() << "drawBitmap";
@@ -425,7 +412,7 @@ WpgPlug::WpgPlug(ScribusDoc* doc, int flags)
 
 QImage WpgPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
+	QFileInfo fi(fName);
 	double b = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 	double h = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 	docWidth = b;
@@ -485,15 +472,14 @@ bool WpgPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-	double b, h;
 	bool ret = false;
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	if ( showProgress )
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -513,8 +499,8 @@ bool WpgPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-	b = 0.0;
-	h = 0.0;
+	double b = 0.0;
+	double h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
