@@ -23,10 +23,10 @@ for which a new license (GPL+exception) is in place.
 #include <QDomElement>
 
 #include "commonstrings.h"
-#include "fpointarray.h"
 #include "pluginapi.h"
 #include "pageitem.h"
 #include "sccolor.h"
+#include "fpointarray.h"
 
 class MultiProgressDialog;
 class ScribusDoc;
@@ -90,7 +90,7 @@ private:
 		QPointF maskEnd;
 		QPointF maskFocus;
 		double maskScale { 1.0 };
-		int maskTyp { 0 };
+		int maskTyp{ 0 };
 		QString patternMask;
 		VGradient gradientStroke;
 		QPointF strokeStart;
@@ -105,7 +105,7 @@ private:
 		QVector<double> DashPattern;
 		double DashOffset { 0.0 };
 	};
-
+	
 	bool convert(const QString& fn);
 	bool parseDocSequence(const QString& designMap);
 	bool parseDocReference(const QString& designMap);
@@ -134,17 +134,17 @@ private:
 
 	FPointArray Coords;
 	bool interactive { false };
-	MultiProgressDialog * progressDialog { nullptr };
+	MultiProgressDialog * progressDialog { nullptr};
 	bool cancel { false };
 	ScribusDoc* m_Doc { nullptr };
 	Selection* tmpSel { nullptr };
-	int importerFlags { 0 };
+	int importerFlags;
 	QString baseFile;
 	QString m_FileName;
 	QStringList importedColors;
 	QStringList importedPatterns;
 	bool firstPage { true };
-	int pagecount { 0 };
+	int pagecount { 1 };
 	double topMargin { 0.0 };
 	double leftMargin { 0.0 };
 	double rightMargin { 0.0 };
