@@ -26,12 +26,9 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-class imageCollection
+class ImageCollection
 {
 	public:
-		//creates collection object setting name and file
-		imageCollection();
-
 		//name of the collection
 		QString name;
 		//path to the collectionfile
@@ -40,16 +37,14 @@ class imageCollection
 		QStringList imageFiles;
 		//tags to each image;
 		QList<QStringList> tags;
-
 };
 
-
 //manages a set of collections
-class collections
+class Collections
 {
 	public:
 		//sets name
-		collections (const QString& collectionsName );
+		explicit Collections(const QString& collectionsName);
 
 		//contains name of the collections
 		QString name;
@@ -58,34 +53,33 @@ class collections
 		QStringList collectionFiles;
 };
 
-
 //a thread to read collectionfiles
-class collectionReaderThread : public QXmlStreamReader, public QThread
+class CollectionReaderThread : public QXmlStreamReader, public QThread
 {
 	public:
 		//set file to read
-		collectionReaderThread ( QString &xmlFile2, bool importCollection );
+		CollectionReaderThread(const QString& xmlFile2, bool importCollection);
 
 		//starts reading the file
 		void readFile();
 
 		//is executed after starting the thread
-		void run();
+		void run() override;
 		//restarts the thread
 		void restart();
 
 		//true if thread should restart
-		volatile bool restartThread;
+		volatile bool restartThread { false };
 
 		//hierarchy for collectionsbrowser qtreewidget
-		QList<collections *> collectionsSet;
+		QList<Collections *> collectionsSet;
 		//contains the images read from the file
-		imageCollection *collection;
+		ImageCollection *collection { nullptr };
 
 		//tells which filetype it was, 0 for collectionsset, 1 for collection
-		int type;
+		int type { 0 };
 		//if it is an import
-		bool import;
+		bool import { false };
 		//the file to read from
 		QString xmlFile;
 		QStringList addImages;
@@ -108,97 +102,95 @@ class collectionReaderThread : public QXmlStreamReader, public QThread
 		void readUnknownElement();
 
 		//tells how many categories the collectionsdb contained
-		int categoriesCount;
+		int categoriesCount { 0 };
 };
 
-
-class collectionListReaderThread : public QThread
+class CollectionListReaderThread : public QThread
 {
 		Q_OBJECT
 
 	public:
 		//set files to read
-		collectionListReaderThread ( QStringList &xmlFiles2 );
+		explicit CollectionListReaderThread(const QStringList& xmlFiles2);
 
 		//is executed after starting the thread
-		void run();
+		void run() override;
 		//restarts the thread
 		void restart();
 
 		//true if thread should restart
-		volatile bool restartThread;
+		volatile bool restartThread { false };
 
 		QString xmlFile;
 		QStringList xmlFiles;
 
-		QList<imageCollection *> readCollections;
+		QList<ImageCollection *> readCollections;
 
 	private slots:
 		void collectionReaderThreadFinished();
 
 	private:
-		collectionReaderThread *m_clrt;
+		CollectionReaderThread *m_clrt { nullptr };
 };
 
-
 //thread to write a collectionssetfile
-class collectionsWriterThread : public QXmlStreamWriter, public QThread
+class CollectionsWriterThread : public QXmlStreamWriter, public QThread
 {
 	public:
 		//sets initial values
 		//parameters:
 		//QString &xmlFile2: the file to write
 		//int fileType: the type of file, 0 for collectionfile, 1 for collectionsdb
-		//QList<collections *> saveCollections2: the collectionsset to write to the file
-		collectionsWriterThread (const QString& xmlFile2, const QList<collections *> &saveCollections2 );
+		//QList<Collections *> saveCollections2: the collectionsset to write to the file
+		CollectionsWriterThread(const QString& xmlFile2, const QList<Collections*>& saveCollections2);
+
 		//starts writing to the file
 		void writeFile();
 
 		//called after the thread has been started
-		void run();
+		void run() override;
 		//restarts the thread
 		void restart();
 
 		//true if thread should restart
-		volatile bool restartThread;
+		volatile bool restartThread { false };
 
 	private:
 		//writes a category into a collectionssetfile
-		void writeCategory ( const collections *category );
+		void writeCategory(const Collections *category);
 		//writes a collection into a collectionssetfile
-		void writeCollection ( const QString &collectionName, const QString &collectionFile );
+		void writeCollection(const QString& collectionName, const QString& collectionFile);
 
 		//contains the path to the output file
 		QString xmlFile;
 		//the collection to write into a collectionfile
-		QList<collections *> saveCollections;
+		QList<Collections *> saveCollections;
 };
 
-
 //thread to write a collectionfile
-class collectionWriterThread : public QXmlStreamWriter, public QThread
+class CollectionWriterThread : public QXmlStreamWriter, public QThread
 {
 	public:
 		//sets initial values
 		//parameters:
 		//QString &xmlFile2: the file to write
-		//imageCollection *saveCollection2: the collection to write to the file
-		collectionWriterThread ( QString &xmlFile2, imageCollection &saveCollection2 );
+		//ImageCollection *saveCollection2: the collection to write to the file
+		CollectionWriterThread(const QString& xmlFile2, const ImageCollection& saveCollection2);
 		//starts writing to the file
 		void writeFile();
 
 		//called after the thread has been started
-		void run();
+		void run() override;
 
 	private:
 		//writes an image into a collectionfile
-		void writeImage ( const QString &imageFile, const QStringList &tags );
-		void writeTags ( const QStringList &tags );
+		void writeImage(const QString& imageFile, const QStringList& tags);
+		void writeTags(const QStringList& tags);
 
 		//contains the path to the output file
 		QString xmlFile;
 		//the collection to write into a collectionfile
-		imageCollection saveCollection;
+		ImageCollection saveCollection;
 };
 
 #endif // COLLECTION_H
