@@ -19,10 +19,7 @@ PyObject *scribus_getcelltext(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -65,11 +62,7 @@ PyObject *scribus_setcelltext(PyObject* /* self */, PyObject* args)
 	PyESString text;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", text.ptr(), "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		text.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -95,10 +88,7 @@ PyObject *scribus_getcellstyle(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -124,11 +114,7 @@ PyObject *scribus_setcellstyle(PyObject* /* self */, PyObject* args)
 	PyESString style;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", style.ptr(), "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		style.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -154,10 +140,7 @@ PyObject *scribus_getcellrowspan(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -177,10 +160,7 @@ PyObject *scribus_getcellcolumnspan(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -200,10 +180,7 @@ PyObject *scribus_getcellfillcolor(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "ii|es", &row, &column, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -229,11 +206,7 @@ PyObject *scribus_setcellfillcolor(PyObject* /* self */, PyObject* args)
 	PyESString color;
 	int row, column;
 	if (!PyArg_ParseTuple(args, "iies|es", &row, &column, "utf-8", color.ptr(), "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		color.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -260,10 +233,7 @@ PyObject *scribus_setcellleftborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -297,10 +267,7 @@ PyObject *scribus_setcellrightborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -334,10 +301,7 @@ PyObject *scribus_setcelltopborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -371,10 +335,7 @@ PyObject *scribus_setcellbottomborder(PyObject* /* self */, PyObject* args)
 	int row, column;
 	PyObject* borderLines;
 	if (!PyArg_ParseTuple(args, "iiO|es", &row, &column, &borderLines, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -408,10 +369,7 @@ PyObject *scribus_setcellleftpadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -444,10 +402,7 @@ PyObject *scribus_setcellrightpadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -480,10 +435,7 @@ PyObject *scribus_setcelltoppadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -516,10 +468,7 @@ PyObject *scribus_setcellbottompadding(PyObject* /* self */, PyObject* args)
 	int row, column;
 	double padding;
 	if (!PyArg_ParseTuple(args, "iid|es", &row, &column, &padding, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
