@@ -36,12 +36,12 @@ PrintPreviewCreator_PDF::PrintPreviewCreator_PDF(ScribusDoc* doc) :
 	m_printOptions.prnLanguage = PrintLanguage::PDF;
 
 	// Generate a template name for temporary files
-	QScopedPointer<QTemporaryFile> tempFile(new QTemporaryFile(ScPaths::tempFileDir() + "/scpdfpreview_XXXXXX.png"));
-	if (tempFile->open())
+	QTemporaryFile tempFile(ScPaths::tempFileDir() + "/scpdfpreview_XXXXXX.png");
+	if (tempFile.open())
 	{
-		QString tempFileBase = tempFile->fileName();
-		tempFile->setAutoRemove(false);
-		tempFile->close();
+		QString tempFileBase = tempFile.fileName();
+		tempFile.setAutoRemove(false);
+		tempFile.close();
 		m_tempBaseName = QFileInfo(tempFileBase).completeBaseName();
 	}
 	if (m_tempBaseName.isEmpty())
@@ -313,7 +313,7 @@ QPixmap PrintPreviewCreator_PDF::createPreview(int pageIndex)
 		pixmap = QPixmap(image.width(), image.height());
 		pixmap.setDevicePixelRatio(m_devicePixelRatio);
 		QPainter p;
-		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
+		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill"));
 		p.begin(&pixmap);
 		p.fillRect(0, 0, image.width(), image.height(), b);
 		p.drawImage(0, 0, image);
