@@ -34,7 +34,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribusdoc.h"
 #include "util.h"
 #include "util_formats.h"
-#include "util_math.h"
+
 #include "text/boxes.h"
 
 MarksOptions::MarksOptions(const PrintOptions& opt)
@@ -516,7 +516,7 @@ void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, const Q
 	const ScPattern& pattern = m_doc->docPatterns[item->pattern()];
 	const ScPatternTransform& patternTrans = item->patternTransform();
 
-	// Compute pattern tansformation matrix and its inverse for converting pattern coordinates
+	// Compute pattern transformation matrix and its inverse for converting pattern coordinates
 	// to pageitem coordinates 
 	QTransform matrix;
 	matrix.translate(patternTrans.offsetX, patternTrans.offsetY);
@@ -538,7 +538,7 @@ void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, const Q
 	double rot    = patternTrans.rotation - floor(patternTrans.rotation / 90) * 90;
 	double ctheta = cos(rot * M_PI / 180);
 	double stheta = sin(rot * M_PI / 180);
-	QRectF  itemRect(0.0, 0.0, item->width(), item->height());
+	//QRectF  itemRect(0.0, 0.0, item->width(), item->height());
 	QPointF pa(width * stheta * stheta, -width * stheta * ctheta);
 	QPointF pb(width + height * ctheta * stheta, height * stheta * stheta);
 	QPointF pc(-height * ctheta * stheta, height * ctheta * ctheta);
