@@ -10,7 +10,7 @@ for which a new license (GPL+exception) is in place.
 #include "scimage.h"
 #include "scpattern.h"
 #include "util.h"
-#include "util_math.h"
+
 
 ScPainterEx_Cairo::ScPainterEx_Cairo(cairo_t* context, const QRect& rect, ScribusDoc* doc, bool gray) : ScPainterExBase()
 {
@@ -542,12 +542,12 @@ cairo_pattern_t* ScPainterEx_Cairo::getMaskPattern()
 			pat = cairo_pattern_create_radial(fx, fy, 0, x1, y1, sqrt(pow(x2 - x1, 2) + pow(y2 - y1, 2)));
 		QList<VColorStopEx*> colorStops = m_maskGradient.colorStops();
 		QColor qStopColor;
-		for (int offset = 0; offset < colorStops.count(); offset++)
+		for (qsizetype offset = 0; offset < colorStops.count(); offset++)
 		{
 			const auto* stop = colorStops[offset];
 			qStopColor = transformColor(ScColorShade(stop->color, stop->shade), 1.0);
 			double a = colorStops[offset]->opacity;
-			double r, g, b;
+			float r, g, b;
 			qStopColor.getRgbF(&r, &g, &b);
 			if (m_maskMode == 3)
 				a = 0.3 * r + 0.59 * g + 0.11 * b;
@@ -642,7 +642,7 @@ void ScPainterEx_Cairo::fillPathHelper()
 		cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_WINDING);
 	if (m_fillMode == ScPainterExBase::Solid)
 	{
-		double r, g, b;
+		float r, g, b;
 		QColor fillColor = transformColor(m_fillColor, 1.0);
 		fillColor.getRgbF(&r, &g, &b);
 		if (m_maskMode > 0)
@@ -716,7 +716,7 @@ void ScPainterEx_Cairo::strokePathHelper()
 	}
 	else
 	{
-		double r, g, b;
+		float r, g, b;
 		QColor strokeColor = transformColor(m_strokeColor, 1.0);
 		strokeColor.getRgbF(&r, &g, &b);
 		cairo_set_source_rgba(m_cr, r, g, b, m_strokeTrans);
@@ -870,7 +870,7 @@ void ScPainterEx_Cairo::drawGradient(const VGradientEx& gradient)
 
 void ScPainterEx_Cairo::drawLinearGradient(const VGradientEx& gradient)
 {
-	double r, g, b;
+	float r, g, b;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
 	const VColorStopEx* stop = nullptr;
 	QColor color;
@@ -919,7 +919,7 @@ void ScPainterEx_Cairo::drawLinearGradient(const VGradientEx& gradient)
 
 void ScPainterEx_Cairo::drawCircularGradient(const VGradientEx& gradient)
 {
-	double r, g, b;
+	float r, g, b;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
 	const VColorStopEx* stop = nullptr;
 	QColor color;
@@ -986,7 +986,7 @@ void ScPainterEx_Cairo::drawFourColorGradient()
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
 
-	double r, g, b, a;
+	float r, g, b, a;
 	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
 	cairo_mesh_pattern_begin_patch(mpat);
 	cairo_mesh_pattern_move_to(mpat, p1x, p1y);
@@ -1064,7 +1064,7 @@ void ScPainterEx_Cairo::drawDiamondGradient(const VGradientEx& gradient)
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
 
-	double r, g, b, a;
+	float r, g, b, a;
 	const VColorStopEx* stop = nullptr;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
 	QList<QColor> qStopColors;
@@ -1116,7 +1116,7 @@ void ScPainterEx_Cairo::drawDiamondGradient(const VGradientEx& gradient)
 	cairo_set_operator(cr, CAIRO_OPERATOR_ADD);
 
 	cairo_pattern_t *mpat = cairo_pattern_create_mesh();
-	for (int offset = 1 ; offset <  qStopRampPoints.count() ; offset++)
+	for (qsizetype offset = 1 ; offset <  qStopRampPoints.count() ; offset++)
 	{
 		QLineF e1 = edge1;
 		QLineF e1s = edge1;
@@ -1284,11 +1284,11 @@ void ScPainterEx_Cairo::drawMeshGradient()
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
 
-	double r, g, b, a;
+	float r, g, b, a;
 	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
-	for (int grow = 0; grow < m_meshGradientArray.count() - 1; ++grow)
+	for (qsizetype grow = 0; grow < m_meshGradientArray.count() - 1; ++grow)
 	{
-		for (int gcol = 0; gcol < m_meshGradientArray[grow].count() - 1; ++gcol)
+		for (qsizetype gcol = 0; gcol < m_meshGradientArray[grow].count() - 1; ++gcol)
 		{
 			MeshPoint mp1 = m_meshGradientArray[grow][gcol];
 			MeshPoint mp2 = m_meshGradientArray[grow][gcol + 1];
@@ -1362,7 +1362,7 @@ void ScPainterEx_Cairo::drawFreeMeshGradient()
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
 
-	double r, g, b, a;
+	float r, g, b, a;
 	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
 	for (int col = 0; col < m_meshGradientPatches.count(); col++)
 	{
@@ -1431,7 +1431,7 @@ void ScPainterEx_Cairo::drawHatch()
 {
 	cairo_path_t* path = cairo_copy_path(m_cr);
 
-	cairo_surface_t *img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, m_hatchWidth, m_hatchHeight);
+	cairo_surface_t* img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, m_hatchWidth, m_hatchHeight);
 	cairo_t* cr = cairo_create(img);
 
 	cairo_new_path(cr);
@@ -1441,14 +1441,14 @@ void ScPainterEx_Cairo::drawHatch()
 
 	if (m_hatchUseBackground)
 	{
-		double r2, g2, b2;
+		float r2, g2, b2;
 		QColor hatchBackground = transformColor(m_hatchBackground, 1.0);
 		hatchBackground.getRgbF(&r2, &g2, &b2);
 		cairo_set_source_rgb(cr, r2, g2, b2);
 		cairo_fill_preserve(cr);
 	}
 
-	double r, g, b;
+	float r, g, b;
 	QColor hatchForeground = transformColor(m_hatchForeground, 1.0);
 	hatchForeground.getRgbF(&r, &g, &b);
 	cairo_set_line_width(cr, 1);
@@ -1559,7 +1559,7 @@ void ScPainterEx_Cairo::strokeGradient(const VGradientEx& gradient)
 
 void ScPainterEx_Cairo::strokeLinearGradient(const VGradientEx& gradient)
 {
-	double r, g, b;
+	float r, g, b;
 	double x1 = gradient.origin().x();
 	double y1 = gradient.origin().y();
 	double x2 = gradient.vector().x();
@@ -1608,7 +1608,7 @@ void ScPainterEx_Cairo::strokeLinearGradient(const VGradientEx& gradient)
 
 void ScPainterEx_Cairo::strokeCircularGradient(const VGradientEx& gradient)
 {
-	double r, g, b;
+	float r, g, b;
 	double x1 = gradient.origin().x();
 	double y1 = gradient.origin().y();
 	double x2 = gradient.vector().x();
