@@ -16,7 +16,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribusstructs.h"
 
 #include <cairo.h>
-#include <windows.h>
+#include <Windows.h>
 
 class SCRIBUS_API ScPrintEngine_GDI : public ScPrintEngine
 {
@@ -112,7 +112,7 @@ protected:
 
 	/*! \brief Send a file to printer using PostScript Passthrough
 	Send a postscript file to a printer using ps passthrough ( works on PS printers only )
-	\param filePath the Postscript file path
+	\param filePath the PostScript file path
 	\param printerDC the printer deice context
 	\param pageWidth width
 	\param pageHeight height
