@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 /***************************************************************************
     begin                : Jan 2005
     copyright            : (C) 2005 by Craig Bradney
-    email                : cbradney@zip.com.au
+    email                : cbradney@scribus.info
  ***************************************************************************/
 
 /***************************************************************************
@@ -31,19 +31,16 @@ for which a new license (GPL+exception) is in place.
 
 ScrAction::ScrAction( QObject * parent ) : QAction( parent )
 {
-	initScrAction();
 }
 
-ScrAction::ScrAction(const QString & menuText, QKeySequence accel, QObject * parent ) : QAction(menuText, parent)
+ScrAction::ScrAction(const QString & menuText, const QKeySequence& accel, QObject * parent ) : QAction(menuText, parent)
 {
 	setShortcut(accel);
-	initScrAction();
 }
 
-ScrAction::ScrAction(ActionType aType, const QString & menuText, QKeySequence accel, QObject * parent, QVariant d) : QAction(menuText, parent)
+ScrAction::ScrAction(ActionType aType, const QString & menuText, const QKeySequence& accel, QObject * parent, const QVariant& d) : QAction(menuText, parent)
 {
 	setShortcut(accel);
-	initScrAction();
 	setData(d);
 
 	m_actionType = aType;
@@ -51,11 +48,10 @@ ScrAction::ScrAction(ActionType aType, const QString & menuText, QKeySequence ac
 		connect (this, SIGNAL(triggered()), this, SLOT(triggeredToTriggeredData()));
 }
 
-ScrAction::ScrAction(ActionType aType, const QPixmap& icon16, const QPixmap& icon22, const QString & menuText, QKeySequence accel, QObject * parent, QVariant d)
+ScrAction::ScrAction(ActionType aType, const QPixmap& icon16, const QPixmap& icon22, const QString & menuText, const QKeySequence& accel, QObject * parent, const QVariant& d)
           : QAction(QIcon(icon16), menuText, parent)
 {
 	setShortcut(accel);
-	initScrAction();
 	icon().addPixmap(icon22, QIcon::Normal, QIcon::On);
 
 	m_actionType = aType;
@@ -64,11 +60,10 @@ ScrAction::ScrAction(ActionType aType, const QPixmap& icon16, const QPixmap& ico
 		connect (this, SIGNAL(triggered()), this, SLOT(triggeredToTriggeredData()));
 }
 
-ScrAction::ScrAction(ActionType aType, const QString& icon16Path, const QString& icon22Path, const QString & menuText, QKeySequence accel, QObject * parent, QVariant d)
+ScrAction::ScrAction(ActionType aType, const QString& icon16Path, const QString& icon22Path, const QString & menuText, const QKeySequence& accel, QObject * parent, const QVariant& d)
          : QAction(menuText, parent), m_iconPath16(icon16Path), m_iconPath22(icon22Path)
 {
 	setShortcut(accel);
-	initScrAction();
 	loadIcon();
 
 	m_actionType = aType;
@@ -79,40 +74,27 @@ ScrAction::ScrAction(ActionType aType, const QString& icon16Path, const QString&
 		connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(loadIcon()));
 }
 
-ScrAction::ScrAction(const QString& icon16Path, const QString& icon22Path, const QString & menuText, QKeySequence accel, QObject * parent )
+ScrAction::ScrAction(const QString& icon16Path, const QString& icon22Path, const QString & menuText, const QKeySequence& accel, QObject * parent )
          : QAction(menuText, parent), m_iconPath16(icon16Path), m_iconPath22(icon22Path)
 {
 	setShortcut(accel);
 	setMenuRole(QAction::NoRole);
-	initScrAction();
 	loadIcon();
 	if (!m_iconPath16.isEmpty() || !m_iconPath22.isEmpty())
 		connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(loadIcon()));
 }
 
 
-ScrAction::ScrAction(QKeySequence accel, QObject * parent, QVariant d)
+ScrAction::ScrAction(const QKeySequence& accel, QObject * parent, const QVariant& d)
 	: QAction( QIcon(QPixmap()), "", parent )
 {
 	setShortcut(accel);
-	initScrAction();
 	icon().addPixmap(QPixmap(), QIcon::Normal, QIcon::On);
 	m_actionType = UnicodeChar;
 	setData(d);
 	connect (this, SIGNAL(triggered()), this, SLOT(triggeredToTriggeredData()));
 }
 
-
-void ScrAction::initScrAction()
-{
-	m_actionType = ScrAction::Normal;
-	m_menuIndex = -1;
-	m_popupMenuAddedTo = nullptr;
-	m_savedKeySequence = QKeySequence("");
-	m_shortcutSaved = false;
-	m_fakeToggle = false;
-}
-
 void ScrAction::triggeredToTriggeredData()
 {
 	if (m_actionType == ScrAction::DataInt)
@@ -132,6 +114,8 @@ void ScrAction::triggeredToTriggeredData()
 		emit triggeredData(data().toString());
 	if (m_actionType == ScrAction::RecentScript)
 		emit triggeredData(data().toString());
+	if (m_actionType == ScrAction::OwnScript)
+		emit triggeredData(data().toString());
 	if (m_actionType == ScrAction::UnicodeChar)
 		emit triggeredUnicodeShortcut(data().toInt());
 	if (m_actionType == ScrAction::Layer)
@@ -162,6 +146,8 @@ void ScrAction::toggledToToggledData(bool ison)
 		emit toggledData(ison, data().toString());
 	if (m_actionType == ScrAction::RecentScript)
 		emit toggledData(ison, text());
+	if (m_actionType == ScrAction::OwnScript)
+		emit toggledData(ison, text());
 	if (m_actionType == ScrAction::Layer)
 		emit toggledData(ison, data().toInt());
 	// no toggle for UnicodeChar
@@ -301,14 +287,14 @@ void ScrAction::loadIcon()
 
 	if (!m_iconPath16.isEmpty())
 	{
-		QPixmap pix = iconManager.loadPixmap(m_iconPath16);
+		QPixmap pix = iconManager.loadPixmap(m_iconPath16, 16);
 		if (!pix.isNull())
 			newIcon.addPixmap(pix, QIcon::Normal, QIcon::On);
 	}
 
 	if (!m_iconPath22.isEmpty())
 	{
-		QPixmap pix = iconManager.loadPixmap(m_iconPath22);
+		QPixmap pix = iconManager.loadPixmap(m_iconPath22, 20);
 		if (!pix.isNull())
 			newIcon.addPixmap(pix, QIcon::Normal, QIcon::On);
 	}
