@@ -8,7 +8,7 @@ for which a new license (GPL+exception) is in place.
 /***************************************************************************
     begin                : Jan 2005
     copyright            : (C) 2005 by Craig Bradney
-    email                : cbradney@zip.com.au
+    email                : cbradney@scribus.info
  ***************************************************************************/
 
 /***************************************************************************
@@ -37,7 +37,7 @@ class SCRIBUS_API ScrAction : public QAction
 	Q_OBJECT
 
 public:
-	enum ActionType { Normal, DataInt, DataDouble, DataQString, RecentFile, DLL, Window, RecentScript, UnicodeChar, Layer, ActionDLL, RecentPaste, ActionDLLSE };
+	enum ActionType { Normal, DataInt, DataDouble, DataQString, RecentFile, DLL, Window, RecentScript, UnicodeChar, Layer, ActionDLL, RecentPaste, ActionDLLSE, OwnScript };
 	
 	/*!
 		\author Craig Bradney
@@ -45,7 +45,7 @@ public:
 		\brief Constructor from QAction, sets menuType to Normal
 		\param parent Parent object of this action
 	*/
-	ScrAction (QObject *parent) ;
+	ScrAction (QObject *parent);
 		
 	/*!
 		\author Craig Bradney
@@ -55,7 +55,7 @@ public:
 		\param accel Accelerator QKeySequence
 		\param parent Parent object of this action
 	*/
-	ScrAction(const QString &menuText, QKeySequence accel, QObject *parent);
+	ScrAction(const QString &menuText, const QKeySequence& accel, QObject *parent);
 		
 	/*!
 		\author Craig Bradney
@@ -71,9 +71,9 @@ public:
 		\param extraDouble extra double value
 		\param extraQString extra QString value
 	 */
-	ScrAction(ActionType aType, const QString &menuText, QKeySequence accel, QObject *parent, QVariant d = QVariant());
-	ScrAction(ActionType aType, const QPixmap& icon16, const QPixmap& icon22, const QString &menuText, QKeySequence accel, QObject *parent, QVariant d = QVariant());
-	ScrAction(ActionType aType, const QString& icon16Path, const QString& icon22Path, const QString &menuText, QKeySequence accel, QObject *parent, QVariant d = QVariant());
+	ScrAction(ActionType aType, const QString &menuText, const QKeySequence& accel, QObject *parent, const QVariant& d = QVariant());
+	ScrAction(ActionType aType, const QPixmap& icon16, const QPixmap& icon22, const QString &menuText, const QKeySequence& accel, QObject *parent, const QVariant& d = QVariant());
+	ScrAction(ActionType aType, const QString& icon16Path, const QString& icon22Path, const QString &menuText, const QKeySequence& accel, QObject *parent, const QVariant& d = QVariant());
 	/*!
 		\author Craig Bradney
 		\date Jan 2005
@@ -83,7 +83,7 @@ public:
 		\param accel Accelerator QKeySequence
 		\param parent Parent of this action
 	*/
-	ScrAction(const QString& icon16Path, const QString& icon22Path, const QString & menuText, QKeySequence accel, QObject *parent);
+	ScrAction(const QString& icon16Path, const QString& icon22Path, const QString & menuText, const QKeySequence& accel, QObject *parent);
 	/*!
 	\author Craig Bradney
 	\date Mar 2008
@@ -93,7 +93,7 @@ public:
 	\param extraInt extra int value
 	\param extraQString extra QString value
 	 */
-	ScrAction(QKeySequence accel, QObject *parent, QVariant data = QVariant());
+	ScrAction(const QKeySequence& accel, QObject *parent, const QVariant& data = QVariant());
 	~ScrAction() = default;
 	
 	/*!
@@ -187,12 +187,12 @@ signals:
 	void triggeredUnicodeShortcut(int);
 	
 protected:
-	int m_menuIndex;
-	ActionType m_actionType;
-	QMenu *m_popupMenuAddedTo;
+	int m_menuIndex {-1};
+	ActionType m_actionType {ScrAction::Normal};
+	QMenu *m_popupMenuAddedTo {nullptr};
 	QKeySequence m_savedKeySequence;
-	bool m_shortcutSaved;
-	bool m_fakeToggle;
+	bool m_shortcutSaved {false};
+	bool m_fakeToggle {false};
 
 	QString m_iconPath16;
 	QString m_iconPath22;
