@@ -71,7 +71,10 @@ class BookPalette;
 class CharSelect;
 class CheckDocument;
 class ColorCombo;
+class ContentPalette;
 class DockManager;
+class DocumentLogManager;
+class DocumentLogViewer;
 class DownloadsPalette;
 class EditToolBar;
 class FileToolBar;
@@ -94,7 +97,6 @@ class PagePalette;
 class PageSelector;
 class PrefsContext;
 class PrefsManager;
-class ContentPalette;
 class PropertiesPalette;
 class ResourceManager;
 class ScMWMenuManager;
@@ -247,6 +249,7 @@ public:
 	QLabel* mainWindowXPosDataLabel {nullptr};
 	QLabel* mainWindowYPosLabel {nullptr};
 	QLabel* mainWindowYPosDataLabel {nullptr};
+
 	GuideManager *guidePalette {nullptr};
 	CharSelect *charPalette {nullptr};
 	PropertiesPalette *propertiesPalette {nullptr};
@@ -267,6 +270,8 @@ public:
 	UndoPalette* undoPalette {nullptr};
 	AlignDistributePalette *alignDistributePalette {nullptr};
 	ResourceManager *resourceManager {nullptr};
+	DocumentLogViewer *documentLogViewer {nullptr};
+
 	StoryEditor* storyEditor {nullptr};
 	StoryEditor* CurrStED {nullptr};
 	QMdiArea *mdiArea {nullptr};
@@ -397,7 +402,8 @@ public slots:
 	/** \brief put the marked text/object into the clipboard*/
 	void slotEditCopy();
 	/** \brief paste the clipboard into the document*/
-	void slotEditPaste();
+	void slotEditPaste(bool forcePlainText = false);
+	void slotEditPastePlainText();
 	void slotEditCopyContents();
 	void slotEditPasteContents(int absolute=0);
 	void SelectAll(bool docWideSelect = false);
@@ -415,6 +421,7 @@ public slots:
 	void slotOnlineHelp(const QString& jumpToSection = QString(), const QString& jumpToFile = QString());
 	void slotOnlineHelpClosed();
 	void slotResourceManager();
+	void slotItemStyleSearch();
 	void ToggleTips();
 	void ToggleMouseTips();
 	/** \brief Erzeugt eine neue Seite */
@@ -455,8 +462,6 @@ public slots:
 	void toggleRulers();
 	void toggleRulerMode();
 	void togglePagePalette();
-	void toggleUndoPalette();
-	void setUndoPalette(bool visible);
 	void toggleCheckPal();
 	/** \brief Schaltet M_ViewShowImages ein/aus */
 	void toggleImageVisibility();
@@ -540,7 +545,7 @@ public slots:
 	void toggleBase();
 	void toggleSnapGuides();
 	void toggleSnapElements();
-	void SetSnapElements(bool b);
+	void setSnapElements(bool b);
 	void EditTabs();
 	void SearchText();
 	/*! \brief call gimp and wait upon completion */
@@ -656,6 +661,7 @@ private:
 
 	StyleManager *m_styleManager {nullptr};
 	UndoManager *m_undoManager {nullptr};
+	DocumentLogManager *m_documentLogManager {nullptr};
 	PrefsManager& m_prefsManager;
 	WidgetManager &m_widgetManager;
 	FormatsManager *m_formatsManager {nullptr};	
