@@ -24,7 +24,6 @@ for which a new license (GPL+exception) is in place.
 #include <iostream>
 #include <cstdlib>
 
-
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -33,7 +32,6 @@ for which a new license (GPL+exception) is in place.
 #include <QLocale>
 #include <QString>
 #include <QStringList>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QTranslator>
 
@@ -55,7 +53,7 @@ for which a new license (GPL+exception) is in place.
 #endif
 
 #if defined(_WIN32)
-#include <windows.h>
+#include <Windows.h>
 #endif
 
 #define ARG_VERSION "--version"
@@ -584,7 +582,9 @@ static void printArgLine(QTextStream & ts, const char * smallArg, const char* fu
 void ScribusQApp::showUsage()
 {
 	QFile f;
-	f.open(stderr, QIODevice::WriteOnly);
+	if (!f.open(stderr, QIODevice::WriteOnly))
+		return;
+
 	QTextStream ts(&f);
 	ts << tr("Usage: scribus [options] [files]") ; Qt::endl(ts); Qt::endl(ts);
 	ts << tr("Options:") ; Qt::endl(ts);
@@ -601,7 +601,6 @@ void ScribusQApp::showUsage()
 	printArgLine(ts, ARG_PYTHONSCRIPT_SHORT, qPrintable(QString("%1 <%2> [%3] ").arg(ARG_PYTHONSCRIPT, tr("script"), tr("arguments ..."))), tr("Run script in Python [with optional arguments]. This option must be last option used") );
 	printArgLine(ts, ARG_NOGUI_SHORT, ARG_NOGUI, tr("Do not start GUI") );
 	ts << (QString("     %1").arg(CMD_OPTIONS_END,-39)) << tr("Explicit end of command line options"); Qt::endl(ts);
- 	
 	
 #if defined(_WIN32) && !defined(_CONSOLE)
 	printArgLine(ts, ARG_CONSOLE_SHORT, ARG_CONSOLE, tr("Display a console window") );
@@ -645,7 +644,9 @@ void ScribusQApp::showVersion()
 void ScribusQApp::showHeader()
 {
 	QFile f;
-	f.open(stderr, QIODevice::WriteOnly);
+	if (!f.open(stderr, QIODevice::WriteOnly))
+		return;
+
 	QTextStream ts(&f);
 	ts << Qt::endl;
 	QString heading( tr("Scribus, Open Source Desktop Publishing") );
@@ -692,23 +693,32 @@ void ScribusQApp::downloadComplete(const QString &t)
 
 bool ScribusQApp::event(QEvent *event)
 {
-	switch (event->type()) 
+	switch (event->type())
 	{
 	case QEvent::FileOpen:
+	{
+		QString filename = static_cast<QFileOpenEvent*>(event)->file();
+		if (m_ScCore && m_ScCore->initialized())
 		{
-			QString filename = static_cast<QFileOpenEvent*>(event)->file();
-			if(m_ScCore && m_ScCore->initialized())
-			{
-				ScribusMainWindow* mw = m_ScCore->primaryMainWindow();
-				mw->loadDoc(filename);
-			}
-			else
-			{
-				m_filesToLoad.append(filename);
-			}
-			return true;
+			ScribusMainWindow* mw = m_ScCore->primaryMainWindow();
+			mw->loadDoc(filename);
 		}
-	default:
-		return QApplication::event(event);
+		else
+		{
+			m_filesToLoad.append(filename);
+		}
+		return true;
 	}
+	case QEvent::ApplicationPaletteChange:
+	{
+		IconManager& im = IconManager::instance();
+		im.rebuildCache();
+		emit iconSetChanged();
+	}
+		break;
+	default:
+		break;
+	}
+
+	return QApplication::event(event);
 }
