@@ -30,6 +30,7 @@ for which a new license (GPL+exception) is in place.
 #include <QMessageBox>
 #include <QScreen>
 #include <QStyleFactory>
+#include <QStyleHints>
 
 #include "colormgmt/sccolormgmtenginefactory.h"
 #include "commonstrings.h"
@@ -44,13 +45,14 @@ for which a new license (GPL+exception) is in place.
 #include "scribus.h"
 #include "scribusapp.h"
 #include "ui/splash.h"
+#include "ui/factories/scribusproxystyle.h"
 #include "undomanager.h"
 #include "util_debug.h"
 #include "util_ghostscript.h"
 
 //extern ScribusQApp* ScQApp;
 
-ScribusCore::ScribusCore() : defaultEngine(colorMgmtEngineFactory.createDefaultEngine()),
+ScribusCore::ScribusCore() : defaultEngine(ScColorMgmtEngineFactory::createDefaultEngine()),
 							m_iconManager(IconManager::instance()),
 							m_prefsManager(PrefsManager::instance())
 {
@@ -175,19 +177,43 @@ int ScribusCore::initScribusCore(bool showSplash, bool showFontInfo, bool showPr
 	setSplashStatus( tr("Reading Preferences") );
 	m_prefsManager.readPrefs();
 
+	// This is a very basic implemenation of the UI theme palette.
+	// If necessary implement platform specific theme configurations here.
+
 	// Configure GUI
 	const QString& prefsUiStyle = m_prefsManager.appPrefs.uiPrefs.style;
+	QString qtStyle = nullptr;
 	if (prefsUiStyle.length() > 0)
 	{
-		QStyle* qtStyle = nullptr;
 		QStringList availableStyles = QStyleFactory::keys();
 		if (availableStyles.contains(prefsUiStyle))
-			qtStyle = QStyleFactory::create(prefsUiStyle);
-		if (qtStyle)
-			QApplication::setStyle(qtStyle);
+			qtStyle = prefsUiStyle;
 		else
 			m_prefsManager.appPrefs.uiPrefs.style.clear();
 	}
+
+	ScribusProxyStyle* scStyle = new ScribusProxyStyle(qtStyle);
+	scStyle->setParent(qApp);
+
+	// Apply different palette only if the system UI palette is different.
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
+	if (m_prefsManager.appPrefs.uiPrefs.stylePalette == "dark" && QApplication::styleHints()->colorScheme() == Qt::ColorScheme::Light)
+	{
+		scStyle->setApplicationTheme(ScribusProxyStyle::ApplicationTheme::Dark);
+		m_SplashScreen->setPixmap(m_iconManager.splashScreen());
+	}
+	else if (m_prefsManager.appPrefs.uiPrefs.stylePalette == "light" && QApplication::styleHints()->colorScheme() == Qt::ColorScheme::Dark)
+	{
+		scStyle->setApplicationTheme(ScribusProxyStyle::ApplicationTheme::Light);
+		m_SplashScreen->setPixmap(m_iconManager.splashScreen());
+	}
+	else
+		scStyle->setApplicationTheme(ScribusProxyStyle::ApplicationTheme::System);
+#endif
+
+	qApp->setStyle(scStyle);
+	qApp->installEventFilter(scStyle);
+
 	QFont apf = QApplication::font();
 	apf.setPointSize(m_prefsManager.appPrefs.uiPrefs.applicationFontSize);
 	QApplication::setFont(apf);
@@ -326,37 +352,34 @@ bool ScribusCore::initFonts(bool showFontInfo)
 
 void ScribusCore::getCMSProfiles(bool showInfo)
 {
-	QString profDir;
-	QStringList profDirs;
 	MonitorProfiles.clear();
 	PrinterProfiles.clear();
 	InputProfiles.clear();
 	InputProfilesCMYK.clear();
 	LabProfiles.clear();
-	profDirs = ScPaths::systemProfilesDirs();
+
+	QStringList profDirs = ScPaths::systemProfilesDirs();
 	profDirs.prepend( m_prefsManager.appPrefs.pathPrefs.colorProfiles );
-	profDirs.prepend( ScPaths::instance().shareDir()+"profiles/");
+	profDirs.prepend( ScPaths::instance().shareDir() + "profiles/");
 	for (int i = 0; i < profDirs.count(); i++)
 	{
-		profDir = profDirs[i];
-		if(!profDir.isEmpty())
-		{
-			if(profDir.right(1) != "/")
-				profDir += "/";
-			getCMSProfilesDir(profDir, showInfo, true);
-		}
+		QString profDir = profDirs[i];
+		if (profDir.isEmpty())
+			continue;
+		if (profDir.right(1) != "/")
+			profDir += "/";
+		getCMSProfilesDir(profDir, showInfo, true);
 	}
 	m_haveCMS = (!PrinterProfiles.isEmpty()) && (!InputProfiles.isEmpty()) && (!MonitorProfiles.isEmpty());
 }
 
 void ScribusCore::getCMSProfilesDir(const QString& pfad, bool showInfo, bool recursive)
 {
-	QString profileName;
 	QList<ScColorProfileInfo> profileInfos = defaultEngine.getAvailableProfileInfo(pfad, recursive);
 	for (int i = 0; i < profileInfos.count(); ++i)
 	{
 		const ScColorProfileInfo& profInfo = profileInfos.at(i);
-		profileName = profInfo.description;
+		QString profileName = profInfo.description;
 		if (profileName.isEmpty())
 		{
 			if (showInfo)
@@ -369,49 +392,49 @@ void ScribusCore::getCMSProfilesDir(const QString& pfad, bool showInfo, bool rec
 				sDebug(profInfo.debug);
 			continue;
 		}
-		switch (static_cast<int>(profInfo.deviceClass))
+		switch (profInfo.deviceClass)
 		{
 		case Class_Input:
 			if (profInfo.colorSpace == ColorSpace_Rgb)
 			{
 				if (!InputProfiles.contains(profileName))
-					InputProfiles.insert(profileName, profInfo.file);
+					InputProfiles.insert(profileName, profInfo);
 			}
 			break;
 		case Class_ColorSpace:
 			if (profInfo.colorSpace == ColorSpace_Rgb)
 			{
 				if (!InputProfiles.contains(profileName))
-					InputProfiles.insert(profileName, profInfo.file);
+					InputProfiles.insert(profileName, profInfo);
 			}
 			if (profInfo.colorSpace == ColorSpace_Cmyk)
 			{
 				if (!InputProfilesCMYK.contains(profileName))
-					InputProfilesCMYK.insert(profileName, profInfo.file);
+					InputProfilesCMYK.insert(profileName, profInfo);
 			}
 			if (profInfo.colorSpace == ColorSpace_Lab)
 			{
 				if (!LabProfiles.contains(profileName))
-					LabProfiles.insert(profileName, profInfo.file);
+					LabProfiles.insert(profileName, profInfo);
 			}
 			break;
 		case Class_Display:
 			if (profInfo.colorSpace == ColorSpace_Rgb)
 			{
 				if (!MonitorProfiles.contains(profileName))
-					MonitorProfiles.insert(profileName, profInfo.file);
+					MonitorProfiles.insert(profileName, profInfo);
 				if (!InputProfiles.contains(profileName))
-					InputProfiles.insert(profileName, profInfo.file);
+					InputProfiles.insert(profileName, profInfo);
 			}
 			if (profInfo.colorSpace == ColorSpace_Cmyk)
 			{
 				if (!InputProfilesCMYK.contains(profileName))
-					InputProfilesCMYK.insert(profileName, profInfo.file);
+					InputProfilesCMYK.insert(profileName, profInfo);
 			}
 			if (profInfo.colorSpace == ColorSpace_Lab)
 			{
 				if (!LabProfiles.contains(profileName))
-					LabProfiles.insert(profileName, profInfo.file);
+					LabProfiles.insert(profileName, profInfo);
 			}
 			break;
 		case Class_Output:
@@ -420,13 +443,17 @@ void ScribusCore::getCMSProfilesDir(const QString& pfad, bool showInfo, bool rec
 			if (profInfo.colorSpace == ColorSpace_Cmyk)
 			{
 				if (!PDFXProfiles.contains(profileName))
-					PDFXProfiles.insert(profileName, profInfo.file);
+					PDFXProfiles.insert(profileName, profInfo);
 				if (!InputProfilesCMYK.contains(profileName))
-					InputProfilesCMYK.insert(profileName, profInfo.file);
+					InputProfilesCMYK.insert(profileName, profInfo);
 				if (!PrinterProfiles.contains(profileName))
-					PrinterProfiles.insert(profileName, profInfo.file);
+					PrinterProfiles.insert(profileName, profInfo);
 			}
 			break;
+		default:
+			if (showInfo)
+				sDebug(QString("Color profile uses an unsupported device class: %1").arg(profInfo.file));
+			break;
 		}
 		if (showInfo)
 			sDebug( QString("Color profile %1 loaded from %2").arg(profileName, profInfo.file) );
@@ -444,12 +471,12 @@ void ScribusCore::InitDefaultColorTransforms()
 	// Open the default RGB profile
 	if (InputProfiles.contains(defaultRGBString1))
 	{
-		defaultRGBProfile = defaultEngine.openProfileFromFile(InputProfiles[defaultRGBString1]);
+		defaultRGBProfile = defaultEngine.openProfileFromFile(InputProfiles[defaultRGBString1].file);
 		defaultRGBString = defaultRGBString1;
 	}
 	else if (InputProfiles.contains(defaultRGBString2))
 	{
-		defaultRGBProfile = defaultEngine.openProfileFromFile(InputProfiles[defaultRGBString2]);
+		defaultRGBProfile = defaultEngine.openProfileFromFile(InputProfiles[defaultRGBString2].file);
 		defaultRGBString = defaultRGBString2;
 	}
 	else
@@ -460,9 +487,9 @@ void ScribusCore::InitDefaultColorTransforms()
 
 	// Open the default CMYK profile
 	if (InputProfilesCMYK.contains(defaultCMYKString1))
-		defaultCMYKProfile = defaultEngine.openProfileFromFile(InputProfilesCMYK[defaultCMYKString1]);
+		defaultCMYKProfile = defaultEngine.openProfileFromFile(InputProfilesCMYK[defaultCMYKString1].file);
 	else if (InputProfilesCMYK.contains(defaultCMYKString2))
-		defaultCMYKProfile = defaultEngine.openProfileFromFile(InputProfilesCMYK[defaultCMYKString2]);
+		defaultCMYKProfile = defaultEngine.openProfileFromFile(InputProfilesCMYK[defaultCMYKString2].file);
 
 	// Keep all chance to have monitor profile set
 	monitorProfile = defaultRGBProfile;
@@ -476,14 +503,20 @@ void ScribusCore::InitDefaultColorTransforms()
 	// Default rgb profile may be a memory profile, if it is the case add it to the lists of 
 	// rgb profiles (input and monitor) so that it can be used later in prefs
 	if (!InputProfiles.contains(defaultRGBString))
-		InputProfiles.insert(defaultRGBString, defaultRGBProfile.profilePath());
+	{
+		ScColorProfileInfo profileInfo = defaultRGBProfile.info();
+		InputProfiles.insert(defaultRGBString, profileInfo);
+	}
 	if (!MonitorProfiles.contains(defaultRGBString))
-		MonitorProfiles.insert(defaultRGBString, defaultRGBProfile.profilePath());
+	{
+		ScColorProfileInfo profileInfo = defaultRGBProfile.info();
+		MonitorProfiles.insert(defaultRGBString, profileInfo);
+	}
 
 	// Open monitor profile as defined by user preferences
 	QString displayProfile = m_prefsManager.appPrefs.colorPrefs.DCMSset.DefaultMonitorProfile;
 	if (MonitorProfiles.contains(displayProfile))
-		monitorProfile = defaultEngine.openProfileFromFile( MonitorProfiles[displayProfile] );
+		monitorProfile = defaultEngine.openProfileFromFile( MonitorProfiles[displayProfile].file);
 	if (monitorProfile.isNull())
 	{
 		m_prefsManager.appPrefs.colorPrefs.DCMSset.DefaultMonitorProfile = defaultRGBString;
@@ -533,7 +566,7 @@ void ScribusCore::initCMS()
 	if (!m_haveCMS)
 		return;
 
-	ProfilesL::Iterator ip;
+	ScProfileInfoMap::Iterator ip;
 	QString defaultRGBString1 = "sRGB display profile (ICC v2.2)";
 	QString defaultRGBString2 = "sRGB IEC61966-2.1";
 	QString defaultCMYKString1 = "ISO Coated v2 300% (basICColor)";
