@@ -28,21 +28,23 @@ for which a new license (GPL+exception) is in place.
 #endif
 // include files for QT
 #include <QColor>
+#include <QFile>
 #include <QFont>
+#include <QHash>
 #include <QList>
 #include <QMap>
-#include <QHash>
 #include <QObject>
 #include <QPixmap>
 #include <QRectF>
 #include <QStringList>
 #include <QTimer>
-#include <QFile>
+#include <QUuid>
 
 #include "appmodes.h"
 #include "gtgettext.h" //CB For the ImportSetup struct and itemadduserframe
 #include "scribusapi.h"
 #include "colormgmt/sccolormgmtengine.h"
+#include "colormgmt/sccolormgmtstructs.h"
 #include "documentinformation.h"
 #include "numeration.h"
 #include "marks.h"
@@ -100,6 +102,7 @@ public:
 	~ScribusDoc();
 
 	void init();
+	QString uuidString() {return m_uuid.toString(QUuid::WithoutBraces);}
 	bool inAnEditMode() const;
 	bool inASpecialEditMode() const;
 	QList<PageItem*> getAllItems(const QList<PageItem*> &items) const;
@@ -549,8 +552,8 @@ public:
 	/*!
 		* @brief Builds a qmap of the icc profiles used within the document
 	 */
-	void getUsedProfiles(ProfilesL& usedProfiles) const;
-	bool OpenCMSProfiles(ProfilesL InPo, ProfilesL InPoCMYK, ProfilesL MoPo, ProfilesL PrPo);
+	void getUsedProfiles(ScProfileInfoMap& usedProfiles) const;
+	bool OpenCMSProfiles(ScProfileInfoMap InPo, ScProfileInfoMap InPoCMYK, ScProfileInfoMap MoPo, ScProfileInfoMap PrPo);
 	void CloseCMSProfiles();
 	void SetDefaultCMSParams();
 	/**
@@ -917,7 +920,7 @@ public:
 	   @param PrCMYK cmyk profile
 	   @param dia optional progress widget
 	 */
-	void RecalcPictures(ProfilesL *Pr, ProfilesL *PrCMYK, QProgressBar *dia = 0);
+	void RecalcPictures(ScProfileInfoMap *Pr, ScProfileInfoMap *PrCMYK, QProgressBar *dia = 0);
 	/**
 	 * \brief Handle image with color profiles
 	 * @param items list of page items to update
@@ -925,7 +928,7 @@ public:
 	 * @param PrCMYK cmyk profile
 	 * @param dia optional progress widget
 	 */
-	void RecalcPictures(const QList<PageItem*>* items, ProfilesL *Pr, ProfilesL *PrCMYK, QProgressBar *dia = nullptr);
+	void RecalcPictures(const QList<PageItem*>* items, ScProfileInfoMap *Pr, ScProfileInfoMap *PrCMYK, QProgressBar *dia = nullptr);
 
 	/**
 	 * @brief Find the minX,MinY and maxX,maxY for the canvas required for the doc
@@ -1318,6 +1321,7 @@ protected:
 	bool m_symbolEditMode {false};
 	bool m_inlineEditMode {false};
 	int  m_storedLayerID {0};
+	int  m_storedFirstLayerID {0};
 	bool m_storedLayerLock {false};
 	bool m_storedLayerVis {false};
 	QMap<QString, double> m_constants;
@@ -1329,9 +1333,9 @@ protected:
 	QString m_currentEditedSymbol;
 	int m_currentEditedIFrame {0};
 	QString m_documentFileName;
+	QUuid m_uuid;
 
 public: // Public attributes
-	bool is12doc {false}; //public for now, it will be removed later
 	int NrItems {0};
 	int First {1};
 	int Last {0};
@@ -1339,7 +1343,7 @@ public: // Public attributes
 	int viewID {0};
 	bool SnapGrid {false};
 	bool SnapGuides {false};
-	bool SnapElement {false};
+	bool SnapItems {false};
 	bool GuideLock {false};
 	bool dontResize {false};
 	/** \brief Minimum and Maximum Points of Document */
@@ -1444,7 +1448,7 @@ public:
 	struct BookMa {
 		QString Title;
 		QString Text;
-		QString Aktion;
+		QString Action;
 		PageItem *PageObject;
 		int Parent;
 		int ItemNr;
