@@ -69,7 +69,7 @@ void AdapterWidget::mousePressEvent ( QMouseEvent* event )
 			button = 2;
 			break;
 		case Qt::RightButton:
-			qApp->setOverrideCursor(IconManager::instance().loadCursor("lupez.png"));
+			qApp->setOverrideCursor(IconManager::instance().loadCursor("cursor-zoom-in"));
 			button = 3;
 			break;
 		case Qt::NoButton:
