@@ -78,7 +78,7 @@ ColorsAndFillsDialog::ColorsAndFillsDialog(QWidget* parent, QHash<QString, VGrad
 	setupUi(this);
 	setModal(true);
 
-	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+	setWindowIcon(IconManager::instance().loadIcon("app-icon"));
 	dataTree->setContextMenuPolicy(Qt::CustomContextMenu);
 	dataTree->setIconSize(QSize(60, 48));
 	colorItems = new QTreeWidgetItem(dataTree);
@@ -232,7 +232,7 @@ QTreeWidgetItem* ColorsAndFillsDialog::updateGradientList(const QString& addedNa
 		VGradient gr = dialogGradients.value(patK[i]);
 		QImage pixm(48, 12, QImage::Format_ARGB32);
 		QPainter pb;
-		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
+		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill"));
 		pb.begin(&pixm);
 		pb.fillRect(0, 0, 48, 12, b);
 		pb.end();
@@ -476,8 +476,8 @@ void ColorsAndFillsDialog::createNew()
 		if (!dia->exec())
 			return;
 
-		dia->Farbe.setSpotColor(dia->isSpotColor());
-		m_colorList.insert(dia->colorName(), dia->Farbe);
+		dia->m_color.setSpotColor(dia->isSpotColor());
+		m_colorList.insert(dia->colorName(), dia->m_color);
 		QTreeWidgetItem *lg = updateColorList(dia->colorName());
 		if (lg != nullptr)
 		{
@@ -557,9 +557,9 @@ void ColorsAndFillsDialog::editColorItem()
 		if (!dia->exec())
 			return;
 
-		dia->Farbe.setSpotColor(dia->isSpotColor());
-		dia->Farbe.setRegistrationColor(tmpColor.isRegistrationColor());
-		m_colorList[dia->colorName()] = dia->Farbe;
+		dia->m_color.setSpotColor(dia->isSpotColor());
+		dia->m_color.setRegistrationColor(tmpColor.isRegistrationColor());
+		m_colorList[dia->colorName()] = dia->m_color;
 		if (it->text(0) != dia->colorName())
 		{
 			replaceColorMap.insert(it->text(0), dia->colorName());
@@ -680,9 +680,9 @@ void ColorsAndFillsDialog::duplicateColorItem()
 			return;
 		}
 
-		dia->Farbe.setSpotColor(dia->isSpotColor());
-		dia->Farbe.setRegistrationColor(tmpColor.isRegistrationColor());
-		m_colorList[dia->colorName()] = dia->Farbe;
+		dia->m_color.setSpotColor(dia->isSpotColor());
+		dia->m_color.setRegistrationColor(tmpColor.isRegistrationColor());
+		m_colorList[dia->colorName()] = dia->m_color;
 		if (nam != dia->colorName())
 		{
 			replaceColorMap.insert(nam, dia->colorName());
@@ -1303,10 +1303,10 @@ void ColorsAndFillsDialog::loadVectors(const QString& data)
 	uint ap = m_doc->docPatterns.count();
 	bool savedAlignGrid = m_doc->SnapGrid;
 	bool savedAlignGuides = m_doc->SnapGuides;
-	bool savedAlignElement = m_doc->SnapElement;
+	bool savedAlignElement = m_doc->SnapItems;
 	m_doc->SnapGrid = false;
 	m_doc->SnapGuides = false;
-	m_doc->SnapElement = false;
+	m_doc->SnapItems = false;
 	if (fi.suffix().toLower() == "sce")
 	{
 		ScriXmlDoc ss;
@@ -1329,7 +1329,7 @@ void ColorsAndFillsDialog::loadVectors(const QString& data)
 	}
 	m_doc->SnapGrid = savedAlignGrid;
 	m_doc->SnapGuides = savedAlignGuides;
-	m_doc->SnapElement = savedAlignElement;
+	m_doc->SnapItems = savedAlignElement;
 	uint ae = m_doc->Items->count();
 	if (ac != ae)
 	{
@@ -1947,7 +1947,7 @@ void ColorsAndFillsDialog::doSaveDefaults(const QString& name, bool changed)
 	filename.replace(" ", "_");
 	filename  = QDir::toNativeSeparators(ScPaths::userPaletteFilesDir(true)) + filename;
 	filename += ".xml";
-	const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA170EXPORT);
+	const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA171EXPORT);
 	if (fmt)
 	{
 		std::unique_ptr<ScribusDoc> s_doc(new ScribusDoc());
