@@ -345,7 +345,7 @@ void ContextMenu::createMenuItems_Selection()
 		
 		if ((selectedItemCount == 1) && currItem->isTextFrame())
 		{
-			if (currItem->itemText.length() > 0)
+			if (currItem->itemText.isNotEmpty())
 				m_ScMW->scrActions["itemAdjustFrameHeightToText"]->setEnabled(true);
 		}
 	}
@@ -413,13 +413,10 @@ void ContextMenu::createMenuItems_Selection()
 		if (m_Sel.objectsLayer() != -1)
 			addAction(m_ScMW->scrActions["itemGroup"]);
 	}
-	else
+	if (selectedItemCount > 0 && m_doc->m_Selection->containsItemType(PageItem::Group))
 	{
-		if (currItem->isGroup())
-		{
-			addAction(m_ScMW->scrActions["itemUngroup"]);
-			addAction(m_ScMW->scrActions["itemGroupAdjust"]);
-		}
+		addAction(m_ScMW->scrActions["itemUngroup"]);
+		addAction(m_ScMW->scrActions["itemGroupAdjust"]);
 	}
 	//-->
 
@@ -495,7 +492,10 @@ void ContextMenu::createMenuItems_Selection()
 		menuEdit->addAction(m_ScMW->scrActions["editCopy"]);
 	if (((m_doc->appMode == modeEdit && currItem->itemType() == PageItem::TextFrame) || (m_doc->appMode == modeEditTable && currItem->itemType() == PageItem::Table)) &&
 		(ScMimeData::clipboardHasScribusText() || ScMimeData::clipboardHasScribusElem() || ScMimeData::clipboardHasPlainText()))
+	{
 		menuEdit->addAction(m_ScMW->scrActions["editPaste"]);
+		menuEdit->addAction(m_ScMW->scrActions["editPastePlainText"]);
+	}
 	if (!currItem->locked() && (m_doc->appMode != modeEdit)  && (m_doc->appMode != modeEditTable) && (!(currItem->isSingleSel)))
 		menuEdit->addAction(m_ScMW->scrActions["itemDelete"]);
 
@@ -601,7 +601,7 @@ void ContextMenu::createMenuItems_NoSelection(double mx, double my)
 	addSeparator();
 	addAction(m_ScMW->scrActions["viewSnapToGrid"]);
 	addAction(m_ScMW->scrActions["viewSnapToGuides"]);
-	addAction(m_ScMW->scrActions["viewSnapToElements"]);
+	addAction(m_ScMW->scrActions["viewSnapToItems"]);
 	
 	onAPage = (m_doc->OnPage(mx, my) != -1);
 	if (onAPage)
