@@ -27,10 +27,10 @@ for which a new license (GPL+exception) is in place.
 #include <QWidget>
 #include <QComboBox>
 #include <QFontDatabase>
-#include <QPixmapCache>
 #include <QValidator>
 
 #include "scribusapi.h"
+#include "ui/widgets/form_widget.h"
 
 class QEvent;
 class QFont;
@@ -71,15 +71,20 @@ class SCRIBUS_API FontComboH : public QWidget
 	Q_OBJECT
 
 public:
-	FontComboH(QWidget* parent, bool labels=false);
+	FontComboH(QWidget* parent, bool labels = false);
 	~FontComboH() {}
 	
-	QString currentFont();
+	QString currentFont() const;
 	void rebuildList(ScribusDoc *currentDoc, bool forAnnotation = false, bool forSubstitute = false);
 
+	void setGuestWidget( QWidget * widget);
+	QWidget* guestWidget();
+
 public slots:
 	void setCurrentFont(const QString& f);
 	void languageChange();
+	void iconSetChange();
+	void toggleLabelVisibility(bool v);
 
 signals:
 	void fontSelected(QString);
@@ -91,8 +96,8 @@ protected slots:
 protected:
 	QComboBox* fontFamily { nullptr };
 	QComboBox* fontStyle { nullptr };
-	QLabel *fontFaceLabel { nullptr };
-	QLabel *fontStyleLabel { nullptr };
+	FormWidget *fontFaceLabel { nullptr };
+	FormWidget *fontStyleLabel { nullptr };
 	QGridLayout* fontComboLayout { nullptr };
 	PrefsManager& prefsManager;
 	ScribusDoc *currDoc { nullptr };
@@ -111,25 +116,19 @@ protected:
 class FontFamilyDelegate : public QAbstractItemDelegate
 {
 	Q_OBJECT
+
 	public:
 		explicit FontFamilyDelegate(QObject *parent);
 
 		// painting
-		void paint(QPainter *painter,
-				   const QStyleOptionViewItem &option,
-				   const QModelIndex &index) const Q_DECL_OVERRIDE;
+		void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+		bool helpEvent(QHelpEvent * event, QAbstractItemView * view, const QStyleOptionViewItem & option, const QModelIndex & index) override;
+		QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-		bool helpEvent(QHelpEvent * event, QAbstractItemView * view,
-					   const QStyleOptionViewItem & option, const QModelIndex & index) Q_DECL_OVERRIDE;
-
-		QSize sizeHint(const QStyleOptionViewItem &option,
-					   const QModelIndex &index) const Q_DECL_OVERRIDE;
-
-		QFontDatabase::WritingSystem writingSystem;
+		QFontDatabase::WritingSystem writingSystem { QFontDatabase::Any };
 
 	protected:
 		QFont m_font;
-		static QPixmapCache pixmapCache;
 };
 
 class FontComboValidator : public QValidator
