@@ -50,7 +50,7 @@ gtImporterDialog::gtImporterDialog(const QString& fileName, const QStringList& i
 		ext.prepend(".");
 
 	setWindowTitle( tr("Choose the importer to use"));
-	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+	setWindowIcon(IconManager::instance().loadIcon("app-icon"));
 
 	QBoxLayout* layout = new QVBoxLayout(this);
 
