@@ -16,7 +16,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 	typeStr = tr("Anchors");
 	//adding name of marks type, and make it unselectable
 	LabelList->addItem("+++ " + typeStr);
-	qobject_cast<QStandardItemModel *>(LabelList->model())->item( ++index )->setEnabled( false );
+	qobject_cast<QStandardItemModel *>(LabelList->model())->item(++index)->setEnabled(false);
 	for (int i = 0; i < marks.size(); ++i)
 	{
 		if (marks[i]->isType(typeMrk))
@@ -28,7 +28,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 	typeMrk = MARK2MarkType;
 	typeStr = tr("Mark to Mark");
 	LabelList->addItem("+++ " + typeStr);
-	qobject_cast<QStandardItemModel *>(LabelList->model())->item( ++index )->setEnabled( false );
+	qobject_cast<QStandardItemModel *>(LabelList->model())->item(++index)->setEnabled(false);
 	for (int i = 0; i < marks.size(); ++i)
 	{
 		if (marks[i]->isType(typeMrk) && marks[i] != omitMark)
@@ -40,7 +40,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 	typeMrk = MARK2ItemType;
 	typeStr = tr("Mark to Item");
 	LabelList->addItem("+++ " + typeStr);
-	qobject_cast<QStandardItemModel *>(LabelList->model())->item( ++index )->setEnabled( false );
+	qobject_cast<QStandardItemModel *>(LabelList->model())->item(++index)->setEnabled(false);
 	for (int i = 0; i < marks.size(); ++i)
 	{
 		if (marks[i]->isType(typeMrk))
@@ -52,7 +52,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 	typeMrk = MARKNoteMasterType;
 	typeStr = tr("Note mark");
 	LabelList->addItem("+++ " + typeStr);
-	qobject_cast<QStandardItemModel *>(LabelList->model())->item( ++index )->setEnabled( false );
+	qobject_cast<QStandardItemModel *>(LabelList->model())->item(++index)->setEnabled(false);
 	for (int i = 0; i < marks.size(); ++i)
 	{
 		if (marks[i]->isType(typeMrk))
@@ -63,7 +63,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 	}
 //	typeMrk = MARKIndexType;	typeStr = tr("Index entry");
 //	LabelList->addItem("+++ " + typeStr);
-//	qobject_cast<QStandardItemModel *>(LabelList->model())->item( ++index )->setEnabled( false );
+//	qobject_cast<QStandardItemModel *>(LabelList->model())->item(++index)->setEnabled(false);
 //	for (int i = 0; i < marks.size(); ++i)
 //	{
 //		if (marks[i]->isType(typeMrk))
@@ -72,7 +72,7 @@ Mark2Mark::Mark2Mark(const QList<Mark*>& marks, Mark* omitMark, QWidget *parent)
 //			index++;
 //		}
 //	}
-	setWindowTitle(tr("Mark to Mark"));
+	setWindowTitle(tr("Reference to Mark"));
 }
 
 void Mark2Mark::values(QString& label, Mark* &mrk)
@@ -80,7 +80,7 @@ void Mark2Mark::values(QString& label, Mark* &mrk)
 	label = this->labelEdit->text();
 	int labelID = LabelList->currentIndex();
 	if (labelID == 0)
-		mrk= nullptr;
+		mrk = nullptr;
 	else
 		mrk = (Mark*) LabelList->itemData(labelID).value<void*>();
 }
@@ -94,12 +94,13 @@ void Mark2Mark::setValues(const QString label, const Mark* mrk)
 
 void Mark2Mark::changeEvent(QEvent *e)
 {
-    QDialog::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        retranslateUi(this);
-        break;
-    default:
-        break;
-    }
+	QDialog::changeEvent(e);
+	switch (e->type())
+	{
+		case QEvent::LanguageChange:
+			retranslateUi(this);
+			break;
+		default:
+			break;
+	}
 }
