@@ -16,7 +16,6 @@ for which a new license (GPL+exception) is in place.
 #include "scconfig.h"
 #include "pdfexportdialog.h"
 
-
 #include <QByteArray>
 #include <QCheckBox>
 #include <QFileDialog>
@@ -33,6 +32,7 @@ for which a new license (GPL+exception) is in place.
 #include <QToolTip>
 #include <QVBoxLayout>
 
+#include "colormgmt/sccolormgmtstructs.h"
 #include "commonstrings.h"
 #include "iconmanager.h"
 #include "pdfoptions.h"
@@ -49,8 +49,8 @@ for which a new license (GPL+exception) is in place.
 PDFExportDialog::PDFExportDialog( QWidget* parent, const QString & docFileName,
 								  const QMap<QString, int > & DocFonts,
 								  ScribusView *currView, PDFOptions & pdfOptions,
-								  const ProfilesL & PDFXProfiles, const SCFonts &AllFonts,
-								  const ProfilesL & printerProfiles)
+								  const ScProfileInfoMap& PDFXProfiles, const SCFonts &AllFonts,
+								  const ScProfileInfoMap& printerProfiles)
 	: QDialog( parent ),
 	m_doc(currView->m_doc),
 	m_opts(pdfOptions),
@@ -59,7 +59,7 @@ PDFExportDialog::PDFExportDialog( QWidget* parent, const QString & docFileName,
 {
 	setModal(true);
 	setWindowTitle( tr( "Save as PDF" ) );
-	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+	setWindowIcon(IconManager::instance().loadIcon("app-icon"));
 	PDFExportLayout = new QVBoxLayout( this );
 	PDFExportLayout->setSpacing(6);
 	PDFExportLayout->setContentsMargins(9, 9, 9, 9);
