@@ -175,6 +175,10 @@ void PropertiesPalette_Line::unsetDoc()
 	comboLineStyle->setDoc(m_doc);
 	buttonLineColor->unsetDoc();
 	buttonLineMask->unsetDoc();
+
+	lineMarkerSelectorStart->clearList();
+	lineMarkerSelectorEnd->clearList();
+
 	updateLineStyles(nullptr);
 
 	setEnabled(false);
@@ -333,7 +337,6 @@ void PropertiesPalette_Line::setCurrentItem(PageItem *item)
 
 	showLineWidth(m_item->lineWidth());
 	showLineValues(m_item->lineStyle(), m_item->lineEnd(), m_item->lineJoin());
-
 }
 
 void PropertiesPalette_Line::updateArrowStyles()
@@ -344,7 +347,12 @@ void PropertiesPalette_Line::updateArrowStyles()
 void PropertiesPalette_Line::updateArrowStyles(ScribusDoc *doc)
 {
 	if (!doc)
+	{
+		lineMarkerSelectorStart->clearList();
+		lineMarkerSelectorEnd->clearList();
 		return;
+	}
+
 	lineMarkerSelectorStart->rebuildList(&doc->arrowStyles());
 	buttonMarkerStart->setIcon(lineMarkerSelectorStart->currentIcon());
 	lineMarkerSelectorEnd->rebuildList(&doc->arrowStyles());
@@ -391,13 +399,8 @@ void PropertiesPalette_Line::setCurrentItem_Line(PageItem *item)
 	item->strokePatternFlip(mirrorX, mirrorY);
 	buttonLineColor->setPattern(
 				item->strokePattern(),
-				item->strokePatternTransform().offsetX,
-				item->strokePatternTransform().offsetY,
-				item->strokePatternTransform().scaleX,
-				item->strokePatternTransform().scaleY,
-				item->strokePatternTransform().skewX,
-				item->strokePatternTransform().skewY,
-				item->strokePatternTransform().rotation,
+				item->strokeGradientType(),
+				item->strokePatternTransform(),
 				item->strokePatternTransform().space,
 				mirrorX, mirrorY,
 				item->isStrokePatternToPath()
@@ -855,13 +858,13 @@ void PropertiesPalette_Line::iconSetChange()
 {
 	IconManager& im = IconManager::instance();
 
-	buttonJoinMiter->setIcon(im.loadIcon("16/stroke-join-miter.png"));
-	buttonJoinBevel->setIcon(im.loadIcon("16/stroke-join-bevel.png"));
-	buttonJoinRound->setIcon(im.loadIcon("16/stroke-join-round.png"));
+	buttonJoinMiter->setIcon(im.loadIcon("stroke-join-miter"));
+	buttonJoinBevel->setIcon(im.loadIcon("stroke-join-bevel"));
+	buttonJoinRound->setIcon(im.loadIcon("stroke-join-round"));
 
-	buttonCapFlat->setIcon(im.loadIcon("16/stroke-cap-butt.png"));
-	buttonCapRound->setIcon(im.loadIcon("16/stroke-cap-round.png"));
-	buttonCapSquare->setIcon(im.loadIcon("16/stroke-cap-square.png"));
+	buttonCapFlat->setIcon(im.loadIcon("stroke-cap-butt"));
+	buttonCapRound->setIcon(im.loadIcon("stroke-cap-round"));
+	buttonCapSquare->setIcon(im.loadIcon("stroke-cap-square"));
 
 	buttonSwapMarker->setIcon(im.loadIcon("swap"));
 	buttonLineMask->setDotIcon(im.loadIcon("mask", 8));
