@@ -61,7 +61,7 @@ protected:
 public slots:
 	void setMainWindow(ScribusMainWindow *mw);
 
-	void setDoc(ScribusDoc *d);
+	void setDoc(ScribusDoc *doc);
 	void setCurrentItem(PageItem *item);
 	void unsetDoc();
 	void unsetItem();
