@@ -21,7 +21,7 @@ for which a new license (GPL+exception) is in place.
 Query::Query( QWidget* parent,  const char* name, bool modal, const QString& text, const QString& title ) : QDialog( parent )
 {
 	setWindowTitle( title );
-	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+	setWindowIcon(IconManager::instance().loadIcon("app-icon"));
 	setModal(modal);
 	queryLayout = new QVBoxLayout( this );
 	queryLayout->setContentsMargins(9, 9, 9, 9);
@@ -133,3 +133,9 @@ void Query::setValidator(const QRegularExpression& rx)
 	QValidator* valid = new QRegularExpressionValidator( rx, this );
 	answerEdit->setValidator(valid);
 }
+
+Query::~Query()
+{
+	if (answerEdit->validator())
+		delete answerEdit->validator();
+};
