@@ -8,11 +8,12 @@ for which a new license (GPL+exception) is in place.
 #include <cstdlib>
 
 #include <QDebug>
-#include <QStandardPaths>
 #include <QLayout>
 #include <QLineEdit>
 #include <QListView>
 #include <QPushButton>
+#include <QStandardPaths>
+#include <QStorageInfo>
 #include <QStringList>
 #include <QUrl>
 
@@ -20,7 +21,7 @@ for which a new license (GPL+exception) is in place.
 #include "scfilewidget.h"
 
 
-ScFileWidget::ScFileWidget(QWidget * parent) : QFileDialog(parent, Qt::Widget)
+ScFileWidget::ScFileWidget(QWidget * parent, fwContextFlags contextFlags) : QFileDialog(parent, Qt::Widget)
 {
 	setOption(QFileDialog::DontUseNativeDialog);
 	setSizeGripEnabled(false);
@@ -34,21 +35,42 @@ ScFileWidget::ScFileWidget(QWidget * parent) : QFileDialog(parent, Qt::Widget)
 
 #ifdef Q_OS_MACOS
 	QList<QUrl> urls;
-	QUrl computer(QUrl::fromLocalFile(QLatin1String("")));
-	if (!urls.contains(computer))
-		urls << computer;
-	QUrl volumes(QUrl::fromLocalFile("/Volumes"));
-	if (!urls.contains(volumes))
-		urls << volumes;
-	QUrl home(QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation)));
-	if (!urls.contains(home))
-		urls << home;
-	QUrl documents(QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)));
-	if (!urls.contains(documents))
-		urls << documents;
-	QUrl dt(QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation)));
-	if (!urls.contains(dt))
-		urls << dt;
+	QUrl macOSUrl(QUrl::fromLocalFile(QLatin1String("")));
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	macOSUrl = QUrl::fromLocalFile("/Volumes");
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	macOSUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	macOSUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	macOSUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	macOSUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation));
+	if (!urls.contains(macOSUrl))
+		urls << macOSUrl;
+	if (contextFlags & contextImages)
+	{
+		macOSUrl = QUrl::fromLocalFile(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
+		if (!urls.contains(macOSUrl))
+			urls << macOSUrl;
+	}
+	setSidebarUrls(urls);
+#endif
+
+#ifdef Q_OS_LINUX
+	QList<QUrl> urls(sidebarUrls());
+	QUrl linuxOSUrl;
+	foreach (const QStorageInfo &storage, QStorageInfo::mountedVolumes())
+	{
+		linuxOSUrl = QUrl::fromLocalFile(storage.rootPath());
+		if (storage.rootPath().startsWith("/media") && !urls.contains(linuxOSUrl))
+			urls << linuxOSUrl;
+	}
 	setSidebarUrls(urls);
 #endif
 
@@ -119,13 +141,12 @@ void ScFileWidget::gotoParentDirectory()
 void ScFileWidget::gotoSelectedDirectory()
 {
 	QStringList s(selectedFiles());
-	if (!s.isEmpty())
-	{
-		QFileInfo fi(s.first());
-//		qDebug()<<s.first()<<fi.absoluteFilePath();
-		if (fi.isDir())
-			setDirectory(fi.absoluteFilePath());
-	}
+	if (s.isEmpty())
+		return;
+	QFileInfo fi(s.first());
+//	qDebug()<<s.first()<<fi.absoluteFilePath();
+	if (fi.isDir())
+		setDirectory(fi.absoluteFilePath());
 }
 
 void ScFileWidget::gotoDesktopDirectory()
