@@ -39,7 +39,7 @@ public:
 	SearchReplace(QWidget* parent, ScribusDoc *doc, PageItem* item, bool mode = true );
 	~SearchReplace() {};
 
-	int firstMatchCursorPosition();
+	int firstMatchCursorPosition() const;
 	void setSearchedText(const QString& text);
 
 public slots:
