@@ -6,7 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 
 #include <QEvent>
-#include <QRegExp>
+#include <QRegularExpression>
 
 #include "colorcombo.h"
 #include "smlinestyle.h"
@@ -215,17 +215,17 @@ QString SMLineStyle::getUniqueName(const QString &name)
 	// both the number and the text leading up to it sans brackets.
 	//     Copy of fred (5)
 	//     ^^^^^^^^^^^^  ^   (where ^ means captured)
-	static QRegExp rx("^(.*)\\s+\\((\\d+)\\)$");
-	int numMatches = rx.lastIndexIn(name);
+	static QRegularExpression rx("^(.*)\\s+\\((\\d+)\\)$");
+	QRegularExpressionMatch match = rx.match(name);
 	// Add a (number) suffix to the end of the name. We start at the
 	// old suffix's value if there was one, or at 2 if there was not.
 	int suffixNum = 1;
 	QString prefix(newName);
-	if (numMatches != -1)
+	if (match.hasMatch())
 	{
 		// Already had a suffix; use the name w/o suffix for prefix and
 		// grab the old suffix value as a starting point.
-		QStringList matches = rx.capturedTexts();
+		QStringList matches = match.capturedTexts();
 		prefix = matches[1];
 		suffixNum = matches[2].toInt();
 	}
@@ -285,6 +285,7 @@ void SMLineStyle::apply()
 		}
 	}
 	m_doc->changed();
+	m_doc->changedPagePreview();
 	m_doc->scMW()->requestUpdate(reqLineStylesUpdate);
 	// Better not call DrawNew() here, as this will cause several unnecessary calls
 	// m_doc->view()->DrawNew();
@@ -412,7 +413,7 @@ void SMLineStyle::setupConnections()
 	connect(m_widget->removeButton, SIGNAL(clicked()), this, SLOT(slotDeleteLine()));
 	connect(m_widget->endCombo, SIGNAL(activated(int)), this, SLOT(slotSetEnd(int)));
 	connect(m_widget->joinCombo, SIGNAL(activated(int)), this, SLOT(slotSetJoin(int)));
-	connect(m_widget->colorCombo, SIGNAL(activated(const QString&)), this, SLOT(slotColor(const QString&)));
+	connect(m_widget->colorCombo, SIGNAL(textActivated(QString)), this, SLOT(slotColor(QString)));
 	connect(m_widget->dashCombo, SIGNAL(activated(int)), this, SLOT(slotLineStyle(int)));
 	connect(m_widget->shadeBox, SIGNAL(valueChanged(int)), this, SLOT(slotShade(int)));
 	connect(m_widget->lineWidth, SIGNAL(valueChanged(double)), this, SLOT(slotLineWidth()));
@@ -424,7 +425,7 @@ void SMLineStyle::removeConnections()
 	disconnect(m_widget->removeButton, SIGNAL(clicked()), this, SLOT(slotDeleteLine()));
 	disconnect(m_widget->endCombo, SIGNAL(activated(int)), this, SLOT(slotSetEnd(int)));
 	disconnect(m_widget->joinCombo, SIGNAL(activated(int)), this, SLOT(slotSetJoin(int)));
-	disconnect(m_widget->colorCombo, SIGNAL(activated(const QString&)), this, SLOT(slotColor(const QString&)));
+	disconnect(m_widget->colorCombo, SIGNAL(textActivated(QString)), this, SLOT(slotColor(QString)));
 	disconnect(m_widget->dashCombo, SIGNAL(activated(int)), this, SLOT(slotLineStyle(int)));
 	disconnect(m_widget->shadeBox, SIGNAL(valueChanged(int)), this, SLOT(slotShade(int)));
 	disconnect(m_widget->lineWidth, SIGNAL(valueChanged(double)), this, SLOT(slotLineWidth()));
