@@ -117,7 +117,7 @@ void SMPStyleWidget::iconSetChange()
 	maxGlyphExtLabel->setPixmap(iconManager.loadPixmap("character-scale-width-max"));
 	consecutiveHyphenLabel->setPixmap(iconManager.loadPixmap("hyphen-consecutive"));
 
-	bulletCharTableButton->setIcon(iconManager.loadIcon("22/insert-table.png"));
+	bulletCharTableButton->setIcon(iconManager.loadIcon("character-table"));
 	distFromTextLabel->setPixmap(iconManager.loadPixmap("paragraph-list-offset"));
 	parEffectCharStyleComboLabel->setPixmap(iconManager.loadPixmap("character-style"));
 	peLabel->setPixmap(iconManager.loadPixmap("paragraph-effects-style"));
@@ -156,16 +156,6 @@ void SMPStyleWidget::languageChange()
 
 	fillPECombo();
 
-/* #13455 stop making the font 2ce as big
-	QFont font1;
-	if (font1.pointSize())
-		font1.setPointSize(font1.pointSize() *2);
-	else if (font1.pixelSize())
-		font1.setPixelSize(font1.pixelSize() *2);
-	((QComboBox*) bulletStrEdit)->setFont(font1);
-	(bulletStrEdit->lineEdit())->setFont(font1);
-*/
-
 	backgroundColor->colorButton->setPersistentToolTip( tr("Background color of selected text"));
 	backgroundColor->setText(tr("Background"));
 }
@@ -200,10 +190,14 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	const ParagraphStyle *parent = dynamic_cast<const ParagraphStyle*>(pstyle->parentStyle());
 	m_hasParent = pstyle->hasParent() && parent != nullptr && parent->hasName() && pstyle->parent() != "";
 
+	int  oldLineSpacingModeIndex = lineSpacingMode->currentIndex();
+	bool lineSpacingModeBlocked = lineSpacingMode->blockSignals(true);
 	lineSpacingMode->clear();
 	lineSpacingMode->addItem( tr("Fixed"));
 	lineSpacingMode->addItem( tr("Automatic"));
 	lineSpacingMode->addItem( tr("Baseline"));
+	lineSpacingMode->setCurrentIndex(oldLineSpacingModeIndex);
+	lineSpacingMode->blockSignals(lineSpacingModeBlocked);
 	
 //	optMarginCombo->clear();
 //	optMarginCombo->addItem(tr("None"), ParagraphStyle::OM_None);
@@ -348,7 +342,7 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	}
 	else
 	{
-		lineSpacingMode->setCurrentIndex(pstyle->lineSpacingMode());
+		lineSpacingMode->setCurrentItem(pstyle->lineSpacingMode());
 		lineSpacing->setValue(pstyle->lineSpacing());
 		spaceAbove->setValue(pstyle->gapBefore());
 		spaceBelow->setValue(pstyle->gapAfter());
@@ -1117,5 +1111,11 @@ void SMPStyleWidget::handleParEffectUse(int index)
 	if (m_hasParent)
 		parentParEffectsButton->show();
 
+	int id = peCombo->currentIndex();
+	double newMinimum = -3000.0;
+	if (id == 2 || id == 3)
+		newMinimum = 0.0;
+	parEffectOffset->setMinimum(newMinimum);
+
 	setParagraphEffect(index);
 }
