@@ -19,6 +19,7 @@ for which a new license (GPL+exception) is in place.
 
 #include "scribusapi.h"
 #include "sctextstruct.h"
+#include "ui/widgets/form_widget.h"
 
 class QComboBox;
 class QPushButton;
@@ -75,6 +76,7 @@ protected:
 	void mousePressEvent(QMouseEvent *m) override;
 	void mouseReleaseEvent(QMouseEvent *) override;
 	void mouseMoveEvent(QMouseEvent *m) override;
+	void wheelEvent(QWheelEvent *m) override;
 	void leaveEvent(QEvent*) override;
 	
 private:
@@ -97,10 +99,10 @@ public:
 
 	virtual void setTabs(const QList<ParagraphStyle::TabRecord>& tabs, int unit);
 
-	QList<ParagraphStyle::TabRecord> getTabVals();
-	double getFirstLine();
-	double getLeftIndent();
-	double getRightIndent();
+	QList<ParagraphStyle::TabRecord> getTabVals() const;
+	double getFirstLine() const;
+	double getLeftIndent() const;
+	double getRightIndent() const;
 
 public slots:
 	void resetOFfL();
@@ -145,14 +147,14 @@ protected:
 	QHBoxLayout* indentLayout { nullptr };
 	QComboBox* typeCombo { nullptr };
 	QComboBox* tabFillCombo { nullptr };
-	QLabel* tabFillComboT { nullptr };
+	FormWidget* tabFillComboT { nullptr };
 	RulerT* ruler { nullptr };
 	QToolButton* rulerScrollL { nullptr };
 	QToolButton* rulerScrollR { nullptr };
-	QLabel* positionLabel { nullptr };
-	QLabel* firstLineLabel { nullptr };
-	QLabel* leftIndentLabel { nullptr };
-	QLabel* rightIndentLabel { nullptr };
+	FormWidget* positionLabel { nullptr };
+	FormWidget* firstLineLabel { nullptr };
+	FormWidget* leftIndentLabel { nullptr };
+	FormWidget* rightIndentLabel { nullptr };
 	ScrSpinBox* tabData { nullptr };
 	ScrSpinBox* firstLineData { nullptr };
 	ScrSpinBox* leftIndentData { nullptr };
