@@ -27,6 +27,7 @@ for which a new license (GPL+exception) is in place.
 #ifndef UNDOSTATE_H
 #define UNDOSTATE_H
 
+#include <cstdint>
 #include <vector>
 
 #include <QMap>
@@ -195,6 +196,23 @@ public:
 	 */
 	int getInt(const QString& key, int def = 0) const;
 
+	/**
+	 * @brief Returns the int value attached to the key.
+	 *
+	 * Values are stored as <code>QString</code>s in the map and when queried
+	 * with this method value attached to the key is converted to a 64bit integer. If
+	 * the conversion fails value of the parameter <code>def</code> will be returned.
+	 * If key is not found from the map it will be added there with the
+	 * value given as a parameter <code>def</code>. In such case <code>def</code>
+	 * will also be returned.
+	 * @param key Key that is searched from the map
+	 * @param def Default value to be used if key is not found from the map
+	 * @return <code>qint64</code> value attached to the key in the map. If the key is not found
+	 * from the map it will be added with the value described in the param
+	 * <code>def</code> which is then returned.
+	 */
+	qint64 getInt64(const QString& key, qint64 def = 0) const;
+
 	/**
 	 * @brief Returns the uint value attached to the key.
 	 *
@@ -212,6 +230,23 @@ public:
 	 */
 	uint getUInt(const QString& key, uint def = 0) const;
 
+	/**
+	 * @brief Returns the uint64_t value attached to the key.
+	 *
+	 * Values are stored as <code>QString</code>s in the map and when queried
+	 * with this method value attached to the key is converted to a 64bit integer. If
+	 * the conversion fails value of the parameter <code>def</code> will be returned.
+	 * If key is not found from the map it will be added there with the
+	 * value given as a parameter <code>def</code>. In such case <code>def</code>
+	 * will also be returned.
+	 * @param key Key that is searched from the map
+	 * @param def Default value to be used if key is not found from the map
+	 * @return <code>quint64</code> value attached to the key in the map. If the key is not found
+	 * from the map it will be added with the value described in the param
+	 * <code>def</code> which is then returned.
+	 */
+	quint64 getUInt64(const QString& key, quint64 def = 0) const;
+
 	/**
 	 * @brief Returns the double value attached to the key.
 	 *
@@ -281,6 +316,13 @@ public:
 	 */
 	void set(const QString& key, int value);
 
+	/**
+	 * @brief Set a value for the key.
+	 * @param key Key that can be later used to query the value.
+	 * @param value Value attached to the key.
+	 */
+	void set(const QString& key, qint64 value);
+
 	/**
 	 * @brief Set a value for the key.
 	 * @param key Key that can be later used to query the value.
@@ -288,6 +330,13 @@ public:
 	 */
 	void set(const QString& key, uint value);
 
+	/**
+	 * @brief Set a value for the key.
+	 * @param key Key that can be later used to query the value.
+	 * @param value Value attached to the key.
+	 */
+	void set(const QString& key, quint64 value);
+
 	/**
 	 * @brief Set a value for the key.
 	 * @param key Key that can be later used to query the value.
