@@ -24,12 +24,12 @@ for which a new license (GPL+exception) is in place.
 #include <QDateTime>
 #include <QtGlobal>
 
-#if !defined(_WIN32) && !defined(Q_OS_MAC)
+#if !defined(_WIN32) && !defined(Q_OS_MACOS)
 #include <execinfo.h>
 #include <cxxabi.h>
 #endif
 #if defined(_WIN32)
-#include <windows.h>
+#include <Windows.h>
 #endif
 
 #include "util_debug.h"
@@ -53,7 +53,7 @@ void tDebug(const QString& message)
  */
 void printBacktrace ( int nFrames )
 {
-#if !defined(_WIN32) && !defined(Q_OS_MAC) && !defined(Q_OS_OPENBSD) && !defined(Q_OS_FREEBSD)
+#if !defined(_WIN32) && !defined(Q_OS_MACOS) && !defined(Q_OS_OPENBSD) && !defined(Q_OS_FREEBSD)
 	void ** trace = new void*[nFrames + 1];
 	char **messages = ( char ** ) nullptr;
 	int i, trace_size = 0;
@@ -62,7 +62,7 @@ void printBacktrace ( int nFrames )
 	messages = backtrace_symbols ( trace, trace_size );
 	if ( messages )
 	{
-		for ( i=1; i < trace_size; ++i )
+		for (i = 1; i < trace_size; ++i)
 		{
 			QString msg ( messages[i] );
 			int sep1 ( msg.indexOf ( "(" ) );
