@@ -135,6 +135,11 @@ VGradientEx::~VGradientEx()
 	clearStops();
 }
 
+const QList<VColorStopEx*>& VGradientEx::colorStops() const
+{
+	return m_colorStops;
+}
+
 void VGradientEx::clearStops()
 {
 	while (!m_colorStops.isEmpty())
@@ -160,7 +165,7 @@ void VGradientEx::addStop(const ScColor &color, double rampPoint, double midPoin
 
 void VGradientEx::removeStop(VColorStopEx& colorstop)
 {
-	int n = m_colorStops.indexOf(&colorstop);
+	qsizetype n = m_colorStops.indexOf(&colorstop);
 	if (n >= 0)
 		delete m_colorStops.takeAt(n);
 }
